/******************************************************************************
 *
 * Copyright 2000, Rohde & Schwarz, inc.
 *
 * NAME:        amps.h
 *
 * PURPOSE:     This file includes a list of constants, definitions, and 
 *              prototypes used to define the Rohde & Schwarz AMPS driver
 *              for the CMU.
 *
 * DESCRIPTION: There is no executable code in this file.
 *
 *
 ******************************************************************************/
//#pragma pack(1)

#ifndef _RSCMUK2A_H_
#define _RSCMUK2A_H_

#ifndef _DLL
   #define _REMVXIPNP
#endif   

#if defined(_MSC_VER) || defined(_CVI_)
   #define _OUTSIDEVEE_
#endif

/* INCLUDE FILES */
// modif JMG
#if defined(_CVI_)
    // CVI  environnement
    #include    <stdio.h>
    #include    <stdlib.h>
    #include    <string.h>
    #include    <time.h>
    #include    <ctype.h>
    #include    <visa.h>
    #include    "rscmu200.h"    
#else
    // VC++ 6.0 environnement
    #include    <stdio.h>
    #include    <stdlib.h>
    #include    <float.h>
    #include    <math.h>
    #include    <time.h>
    #include    <visa.h>
    #include    "rscmu200.h"
#endif

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/* PREPROCESSING DIRECTIVES */

// null pointer value
#ifndef NULL 
#define NULL 0L
#endif  // NULL

// general values
#define MAX_BUFFER_SIZE                   1024

// maximum sizes
#define MAX_PARAMETERS                    15
#define MAX_STRING_SIZE                   31
#define MAX_STATUS_STRING                 256
#define MAX_PARM_SIZE                     40
#define MAX_LIST_OPTIONS                  25

// data type constants for command table
#define INTEGER_TYPE                      0
#define FLOAT_TYPE                        1
#define STRING_30_TYPE                    2

// ********************************************************************
// function indices
// ********************************************************************

#define INP_STATE                         0
#define OUTP_STATE                        1
#define SENSE_INP_CORR                    2
#define SRC_INP_CORR                      3
#define SENSE_OUTP_CORR                   4
#define SRC_OUTP_CORR                     5
#define DM_CLK_STATE                      6
#define DM_CLK_FREQ                       7
#define SENS_LEV_RF_DEF                   8
#define LEV_MODE_RF                       9 
#define LEV_MAX_RF                        10
#define LEV_ATT_RF                        11
#define LEV_MODE_AF                       12
#define LEV_MAX_AF                        13
#define RFAN_FREQ                         14
#define RFAN_FREQ_CHAN                    15
#define RFAN_FREQ_OFFSET                  16
#define SAT_SCC                           17
#define ST_DAT                            18
#define AFG_LEV                           19
#define AFG_FREQ                          20
#define SENS_LEV_AF_DEF                   21
#define BSS_SAT_PEAK_DEV_OCH              22
#define MODG_DEV                          23
#define MODG_FREQ                         24
#define BSS_SAT_SCC_OCH                   25
#define RFG_LEV                           26
#define RFG_FREQ                          27
#define RFG_FREQ_CHAN                     28
#define RFG_FREQ_OFFSET                   29
#define SAT_PEAK_DEV                      30
#define ST_PEAK_DEV                       31
#define CONF_NET_VMAC_OCH                 32
#define INIT_AFG                          33
#define INIT_MODG                         34
#define INIT_RFG                          35
#define INIT_SATG                         36
#define INIT_STG                          37 
#define INIT_RXAF                         38
#define INIT_RXAFAN                       39
#define INIT_RX_HN                        40
#define INIT_RX_SENS                      41
#define INIT_TXAF                         42
#define INIT_MOD_TX                       43
#define INIT_HN_TX                        44
#define INIT_AFL                          45
#define ABORT_AFG                         46
#define ABORT_MODG                        47
#define ABORT_RFG                         48
#define ABORT_SATG                        49
#define ABORT_STG                         50
#define ABORT_RXAF                        51
#define ABORT_RXAFAN                      52
#define ABORT_RX_HN                       53
#define ABORT_RX_SENS                     54
#define ABORT_TXAF                        55
#define ABORT_MOD_TX                      56
#define ABORT_HN_TX                       57
#define ABORT_AFL                         58
#define AFG_STATUS                        59
#define MODG_STATUS                       60
#define RFG_STATUS                        61
#define SAT_STATUS                        62
#define ST_STATUS                         63
#define STOP_RXAF                         64
#define STOP_RXAFAN                       65
#define STOP_RX_HN                        66
#define STOP_RX_SENS                      67
#define STOP_TXAF                         68
#define STOP_MOD_TX                       69
#define STOP_HN_TX                        70
#define STOP_AFL                          71
#define CONT_RXAF                         72
#define CONT_RXAFAN                       73
#define CONT_RX_HN                        74
#define CONT_RX_SENS                      75
#define CONT_TXAF                         76
#define CONT_MOD_TX                       77
#define CONT_HN_TX                        78
#define CONT_AFL                          79
#define RXAF_EREP                         80
#define RXAF_DEF                          81
#define RXAF_REP                          82
#define RXAF_HOLDOFF                      83
#define RXAF_LIMIT_DEF                    84
#define RXAF_LIMIT_LINES                  85
#define RXAF_LIMIT_TONE                   86
#define RXAF_TDEF                         87
#define RXAF_TDEF_TONE                    88
#define RXAF_TTONES_DEF                   89
#define RXAF_FILT                         90
#define RXAF_FILT_DEF                     91
#define RXAF_SUBARR                       92
#define RXAFAN_EREP                       93
#define RXAFAN_DEF                        94
#define RXAFAN_REP                        95
#define RXAFAN_LIMITS                     96
#define RXAFAN_LIMIT_DEF                  97
#define RXAFAN_FILT                       98
#define RXAFAN_FILT_DEF                   99
#define TXAF_EREP                         100
#define TXAF_DEF                          101
#define TXAF_REP                          102
#define TXAF_HOLDOFF                      103
#define TXAF_SCALE                        104
#define TXAF_REF                          105
#define TXAF_REF_DEV                      106
#define TXAF_LIMIT_DEF                    107
#define TXAF_LIMIT_LINES                  108
#define TXAF_LIMIT_TONE                   109
#define CALC_TXAF_TONE                    110
#define TXAF_TTONES_DEF                   111
#define READ_TXAF_TONE                    112
#define TXAF_SUBARR                       113
#define TXAF_FILT                         114
#define TXAF_FILT_DEF                     115
#define MOD_TX_EREP                       116
#define MOD_TX_REP                        117
#define MOD_TX_LIMITS                     118
#define MOD_TX_LIM_DEF                    119
#define MOD_TX_FILT                       120
#define MOD_TX_FILT_DEF                   121
// #define NOT_USED                       122
#define RXAF_GRID                         123
#define TXAF_GRID                         124
#define RXAF_STATUS                       125
#define FETCH_RXAF_TONE                   126
#define READ_RXAF_TONE                    127
#define SAMPLE_RXAF_TONE                  128
#define SAMPLE_TXAF_TONE                  129
#define CALC_RXAF_TONE                    130
#define PROC_BSS_AVC_LVL                  131
#define TXAF_STATUS                       132
#define FETCH_TXAF_TONE                   133
#define RXAFAN_STATUS                     134
#define FETCH_RXAFAN                      135
#define READ_RXAFAN                       136
#define SAMPLE_RXAFAN                     137
#define CALC_RXAFAN                       138
#define MOD_TX_STATUS                     139
#define FETCH_MOD_TX                      140
#define READ_MOD_TX                       141
#define SAMPLE_MOD_TX                     142
#define CALC_MOD_TX                       143
#define HN_TX_EREP                        144
#define HN_TX_REP                         145
#define HN_TX_LIMITS                      146
#define HN_TX_LIM_DEF                     147
#define HN_TX_FILT                        148
#define HN_TX_FILT_DEF                    149
#define AFL_TX_EREP                       150
#define SIGNAL_ACTION                     151
#define AFL_TX_LIMITS                     152
#define AFL_TX_LIMITS_DEF                 153
#define AFL_TX_FILT                       154
#define AFL_TX_FILT_DEF                   155
#define MOD_TX_DEF                        156
#define HN_TX_DEF                         157
#define AFL_TX_DEF                        158
#define HN_TX_STATUS                      159
#define AFL_TX_STATUS                     160
#define AFL_TX_TAP_DEV                    161
#define AFL_TX_ERR_RANGE                  162
#define RX_HN_EREP                        163
#define RX_HN_DEF                         164
#define RX_HN_REP                         165
#define RX_HN_LIMITS                      166
#define RX_HN_LIMIT_DEF                   167
#define RX_HN_FILT                        168
#define RX_HN_FILT_DEF                    169
#define RX_SENS_EREP                      170
#define RX_SENS_DEF                       171
#define SIGNAL_STATUS                     172
#define RX_SENS_LIMITS                    173
#define RX_SENS_LIMIT_DEF                 174
#define RX_SENS_FILT                      175
#define RX_SENS_FILT_DEF                  176
#define RX_HN_STATUS                      177
#define RX_SENS_STATUS                    178
#define RX_SENS_SINAD                     179
#define RX_SENS_TSE_RANGE                 180
#define RXAF_SCALE                        181
#define RXAF_REF                          182
#define RXAF_REF_LVL                      183
#define SIG_UNIT                          184
#define SIG_MAC                           185
#define SIG_SAT_PEAK_DEV                  186
#define SIG_SAT_SCC                       187
#define SIG_CHAN                          188
#define BSS_ACC_CHAN                      189
#define BSS_ACC_LVL                       190
#define BSS_AVC_CHAN                      191
#define BSS_AVC_LVL                       192
#define BSS_SAT_PEAK_DEV                  193
#define BSS_SAT_SCC                       194
#define CONF_NET_ID_SID                   195
#define CONF_NET_ID_DCC                   196
#define CONF_NET_REG_HOME                 197
#define CONF_NET_REG_ROAM                 198
#define CONF_NET_SIG_IDMIN                199
#define CONF_NET_REQ_SN                   200
#define CONF_NET_CMAC                     201
#define CONF_NET_VMAC                     202
#define CONF_NET_RCFM                     203
#define CONF_NET_LORLINK                  204
#define CONF_NET_RPERIOD                  205
#define MSINFO_MIN                        206
#define MSINFO_SN                         207
#define MSINFO_POW_CLASS                  208
#define MSINFO_BAND                       209
#define MSINFO_MPCI                       210
#define MSINFO_DIAL_NUM                   211
#define INIT_WPOW                         212
#define ABORT_WPOW                        213
#define STOP_WPOW                         214
#define CONT_WPOW                         215
#define WPOW_EREP                         216
#define WPOW_STATUS                       217
#define WPOW_REP                          218
#define READ_WPOW                         219
#define FETCH_WPOW                        220
#define SAMPLE_WPOW                       221
#define FETCH_TX_HN                       222
#define READ_TX_HN                        223
#define SAMPLE_TX_HN                      224
#define CALC_TX_HN                        225
#define FETCH_TX_AFL                      226
#define READ_TX_AFL                       227
#define SAMPLE_TX_AFL                     228
#define CALC_TX_AFL                       229
#define TXAF_TDEF                         230
#define TXAF_TDEF_TONE                    231
#define READ_TXAF_ARR                     232
#define FETCH_TXAF_ARR                    233
#define SAMPLE_TXAF_ARR                   234
#define READ_TXAF_SUB                     235
#define FETCH_TXAF_SUB                    236
#define SAMPLE_TXAF_SUB                   237
#define READ_RXAF_ARR                     238
#define FETCH_RXAF_ARR                    239
#define SAMPLE_RXAF_ARR                   240
#define READ_RXAF_SUB                     241
#define FETCH_RXAF_SUB                    242
#define SAMPLE_RXAF_SUB                   243
#define FETCH_RX_HN                       244
#define READ_RX_HN                        245
#define SAMPLE_RX_HN                      246
#define CALC_RX_HN                        247
#define FETCH_RX_SENS                     248
#define READ_RX_SENS                      249
#define SAMPLE_RX_SENS                    250
#define CALC_RX_SENS                      251
#define CONF_HANDOFF                      252
#define BSS_AVC_CHAN_OCH                  253
#define BSS_AVC_LVL_OCH                   254
//#define NOT_USED                          256
//#define NOT_USED                          257
//#define NOT_USED                          258
#define READ_RX_SINAD                     259
#define FETCH_RX_SINAD                    260
#define SAMPLE_RX_SINAD                   261
#define CALC_RX_SINAD                     262
#define RX_SINAD_REP                      263
#define RX_SINAD_MTIME                    264
#define RX_SINAD_DEF                      265
#define INIT_MOD_TAD                      266
#define ABOR_MOD_TAD                      267
#define STOP_MOD_TAD                      268
#define CONT_MOD_TAD                      269
#define MOD_TAD_EREP                      270
#define MOD_TAD_STATUS                    271
#define MOD_TAD_REP                       272
#define MOD_TAD_DEF                       273
#define READ_MOD_TAD                      274
#define FETC_MOD_TAD                      275
#define SAMP_MOD_TAD                      276
#define CALC_MOD_TAD                      277
#define INIT_MOD_CPOW                     278
#define ABOR_MOD_CPOW                     279
#define STOP_MOD_CPOW                     280
#define CONT_MOD_CPOW                     281
#define MOD_CPOW_EREP                     282
#define MOD_CPOW_STATUS                   283
#define MOD_CPOW_REP                      284
#define MOD_CPOW_DEF                      285
#define READ_MOD_CPOW                     286
#define FETC_MOD_CPOW                     287
#define SAMP_MOD_CPOW                     288
#define CALC_MOD_CPOW                     289
#define INIT_RX_SINAD                     290
#define ABOR_RX_SINAD                     291
#define STOP_RX_SINAD                     292
#define CONT_RX_SINAD                     293
#define RX_SINAD_STAT                     294
#define RX_SINAD_EREP                     295
#define AFG_SLEV                          296
#define AFG_MOD_EXT                       297
#define TXAF_AFG_MODE                     298
#define TXAF_AFG_LEV                      299
#define RESET_AMPS                        300
#define AMPS_STAT_OPER_SYMB               301
#define AMPS_READ_OPER_SYMB               302
#define RXAF_MODG_FMOD                    303
#define RXAF_MODG_TFD                     304
#define CALC_RXAF                         305
#define RXAFAN_NOTCHFILT                  306
#define RXSENS_NOTCHFILT                  307
#define SET_CONF_PROC                     308
#define TARG_DEV_TYP                      309
#define WBD_REP                           310
#define WBD_DEF                           311
#define WDB_DEV_LIMITS                    312
#define WDB_LIM_DEF                       313
#define INIT_WBD                          314
#define ABOR_WBD                          315
#define STOP_WBD                          316
#define CONT_WBD                          317
#define WBD_STATUS                        318
#define WBD_EREP                          319
#define READ_WBD                          320
#define FETC_WBD                          321
#define SAMP_WBD                          322
#define CALC_LIM_WBD                      323
#define TXAF_AFG_LEV_PCOM                 324
#define MOD_TX_FILT_SFBW                  325
#define HN_TX_FILT_SFBW                   326
#define TXAF_CFACT                        327
#define RXAF_CFACT                        328

#define TRIG_SEQ_SRC                      999
#define TRIG_SEQ_THRESH                   999
#define TRIG_SEQ_DEF                      999

// ********************************************************************
// command indices
// ********************************************************************
// RF Analyzer
#define RSCMU_AMPS_VMAC                   2

// REF Out 2 Clock Frequencies
#define RSCMU_REF_FREQ_9_72               0
#define RSCMU_REF_FREQ_12_96              1
#define RSCMU_REF_FREQ_19_44              2
#define RSCMU_REF_FREQ_38_88              3

// Units
#define RSCMU_AMPS_HZ                     0
#define RSCMU_AMPS_KHZ                    1
#define RSCMU_AMPS_MHZ                    2
#define RSCMU_AMPS_GHZ                    3
#define RSCMU_AMPS_CH                     4

// Subarray measurement modes
#define RSCMU_AMPS_ALL                    0
#define RSCMU_AMPS_ARITHMETIC             1
#define RSCMU_AMPS_MIN                    2
#define RSCMU_AMPS_MAX                    3

// Limit Lines Area
#define RSCMU_AMPS_LIMIT_LOWER            0
#define RSCMU_AMPS_LIMIT_UPPER            1

//Start/Stop measurements
#define RSCMU_MEAS_OFF                    0
#define RSCMU_MEAS_RUN                    1
#define RSCMU_MEAS_STOP                   2
#define RSCMU_MEAS_ERR                    3
#define RSCMU_MEAS_STEP                   4
#define RSCMU_MEAS_RDY                    5
#define RSCMU_MEAS_NEXT                   6

// Trigger Sources
#define RSCMU_AMPS_FRUN                   0
#define RSCMU_AMPS_RFP                    1
#define RSCMU_AMPS_IFP                    2
#define RSCMU_AMPS_EXT                    3

// Bandpass filter states
#define RSCMU_FILTER_BP01                 0
#define RSCMU_FILTER_BP02                 1
#define RSCMU_FILTER_BP03                 2
#define RSCMU_FILTER_BP04                 3
#define RSCMU_FILTER_BP05                 4
#define RSCMU_FILTER_BP06                 5
#define RSCMU_FILTER_BP07                 6
#define RSCMU_FILTER_BP08                 7
#define RSCMU_FILTER_BP09                 8
#define RSCMU_FILTER_BP10                 9
#define RSCMU_FILTER_BP11                 10
#define RSCMU_FILTER_BP12                 11
#define RSCMU_FILTER_BP13                 12
#define RSCMU_FILTER_BP14                 13
#define RSCMU_FILTER_BP15                 14
#define RSCMU_FILTER_BP16                 15
#define RSCMU_FILTER_BP17                 16
#define RSCMU_FILTER_BP18                 17

// Reference tones
#define RSCMU_AMPS_RDEV                   0
#define RSCMU_AMPS_TON01                  1
#define RSCMU_AMPS_TON02                  2
#define RSCMU_AMPS_TON03                  3
#define RSCMU_AMPS_TON04                  4
#define RSCMU_AMPS_TON05                  5
#define RSCMU_AMPS_TON06                  6
#define RSCMU_AMPS_TON07                  7
#define RSCMU_AMPS_TON08                  8
#define RSCMU_AMPS_TON09                  9
#define RSCMU_AMPS_TON10                  10
#define RSCMU_AMPS_TON11                  11
#define RSCMU_AMPS_TON12                  12
#define RSCMU_AMPS_TON13                  13
#define RSCMU_AMPS_TON14                  14
#define RSCMU_AMPS_TON15                  15
#define RSCMU_AMPS_TON16                  16
#define RSCMU_AMPS_TON17                  17
#define RSCMU_AMPS_TON18                  18
#define RSCMU_AMPS_TON19                  19
#define RSCMU_AMPS_TON20                  20
#define RSCMU_AMPS_RLEV                   21

// Filter weigthing
#define RSCMU_FILTER_CME                  0
#define RSCMU_FILTER_CC                   1
#define RSCMU_FILTER_OFF                  2

//Matching      
#define RSCMU_MEAS_STATUS_PASS            0
#define RSCMU_MEAS_STATUS_INV             1
#define RSCMU_MEAS_STATUS_FAIL            2
#define RSCMU_MEAS_STATUS_TMER            3
#define RSCMU_MEAS_STATUS_IMP             4

#define RSCMU_MEAS_MATCH_OK               0
#define RSCMU_MEAS_MATCH_INV              1
#define RSCMU_MEAS_MATCH_NMAU             2
#define RSCMU_MEAS_MATCH_NMAL             3

#define RSCMU_MATCH_MATC                  0
#define RSCMU_MATCH_INV                   1 
#define RSCMU_MATCH_NMAT                  2
#define RSCMU_MATCH_NTSC                  3
#define RSCMU_MATCH_OUT                   4

// CMU Signalling State
#define RSCMU_AMPS_STATE_SOFF             0
#define RSCMU_AMPS_STATE_SON              1
#define RSCMU_AMPS_STATE_REG              2
#define RSCMU_AMPS_STATE_ALRT             3 
#define RSCMU_AMPS_STATE_CEST             4 
#define RSCMU_AMPS_STATE_CPEN             5
#define RSCMU_AMPS_STATE_RPEN             6
#define RSCMU_AMPS_STATE_FPEN             7

#define RSCMU_SOFF                        0
#define RSCMU_SON                         1
#define RSCMU_CTM                         2
#define RSCMU_SMS                         3
#define RSCMU_CREL                        4 
#define RSCMU_AMPS_OCALL                  5
#define RSCMU_AMPS_FST                    6

// Handoff Targets
#if !defined(_RSCMUK2T_H_)
#define RSCMU_HANDOFF_IS136800MS          0
#define RSCMU_HANDOFF_IS1361900MS         1
#define RSCMU_HANDOFF_AMPSMS              2
#define RSCMU_HANDOFF_IS136800MSFallback  3
#define RSCMU_HANDOFF_IS1361900MSFallback 4
#define RSCMU_HANDOFF_AMPSMSFallback      5
#define RSCMU_HANDOFF_NONE                6
#endif

// AFG mode
#define RSCMU_AMPS_AFG_TLEV               0
#define RSCMU_AMPS_AFG_SLEV               1
#define RSCMU_AMPS_AFG_SRES               2

// MODGen mode
#define RSCMU_AMPS_MODG_TLEV              0
#define RSCMU_AMPS_MODG_SLEV              1

// Event Symbolic
#define RSCMU_AMPS_CFM                    0
#define RSCMU_AMPS_RFM                    1
#define RSCMU_AMPS_LORL                   2
#define RSCMU_AMPS_MREG                   3
#define RSCMU_AMPS_MINV                   4
#define RSCMU_AMPS_RFNS                   6
#define RSCMU_AMPS_MDER                   7
#define RSCMU_AMPS_TCH                    9
#define RSCMU_AMPS_RFIO                   11
#define RSCMU_AMPS_RFIU                   12
#define RSCMU_AMPS_AFIO                   13
#define RSCMU_AMPS_AFIU                   14

#define RSCMU_AMPS_NOTCH_05               0
#define RSCMU_AMPS_NOTCH_01               1

#define RSCMU_AMPS_RMSDEV                 0
#define RSCMU_AMPS_PEAKDEV                1

// Limit range
#define RSCMU_AMPS_LIM_DEF                0
#define RSCMU_AMPS_LIM_MAX                1
#define RSCMU_AMPS_LIM_MIN                2

/************************************************************/
/*                      DEFINES                             */
/************************************************************/

#ifndef _OUTSIDEVEE_

// Logical values: 
#define RSCMU_FALSE                       0
#define RSCMU_TRUE                        1

// On/Off values: 
#define RSCMU_ON                          1
#define RSCMU_OFF                         0
#define RSCMU_VAL_ON                      1
#define RSCMU_VAL_OFF                     0

// None value:
#define RSCMU_NONE                        0

/*---------------------------------------------------------------------------*/

#define RSCMU_SECONDARY_ADDRESS_MIN       1
#define RSCMU_SECONDARY_ADDRESS_MAX       30

#define RSCMU_TMO_VALUE                   10000

/*---------------------------------------------------------------------------*/
/* File I/O buffer size:
/*---------------------------------------------------------------------------*/

#define WR_BUFFER_SIZE                    512L
#define RD_BUFFER_SIZE                    512L
#define RD_BUFFER_SIZE_ARRAY              32767L

// Mathematical Values
#define RSCMU_NAN                         9.91e+37
#define RSCMU_NAN_VI_INT32                0x80000000

//Function Group Names FW2.0
#define RSCMU_NOT_MAPPED                  -1
#define RSCMU_BASE                        0
#define RSCMU_RF_NSIG                     1
#define RSCMU_GSM400MS_NSIG               2     
#define RSCMU_GSM400MS_SIG                3
#define RSCMU_GSM400BS_NSIG               4
#define RSCMU_GSM400BS_SIG                5
#define RSCMU_GSM900MS_NSIG               6
#define RSCMU_GSM900MS_SIG                7
#define RSCMU_GSM900BS_NSIG               8
#define RSCMU_GSM900BS_SIG                9
#define RSCMU_GSM1800MS_NSIG              10
#define RSCMU_GSM1800MS_SIG               11
#define RSCMU_GSM1800BS_NSIG              12
#define RSCMU_GSM1800BS_SIG               13
#define RSCMU_GSM1900MS_NSIG              14
#define RSCMU_GSM1900MS_SIG               15
#define RSCMU_GSM1900BS_NSIG              16
#define RSCMU_GSM1900BS_SIG               17
#define RSCMU_IS136800MS_NSIG             18
#define RSCMU_IS136800MS_SIG              19
#define RSCMU_IS1361900MS_NSIG            20
#define RSCMU_IS1361900MS_SIG             21
#define RSCMU_AUDIO_NSIG                  22
#define RSCMU_AMPSMS_NSIG                 23
#define RSCMU_AMPSMS_SIG                  24

//Units
#define RSCMU_HZ                          0
#define RSCMU_KHZ                         1
#define RSCMU_MHZ                         2
#define RSCMU_GHZ                         3
#define RSCMU_US                          0
#define RSCMU_MS                          1
#define RSCMU_S                           2

#define RSCMU_10HZ                        0
#define RSCMU_20HZ                        1
#define RSCMU_30HZ                        2
#define RSCMU_50HZ                        3
#define RSCMU_100HZ                       4
#define RSCMU_200HZ                       5
#define RSCMU_300HZ                       6
#define RSCMU_500HZ                       7
#define RSCMU_1KHZ                        8
#define RSCMU_2KHZ                        9
#define RSCMU_3KHZ                        10
#define RSCMU_5KHZ                        11 
#define RSCMU_10KHZ                       12
#define RSCMU_20KHZ                       13
#define RSCMU_30KHZ                       14
#define RSCMU_50KHZ                       15
#define RSCMU_100KHZ                      16
#define RSCMU_200KHZ                      17
#define RSCMU_300KHZ                      18
#define RSCMU_500KHZ                      19
#define RSCMU_1MHZ                        20
#define RSCMU_WIDE                        21    
#define RSCMU_FREQ_AUTO                   21

//SCPI Connection
#define RSCMU_GPIB                        0
#define RSCMU_COM                         1
#define RSCMU_COM1                        1
#define RSCMU_COM2                        2

//Parity
#define RSCMU_PARITY_NONE                 0
#define RSCMU_PARITY_ODD                  1
#define RSCMU_PARITY_EVEN                 2
 
//Protocol
#define RSCMU_PROTOCOL_NONE               0
#define RSCMU_PROTOCOL_XON                1
#define RSCMU_PROTOCOL_ACK                2

// Status byte  
#define RSCMU_STB_OFF                     0
#define RSCMU_STB_ON                      1

//Query
#define RSCMU_DO_QUERY                    1
#define RSCMU_SKIP_QUERY                  0

//Reset
#define RSCMU_RESET_ON                    1
#define RSCMU_RESET_OFF                   0

//Reference Frequency
#define RSCMU_INTERNAL                    0
#define RSCMU_EXTERNAL                    1
#define RSCMU_REF_FRQ_MIN                 1.2190
#define RSCMU_REF_FRQ_MAX                 39.0

//Attenuation
#define RSCMU_NORM                        0
#define RSCMU_LNO                         1
#define RSCMU_LDIS                        2
#define RSCMU_LOW_NOISE                   1
#define RSCMU_LOW_DIST                    2

//Trigger Condition
#define RSCMU_IMM                         0
#define RSCMU_SIGN                        0
#define RSCMU_RFP                         1
#define RSCMU_IFP                         2
#define RSCMU_EXT                         3
#define RSCMU_FRUN                        3

//Trigger Condition
#define RSCMU_LOW                         0
#define RSCMU_MED                         1
#define RSCMU_HIGH                        2

//Measurement Repetition
#define RSCMU_STOP_ON                     1
#define RSCMU_STOP_ALIM                   1
#define RSCMU_STOP_FLIM                   2
#define RSCMU_STEP                        1
#define RSCMU_STEP_ON                     1
#define RSCMU_ON_LIMIT_FAILURE            1

//Measurement Repetition FW 2.0
#define RSCMU_CONTINUOUS                  0
#define RSCMU_SINGLE_SHOT                 1

//Event Reporting
#define RSCMU_SRQ                         1
#define RSCMU_SOPC                        2
#define RSCMU_SRSQ                        3

// TimeOuts
#define RSCMU_SENS_TRIG_MEAS_TMO_MIN      1.0
#define RSCMU_SENS_TRIG_MEAS_TMO_MAX      1000.0

/*===========================================================================*/
/*                          Measurement Control                              */
/*===========================================================================*/


// Generator Status
#define RSCMU_GEN_STAT_OFF                0
#define RSCMU_GEN_STAT_RUN                1
#define RSCMU_GEN_STAT_ERR                2

// Measurement Status
#define RSCMU_MEAS_STAT_OFF               0
#define RSCMU_MEAS_STAT_RUN               1
#define RSCMU_MEAS_STAT_STOP              2
#define RSCMU_MEAS_STAT_ERR               3
#define RSCMU_MEAS_STAT_STEP              4
#define RSCMU_MEAS_STAT_RDY               5

// Sensitivity Measurement Status
#define RSCMU_MEAS_STAT_PASS              0
#define RSCMU_MEAS_STAT_INV               1
#define RSCMU_MEAS_STAT_FAIL              2
#define RSCMU_MEAS_STAT_TMER              3
#define RSCMU_MEAS_STAT_IMP               4

/*===========================================================================*/
/*                                                                           */
/*===========================================================================*/


//Frequency Bandwidth
#define RSCMU_BAND_RESTRICT               0
#define RSCMU_BAND_WIDE                   1
#define RSCMU_BANDWIDTH_30KHZ             1
#define RSCMU_BANDWIDTH_300KHZ            2

// Generator Modulation
#define RSCMU_SSB                         1

//Input connectors
#define RSCMU_INPUT_RF1                   0
#define RSCMU_INPUT_RF2                   1
#define RSCMU_INPUT_RF4                   2

//Output Connectors
#define RSCMU_OUTPUT_RF1                  0
#define RSCMU_OUTPUT_RF2                  1
#define RSCMU_OUTPUT_RF3                  2

// Audio input signal
#define RSCMU_AFAN_AFIN                   0
#define RSCMU_AFAN_AUX1                   1

// Audio path coupling
#define RSCMU_AFAN_AC                     0
#define RSCMU_AFAN_DC                     1

// Speech Encoder Input
#define RSCMU_SPEN_HAND                   0
#define RSCMU_SPEN_GEN                    1
#define RSCMU_SPEN_AUX1                   2

// Speech Decoder Output
#define RSCMU_SPD_HAND                    0
#define RSCMU_SPD_ANAL                    1
#define RSCMU_SPD_AUX2                    2

// Limit Check
#define RSCMU_OK                          0
#define RSCMU_INV                         1
#define RSCMU_NMAU                        2
#define RSCMU_NMAL                        3

#define RSCMU_MATCH_MATC                  0
#define RSCMU_MATCH_INV                   1 
#define RSCMU_MATCH_NMAT                  2
#define RSCMU_MATCH_NTSC                  3
#define RSCMU_MATCH_OUT                   4
#define RSCMU_MATCH_NTR                   5
#define RSCMU_MATCH_BNF                   6
#define RSCMU_MATCH_OFF                   7

#define RSCMU_MANUAL                      0
#define RSCMU_AUTO                        1
#define RSCMU_PCL                         2
#define RSCMU_ALWAYS                      0

#define RSCMU_CURRENT                     0
#define RSCMU_AVERAGE                     1
#define RSCMU_MAXMIN                      2
#define RSCMU_MAXIMUM                     2
#define RSCMU_MINIMUM                     3
#define RSCMU_AVERAGED                    1 // Do not remove it due to keep the compatibility

//Serial interface
#define RSCMU_APPL_TRAN                   0 
#define RSCMU_APPL_REM                    1 
#define RSCMU_APPL_PRIN                   2 

//Input/output attenuation
#define RSCMU_ATT_MIN                     -50
#define RSCMU_ATT_MAX                     +50

//Multiple Measurement
#define RSCMU_MULT_MEAS_MIN               1
#define RSCMU_MULT_MEAS_MAX               10000

//Absolute level on used Timeslot
//#define RSCMU_USEDSLOTMIN                 -137.0
//#define RSCMU_USEDSLOTMAX                 +13.0

//Frequency offset
#define RSCMU_FREQ_OFFSET_MIN             -135000
#define RSCMU_FREQ_OFFSET_MAX             +135000

//Power Level Range
#define RSCMU_LEV_RANGE_MIN               10
#define RSCMU_LEV_RANGE_MAX               100

//Test Points Number
#define RSCMU_TEST_PTS_MIN                1
#define RSCMU_TEST_PTS_MAX                560

#define RSCMU_REG_MAX                     32767
#define RSCMU_SUB_REG_MAX                 15
#define RSCMU_ADDR_PRIM_MAX               30
#define RSCMU_ADDR_SEC_MAX                30  

#define RSCMU_DATABITS_MIN                7
#define RSCMU_DATABITS_MAX                8
#define RSCMU_STOPBITS_MIN                1
#define RSCMU_STOPBITS_MAX                2

#define RSCMU_SUM1                        1
#define RSCMU_SUM2                        2

//Keyboard Assignment
#define RSCMU_KBUS                        0
#define RSCMU_KBGR                        1

//positive / negative
#define RSCMU_POS                        1
#define RSCMU_NEG                         0

// Frequency hopping
#define RSCMU_REL                         0
#define RSCMU_ABS                         1


#endif // end of rscmu200 defines for VEE

// Crest Factor
#define RSCMU_CR_FACTOR_LOW               0
#define RSCMU_CR_FACTOR_MAX               1

// SFBW Filter
#define RSCMU_FILTER_SFBW_F020            0
#define RSCMU_FILTER_SFBW_F100            1
/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
/*---------------------------------------------------------------------------*/
/* The codes for instrument specific ERRORS must be in the range             */
/* 0xBFFC0900 to 0xBFFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_ERROR (VI_INSTR_ERROR_OFFSET + n)                 */
/*                                                                           */
/* The codes for instrument specific WARNINGS must be in the range           */
/* 0x3FFC0900 to 0x3FFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_WARNING (VI_INSTR_WARNINGS_OFFSET + n)            */
/*                                                                           */
/* Where n represents each instrument specific error/warning number.         */
/* The valid range for n is 0x000 to 0x1FF  for CMU Base                     */
/* The valid range for n is 0x200 to 0x2FF  for K2G Option                   */
/* The valid range for n is 0x300 to 0x3FF  for IS136 Option                 */
/* The valid range for n is 0x400 to 0x4FF  for AMPS Option                  */
/* For ease of use the lower 16 bits of warnings and errors should not       */
/* overlap in the same driver.                                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/

#ifdef _OUTSIDEVEE_

#if !defined(_RSCMUK2T_H_) && !defined(_RSCMUK8C_H_) && !defined(__K2G_HEADER)
#define VI_INSTR_WARNING_OFFSET                    (0x3FFC0900L)
#define VI_INSTR_ERROR_OFFSET                      (_VI_ERROR+0x3FFC0900L)
#endif

#define RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_AMPS \
AMPS_EXPAND(RSCMU_AMPS_ERROR_CALL_FROM_MS_FAILED,      (VI_INSTR_ERROR_OFFSET + 0x400L), "Call from mobile station failed") \
AMPS_EXPAND(RSCMU_AMPS_ERROR_CALL_TO_MS_FAILED,        (VI_INSTR_ERROR_OFFSET + 0x401L), "Call to mobile station failed") \
AMPS_EXPAND(RSCMU_AMPS_ERROR_RELEASE_TO_MS_FAILED,     (VI_INSTR_ERROR_OFFSET + 0x402L), "Release to mobile station failed") \
AMPS_EXPAND(RSCMU_AMPS_ERROR_INVALID_SIGN_STAT,        (VI_INSTR_ERROR_OFFSET + 0x403L), "The RSCMU is in an internal signalling state where the command is not allowed") \
AMPS_EXPAND(RSCMU_AMPS_ERROR_INVALID_HANDOVER_TARGET,  (VI_INSTR_ERROR_OFFSET + 0x404L), "The handover target is not available") \
AMPS_EXPAND(RSCMU_AMPS_WARNING_GPIB_FEATURE,           (VI_INSTR_WARNING_OFFSET + 0x401L), "GPIB feature not implemanted") 

typedef enum {
#define AMPS_EXPAND(id, value, text) id = value,
    RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_AMPS
#undef AMPS_EXPAND
} RSCMU_ErrorList_AMPS;

// ********************************************************************
// structures for return values
// ********************************************************************

typedef struct {
   int Start;
   int Samples;
} SUBRANGE;

typedef struct {
   SUBRANGE elements[32];
} SUBARRAY;

typedef struct {
   double Limit;
   int    Enabled;
} LIMITS;

typedef struct {
   LIMITS element[20];
} TEST_TONES;

typedef struct {
   int    Freq;
   double Level;
   int    Enabled;
} TXAF_TEST_TONE_DEF;

typedef struct {
   TXAF_TEST_TONE_DEF element[20];
} TXAF_TONE_DEF;

typedef struct {
   int Freq;
   int Deviation;
   int Enabled;
} RXAF_TEST_TONE_DEF;

typedef struct {
   RXAF_TEST_TONE_DEF element[20];
} RXAF_TONE_DEF;

// ********************************************************************
// structures for command table definitions
// ********************************************************************
#if !defined(_RSCMUK2T_H_) && !defined(_RSCMUK8C_H_) && !defined(_RSCMUC2K_H_)
typedef struct listNode {
    ViInt16        num;
    const ViUInt8 *list[MAX_LIST_OPTIONS];
} LIST, *LISTPTR;

typedef struct {
    ViInt32         type;
    ViInt32         min;
    ViInt32         max;
    LISTPTR         params;
} INT_PARAM_INFO;

typedef struct {
    ViInt32         type;
    ViReal64        min;
    ViReal64        max;
    LISTPTR         params;
} FLOAT_PARAM_INFO;

typedef struct {
    ViInt32         type;
    ViUInt8        *min;       // Placeholder ONLY
    ViUInt8        *max;       // Placeholder ONLY
    LISTPTR         params;
} STRING30_PARAM_INFO;

typedef union {
    INT_PARAM_INFO      i;
    FLOAT_PARAM_INFO    f;
    STRING30_PARAM_INFO s30;
} PARAM_INFO_UNION;

typedef struct {
    ViInt32             num;
    STRING30_PARAM_INFO p[MAX_PARAMETERS];
} STRING_PARAM_BLOCK;

typedef struct {
    ViInt32          num;
    PARAM_INFO_UNION p[MAX_PARAMETERS];
} PARAM_BLOCK;

typedef struct {
    const char    *instrCommand;    // ASCII instrument command
    const char    *instrResponse;   // format for response message
    void           (*transmit)();   // transmit routine
    void           (*response)();   // response routine
    PARAM_BLOCK    *xmit;           // pointer to transmit parameter block
    PARAM_BLOCK    *rcvr;           // pointer to receive parameter block
} COMMAND_INFO;
#endif // !defined(_RSCMUK2T_H_) && !defined(_RSCMUK8C_H_)

#endif // _OUTSIDEVEE_

/* GLOBAL PROCEDURES PROVIDED */
ViStatus _VI_FUNC RSCMU_Init_AMPS (ViSession instrSessionBase,
                                   ViPSession instrSessionAMPS,
                                   ViInt32 AMPSFunctionGroup,
                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InpState (ViSession instrumentHandle,
                                       ViInt32 selectionofInputConnector,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_OutpState (ViSession instrumentHandle,
                                        ViInt32 selectionofOutputConnector,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseCorrLossInp (ViSession instrumentHandle,
                                               ViInt32 selectionofInputConnector,
                                               ViReal64 externalAttenuationdB,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceCorrLossInp (ViSession instrumentHandle,
                                                ViInt32 selectionofInputConnector,
                                                ViReal64 externalAttenuationdB,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseCorrLossOutp (ViSession instrumentHandle,
                                                ViInt32 selectionofOutputConnector,
                                                ViReal64 externalAttenuationdB,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceCorrLossOutp (ViSession instrumentHandle,
                                                 ViInt32 selectionofOutputConnector,
                                                 ViReal64 externalAttenuationdB,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CorrLossInpOutp (ViSession instrumentHandle,
                                                ViInt32 selection_ofOutputConnector,
                                                ViReal64 Output_Attenuation_dB,
                                                ViInt32 selection_ofInputConnector,
                                                ViReal64 Input_Attenuation_dB,
                                                ViChar _VI_FAR errorMessage[]);                                                
ViStatus _VI_FUNC RSCMU_AMPS_SourceDmClockState (ViSession instrumentHandle,
                                                 ViBoolean referenceFreqatREFOUT2,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceDmClockFreq (ViSession instrumentHandle,
                                                ViInt32 referenceFrequencyMHz,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseLevModeRF (ViSession instrumentHandle,
                                             ViInt32 inputLevelSetting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseLevMaxRF (ViSession instrumentHandle,
                                            ViReal64 inputLevelMaximumdBm,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseLevDefaultRF (ViSession instrumentHandle,
                                                ViBoolean enabled,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseLevAttRF (ViSession instrumentHandle,
                                            ViInt32 inputLevelAttenuation,
                                            ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_AFModSource (ViSession instrumentHandle,
                                          ViBoolean AFExternalModulation,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_SenseLevModeAF (ViSession instrumentHandle,
                                             ViInt32 inputLevelSetting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseLevMaxAF (ViSession instrumentHandle,
                                            ViReal64 inputLevelMaximumdBm,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseLevDefaultAF (ViSession instrumentHandle,
                                                ViBoolean enabled,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_TrigSeqSource (ViSession instrumentHandle,
                                            ViInt32 triggerMode,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_TrigSeqThreshold (ViSession instrumentHandle,
                                               ViInt32 triggerThreshold,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_TrigSeqDefault (ViSession instrumentHandle,
                                             ViBoolean enabled,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseRfanFreq (ViSession instrumentHandle,
                                            ViReal64 frequency,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseRfanChan (ViSession instrumentHandle,
                                            ViInt32 channel,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseRfanFreqOffset (ViSession instrumentHandle,
                                                  ViReal64 frequencyOffsetkHz,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceRfGLev (ViSession instrumentHandle,
                                           ViReal64 inputLevelMaximumdBm,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseRfGFreq (ViSession instrumentHandle,
                                           ViReal64 frequency,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseRfGFreqChan (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseRfGFreqOffset (ViSession instrumentHandle,
                                                 ViReal64 frequencyOffsetkHz,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitRfGenerator (ViSession instrumentHandle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortRfGenerator (ViSession instrumentHandle,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchRfGeneratorStatus (ViSession instrumentHandle,
                                                     ViPInt32 generatorStatus,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceAfGLev (ViSession instrumentHandle,
                                           ViReal64 AFGeneratorLevelV,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseAfGFreq (ViSession instrumentHandle,
                                           ViInt32 frequencyHz,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitAfGenerator (ViSession instrumentHandle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortAfGenerator (ViSession instrumentHandle,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchAfGeneratorStatus (ViSession instrumentHandle,
                                                     ViPInt32 generatorStatus,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceModGDev (ViSession instrumentHandle,
                                            ViInt32 deviationHz,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseModGFreq (ViSession instrumentHandle,
                                            ViInt32 frequencyHz,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitModGenerator (ViSession instrumentHandle,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortModGenerator (ViSession instrumentHandle,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchModGeneratorStatus (ViSession instrumentHandle,
                                                      ViPInt32 generatorStatus,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceSatPeakDev (ViSession instrumentHandle,
                                               ViInt32 peakDeviationHz,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceSatScc (ViSession instrumentHandle,
                                           ViInt32 SATColorCode,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitSatGenerator (ViSession instrumentHandle,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortSatGenerator (ViSession instrumentHandle,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchSatGeneratorStatus (ViSession instrumentHandle,
                                                      ViPInt32 generatorStatus,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceStPeakDev (ViSession instrumentHandle,
                                              ViInt32 peakDeviationHz,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceStDat (ViSession instrumentHandle,
                                          ViBoolean enabled,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitStGenerator (ViSession instrumentHandle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortStGenerator (ViSession instrumentHandle,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchStGeneratorStatus (ViSession instrumentHandle,
                                                     ViPInt32 generatorStatus,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxContRep (ViSession instrumentHandle,
                                               ViInt32 repetition,
                                               ViInt32 stopCondition,
                                               ViInt32 stepMode,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxContDefault (ViSession instrumentHandle,
                                                   ViBoolean enabled,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxLimLineLevel (ViSession instrumentHandle,
                                                    ViInt32 carrierFreqErrorRangeHz,
                                                    ViInt32 totalPeakDeviationMaxHz,
                                                    ViReal64 SATFreqErrorrange,
                                                    ViInt32 SATPeakDevErrorRangeHz,
                                                    ViReal64 STFreqErrorRangeHz,
                                                    ViInt32 STPeakDevErrorRangeHz,
                                                    ViReal64 modDistortionandNoise,
                                                    ViReal64 residualAM,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxLimDefault (ViSession instrumentHandle,
                                                  ViBoolean enabled,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxFilter (ViSession instrumentHandle,
                                              ViInt32 bandpass,
                                              ViBoolean deemphasis,
                                              ViBoolean expandor, ViInt32 weighting,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxFilterDefault (ViSession instrumentHandle,
                                                     ViBoolean enabled,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitModTx (ViSession instrumentHandle,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortModTx (ViSession instrumentHandle,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopModTx (ViSession instrumentHandle,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueModTx (ViSession instrumentHandle,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchModTxStatus (ViSession instrumentHandle,
                                               ViPInt32 measurementStatus,
                                               ViPInt32 counterforStatisticsCycle,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxErep (ViSession instrumentHandle,
                                            ViInt32 measurementEventReporting,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalModTx (ViSession instrumentHandle,
                                            ViPReal64 carrierFreqError,
                                            ViPReal64 totalPeakDeviation,
                                            ViPReal64 SATFreqError,
                                            ViPReal64 SATPeakDeviation,
                                            ViPReal64 STFreqError,
                                            ViPReal64 STPeakDeviation,
                                            ViPReal64 audioPeakDeviation,
                                            ViPReal64 audioRMSDeviation,
                                            ViPReal64 modDistNoise,
                                            ViPReal64 carrierPower,
                                            ViPReal64 residualAM,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalModTx (ViSession instrumentHandle,
                                             ViPReal64 carrierFreqError,
                                             ViPReal64 totalPeakDeviation,
                                             ViPReal64 SATFreqError,
                                             ViPReal64 SATPeakDeviation,
                                             ViPReal64 STFreqError,
                                             ViPReal64 STPeakDeviation,
                                             ViPReal64 audioPeakDeviation,
                                             ViPReal64 audioRMSDeviation,
                                             ViPReal64 modDistNoise,
                                             ViPReal64 carrierPower,
                                             ViPReal64 residualAM,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalModTx (ViSession instrumentHandle,
                                              ViPReal64 carrierFreqError,
                                              ViPReal64 totalPeakDeviation,
                                              ViPReal64 SATFreqError,
                                              ViPReal64 SATPeakDeviation,
                                              ViPReal64 STFreqError,
                                              ViPReal64 STPeakDeviation,
                                              ViPReal64 audioPeakDeviation,
                                              ViPReal64 audioRMSDeviation,
                                              ViPReal64 modDistNoise,
                                              ViPReal64 carrierPower,
                                              ViPReal64 residualAM,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalModTx (ViSession instrumentHandle,
                                            ViPInt32 carrierFreqError,
                                            ViPInt32 totalPeakDeviation,
                                            ViPInt32 SATFreqError,
                                            ViPInt32 SATPeakDeviation,
                                            ViPInt32 STFreqError,
                                            ViPInt32 STPeakDeviation,
                                            ViPInt32 audioPeakDeviation,
                                            ViPInt32 audioRMSDeviation,
                                            ViPInt32 modDistNoise,
                                            ViPInt32 carrierPower,
                                            ViPInt32 residualAM,
                                            ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModCPOWContRep (ViSession instrumentHandle,
                                                 ViInt32 repetition,
                                                 ViInt32 stopCondition,
                                                 ViInt32 stepMode,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModCPOWContDefault (ViSession instrumentHandle,
                                                     ViBoolean enabled,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_InitModCPOW (ViSession instrumentHandle,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_AbortModCPOW (ViSession instrumentHandle,
                                           ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_StopModCPOW (ViSession instrumentHandle,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ContinueModCPOW (ViSession instrumentHandle,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_FetchModCPOWStatus (ViSession instrumentHandle,
                                                 ViInt32 *measurementStatus,
                                                 ViInt32 *counter_forStatisticsCycle,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModCPOWErep (ViSession instrumentHandle,
                                              ViInt32 measurementEventReporting,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ReadScalModCPOW (ViSession instrumentHandle,
                                              ViReal64 *carrierFreqError,
                                              ViReal64 *carrierPower,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_FetchScalModCPOW (ViSession instrumentHandle,
                                               ViReal64 *carrierFreqError,
                                               ViReal64 *carrierPower,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_SampleScalModCPOW (ViSession instrumentHandle,
                                                ViReal64 *carrierFreqError,
                                                ViReal64 *carrierPower,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_CalcScalModCPOW (ViSession instrumentHandle,
                                              ViInt32 *carrierFreqError,
                                              ViInt32 *carrierPower,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModTADContRep (ViSession instrumentHandle,
                                                ViInt32 repetition,
                                                ViInt32 stopCondition,
                                                ViInt32 stepMode,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModTADContDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_InitModTAD (ViSession instrumentHandle,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_AbortModTAD (ViSession instrumentHandle,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_StopModTAD (ViSession instrumentHandle,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ContinueModTAD (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_FetchModTADStatus (ViSession instrumentHandle,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *counter_forStatisticsCycle,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModTADErep (ViSession instrumentHandle,
                                             ViInt32 measurementEventReporting,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ReadScalModTAD (ViSession instrumentHandle,
                                             ViReal64 *totalPeakDeviation,
                                             ViReal64 *audioPeakDeviation,
                                             ViReal64 *audioRMSDeviation,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_FetchScalModTAD (ViSession instrumentHandle,
                                              ViReal64 *totalPeakDeviation,
                                              ViReal64 *audioPeakDeviation,
                                              ViReal64 *audioRMSDeviation,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_SampleScalModTAD (ViSession instrumentHandle,
                                               ViReal64 *totalPeakDeviation,
                                               ViReal64 *audioPeakDeviation,
                                               ViReal64 *audioRMSDeviation,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_CalcScalModTAD (ViSession instrumentHandle,
                                             ViInt32 *totalPeakDeviation,
                                             ViInt32 *audioPeakDeviation,
                                             ViInt32 *audioRMSDeviation,
                                             ViChar errorMessage[]);

// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDContRep (ViSession instrumentHandle,
                                                ViInt32 repetition,
                                                ViInt32 stopCondition,
                                                ViInt32 stepMode,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDContDefault (ViSession instrumentHandle,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDLim (ViSession instrumentHandle,
                                            ViInt32 carrierFreqErrorRange_Hz,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDLimDefault (ViSession instrumentHandle,
                                                   ViInt32 enabled,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_InitModWBD (ViSession instrumentHandle,
                                         ViChar errorMessage[]);


ViStatus _VI_FUNC RSCMU_AMPS_AbortModWBD (ViSession instrumentHandle,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_StopModWBD (ViSession instrumentHandle,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ContinueModWBD (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_FetchModWBDStatus (ViSession instrumentHandle,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *counter_forStatisticsCycle,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDErep (ViSession instrumentHandle,
                                             ViInt32 measurementEventReporting,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ReadScalModWBD (ViSession instrumentHandle,
                                             ViInt32  *WordSync,
                                             ViReal64 *carrierFreqError,
                                             ViReal64 *carrierPower,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_FetchScalModWBD (ViSession instrumentHandle,
                                              ViInt32 *wordSync,
                                              ViReal64 *carrierFreqError,
                                              ViReal64 *carrierPower,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_SampleScalModWBD (ViSession instrumentHandle,
                                               ViInt32 *wordSync,
                                               ViReal64 *carrierFreqError,
                                               ViReal64 *carrierPower,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_CalcScalModWBD (ViSession instrumentHandle,
                                             ViInt32 *limitMATCH,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxContRep (ViSession instrumentHandle,
                                              ViInt32 repetition,
                                              ViInt32 stopCondition,
                                              ViInt32 stepMode,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxContDefault (ViSession instrumentHandle,
                                                  ViBoolean enabled,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxLimLineLevel (ViSession instrumentHandle,
                                                   ViInt32 carrierFreqErrorRangeHz,
                                                   ViInt32 SATFreqErrorRangeHz,
                                                   ViInt32 SATPeakDevErrorRangeHz,
                                                   ViReal64 humandNoisedB,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxLimDefault (ViSession instrumentHandle,
                                                 ViBoolean enabled,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxFilter (ViSession instrumentHandle,
                                             ViInt32 bandpass, ViBoolean deemphasis,
                                             ViBoolean expandor, ViInt32 weighting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxFilterDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitHnTx (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortHnTx (ViSession instrumentHandle,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopHnTx (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueHnTx (ViSession instrumentHandle,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchHnTxStatus (ViSession instrumentHandle,
                                              ViPInt32 measurementStatus,
                                              ViPInt32 counterforStatisticsCycle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxErep (ViSession instrumentHandle,
                                           ViInt32 measurementEventReporting,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalHnTx (ViSession instrumentHandle,
                                           ViPReal64 carrierFreqError,
                                           ViPReal64 SATFreqError,
                                           ViPReal64 SATPeakDeviation,
                                           ViPReal64 humandNoise,
                                           ViPReal64 carrierPower,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalHnTx (ViSession instrumentHandle,
                                            ViPReal64 carrierFreqError,
                                            ViPReal64 SATFreqError,
                                            ViPReal64 SATPeakDeviation,
                                            ViPReal64 humandNoise,
                                            ViPReal64 carrierPower,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalHnTx (ViSession instrumentHandle,
                                             ViPReal64 carrierFreqError,
                                             ViPReal64 SATFreqError,
                                             ViPReal64 SATPeakDeviation,
                                             ViPReal64 humandNoise,
                                             ViPReal64 carrierPower,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalHnTx (ViSession instrumentHandle,
                                           ViPInt32 carrierFreqError,
                                           ViPInt32 SATFreqError,
                                           ViPInt32 SATPeakDeviation,
                                           ViPInt32 humandNoise,
                                           ViPInt32 carrierPower,
                                           ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_SourceAfGSLev (ViSession instrumentHandle,
                                            ViReal64 AFGeneratorLevel_V,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLTapDev (ViSession instrumentHandle,
                                            ViInt32 targetDeviation,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLTgtErrRange (ViSession instrumentHandle,
                                                 ViInt32 errorRange,
                                                 ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLTgDevType (ViSession instrumentHandle,
                                               ViInt32 targetDeviationType,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLContDefault (ViSession instrumentHandle,
                                                 ViBoolean enabled,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLLimLineLevel (ViSession instrumentHandle,
                                                    ViInt32 carrierFreqErrorRangeHz,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLLimLineDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLFilter (ViSession instrumentHandle,
                                            ViInt32 bandpass, ViBoolean deemphasis,
                                            ViBoolean expandor, ViInt32 weighting,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLFilterDefault (ViSession instrumentHandle,
                                                   ViBoolean enabled,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitAfL (ViSession instrumentHandle,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortAfL (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopAfL (ViSession instrumentHandle,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueAfL (ViSession instrumentHandle,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchAfLStatus (ViSession instrumentHandle,
                                             ViPInt32 measurementStatus,
                                             ViPInt32 counterforStatisticsCycle,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLErep (ViSession instrumentHandle,
                                          ViInt32 measurementEventReporting,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalAfL (ViSession instrumentHandle,
                                          ViPReal64 carrierFreqError,
                                          ViPReal64 audioPeakDeviation,
                                          ViPReal64 audioRMSDeviation,
                                          ViPReal64 carrierPower,
                                          ViPReal64 AFSearchLevel,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalAfL (ViSession instrumentHandle,
                                           ViPReal64 carrierFreqError,
                                           ViPReal64 audioPeakDeviation,
                                           ViPReal64 audioRMSDeviation,
                                           ViPReal64 carrierPower,
                                           ViPReal64 AFSearchLevel,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalAfL (ViSession instrumentHandle,
                                            ViPReal64 carrierFreqError,
                                            ViPReal64 audioPeakDeviation,
                                            ViPReal64 audioRMSDeviation,
                                            ViPReal64 carrierPower,
                                            ViPReal64 AFSearchLevel,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalAfL (ViSession instrumentHandle,
                                          ViPInt32 carrierFreqError,
                                          ViPInt32 audioDeviationPeak,
                                          ViPInt32 audioDeviationRMS,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafContRep (ViSession instrumentHandle,
                                              ViInt32 repetition,
                                              ViInt32 stopCondition,
                                              ViInt32 stepMode,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_DispTxafContGrid (ViSession instrumentHandle,
                                               ViBoolean gridLines,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafRefDev (ViSession instrumentHandle,
                                             ViInt32 deviationHz,
                                             ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafAfgLev (ViSession instrumentHandle,
                                             ViInt32 AFGControl,
                                             ViReal64 AFGLevel_mV,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafHoldoff (ViSession instrumentHandle,
                                              ViReal64 holdoffTime,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceTxafRefValue (ViSession instrumentHandle,
                                                 ViInt32 reference,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafContDefault (ViSession instrumentHandle,
                                                  ViBoolean enabled,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_DispTxafTraceScale (ViSession instrumentHandle,
                                                 ViReal64 min, ViReal64 max,
                                                 ViChar _VI_FAR errorMessage[]);
#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_AMPS_GetResourceName (ViSession instrSession,
                                              ViSession instrSessionBase,
                                              ViChar _VI_FAR sessionName[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfSubTxafMode (ViSession instrumentHandle,
                                              ViInt32 mode,
                                              ViInt32 numberofSubranges,
                                              SUBARRAY subranges,
                                              ViChar _VI_FAR errorMessage[]);
#endif

#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafLimitLines (ViSession instrumentHandle,
                                                 ViInt32 area, 
                                                 TEST_TONES tones,
                                                 ViChar _VI_FAR errorMessage[]);
#endif

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafLimitTone (ViSession instrumentHandle,
                                                ViInt32 area, ViInt32 tone,
                                                ViReal64 limit, ViBoolean enabled,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafLimitDefault (ViSession instrumentHandle,
                                                   ViBoolean enabled,
                                                   ViChar _VI_FAR errorMessage[]);

#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafTestTones (ViSession instrumentHandle,
                                                TXAF_TONE_DEF testTones,
                                                ViChar _VI_FAR errorMessage[]);
#endif

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafTestToneDefinition (ViSession instrumentHandle,
                                                         ViInt32 tone,
                                                         ViInt32 frequency,
                                                         ViReal64 level,
                                                         ViBoolean enabled,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafTestTonesDefault (ViSession instrumentHandle,
                                                       ViBoolean enabled,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafFilter (ViSession instrumentHandle,
                                             ViInt32 bandpass, ViBoolean deemphasis,
                                             ViBoolean expandor, ViInt32 weighting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafFilterDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitTxaf (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortTxaf (ViSession instrumentHandle,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopTxaf (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueTxaf (ViSession instrumentHandle,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchTxafStatus (ViSession instrumentHandle,
                                              ViPInt32 measurementStatus,
                                              ViPInt32 counterforStatisticsCycle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafErep (ViSession instrumentHandle,
                                           ViInt32 measurementEventReporting,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadTxafTone (ViSession instrumentHandle, ViInt32 tone,
                                           ViPReal64 audioFrequency,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchTxafTone (ViSession instrumentHandle,
                                            ViInt32 tone, ViPReal64 audioFrequency,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleTxafTone (ViSession instrumentHandle,
                                             ViInt32 tone, ViPReal64 audioFrequency,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalTxafTone (ViSession instrumentHandle,
                                               ViInt32 tone,
                                               ViPInt32 audioFrequency,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadArrTxaf (ViSession instrumentHandle,
                                          ViReal64 _VI_FAR audioFrequency[],
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchArrTxaf (ViSession instrumentHandle,
                                           ViReal64 _VI_FAR audioFrequency[],
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleArrTxaf (ViSession instrumentHandle,
                                            ViReal64 _VI_FAR audioFrequency[],
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcArrTxaf( ViSession instrSession,
                                            ViInt32     ULim[],
                                            ViInt32     LLim[],
                                            ViChar      errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadSubTxaf (ViSession instrumentHandle,
                                          ViReal64 _VI_FAR audioFrequency[],
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchSubTxaf (ViSession instrumentHandle,
                                           ViReal64 _VI_FAR audioFrequency[],
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleSubTxaf (ViSession instrumentHandle,
                                            ViReal64 _VI_FAR audioFrequency[],
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfWPowContRep (ViSession instrumentHandle,
                                              ViInt32 repetition,
                                              ViInt32 stopCondition,
                                              ViInt32 stepMode,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitWPow (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortWPow (ViSession instrumentHandle,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopWPow (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueWPow (ViSession instrumentHandle,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchWPowStatus (ViSession instrumentHandle,
                                              ViPInt32 measurementStatus,
                                              ViPInt32 counterforStatisticsCycle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfWPowErep (ViSession instrumentHandle,
                                           ViInt32 measurementEventReporting,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalWPow (ViSession instrumentHandle,
                                           ViPReal64 burstPower, 
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalWPow (ViSession instrumentHandle,
                                            ViPReal64 burstPower, 
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalWPow (ViSession instrumentHandle,
                                             ViPReal64 burstPower,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanContRep (ViSession instrumentHandle,
                                                ViInt32 repetition,
                                                ViInt32 stopCondition,
                                                ViInt32 stepMode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanContDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanLimits (ViSession instrumentHandle,
                                               ViReal64 voltmetermin,
                                               ViReal64 voltmetermax,
                                               ViReal64 distortion, ViReal64 SINAD,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanLimitsDefault (ViSession instrumentHandle,
                                                      ViBoolean enabled,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanFilter (ViSession instrumentHandle,
                                               ViInt32 bandpass, ViInt32 weighting,
                                               ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanFilterNotch (ViSession instrumentHandle,
                                                    ViInt32 notchFilter,
                                                    ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanFilterDefault (ViSession instrumentHandle,
                                                      ViBoolean enabled,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitRxAfan (ViSession instrumentHandle,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortRxAfan (ViSession instrumentHandle,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopRxAfan (ViSession instrumentHandle,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueRxAfan (ViSession instrumentHandle,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchRxAfanStatus (ViSession instrumentHandle,
                                                ViPInt32 measurementStatus,
                                                ViPInt32 counterforStatisticsCycle,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanErep (ViSession instrumentHandle,
                                             ViInt32 measurementEventReporting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalRxAfan (ViSession instrumentHandle,
                                             ViPReal64 AFVoltmeterV,
                                             ViPReal64 AFSINADdB,
                                             ViPReal64 AFDistortion,
                                             ViPReal64 AFaudioFreqHz,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalRxAfan (ViSession instrumentHandle,
                                              ViPReal64 AFVoltmeterV,
                                              ViPReal64 AFSINADdB,
                                              ViPReal64 AFDistortion,
                                              ViPReal64 AFaudioFreqHz,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalRxAfan (ViSession instrumentHandle,
                                               ViPReal64 AFVoltmeterV,
                                               ViPReal64 AFSINADdB,
                                               ViPReal64 AFDistortion,
                                               ViPReal64 AFaudioFreqHz,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalRxAfan (ViSession instrumentHandle,
                                             ViPInt32 AFVoltmeter, ViPInt32 AFSINAD,
                                             ViPInt32 AFDistortion,
                                             ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSINADContRep (ViSession instrumentHandle,
                                                   ViInt32 repetition,
                                                   ViInt32 stopCondition,
                                                   ViInt32 stepMode,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSINADMeasTime (ViSession instrumentHandle,
                                                     ViReal64 measurementTime,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSINADContDef (ViSession instrumentHandle,
                                                   ViBoolean enabled,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_FetchRxSINADStatus (ViSession instrumentHandle,
                                                 ViInt32 *measurementStatus,
                                                 ViInt32 *counter_forStatisticsCycle,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSINADErep (ViSession instrumentHandle,
                                              ViInt32 measurementEventReporting,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ReadRxSINAD (ViSession instrumentHandle,
                                            ViReal64 *AFVoltmeter_V,
                                            ViReal64 *AFSINAD_dB,
                                            ViReal64 *SINAD_at_Hz,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_FetchRxSINAD (ViSession instrumentHandle,
                                             ViReal64 *AFVoltmeter_V,
                                             ViReal64 *AFSINAD_dB,
                                             ViReal64 *SINAD_at_Hz,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_SampleRxSINAD (ViSession instrumentHandle,
                                              ViReal64 *AFVoltmeter_V,
                                              ViReal64 *AFSINAD_dB,
                                              ViReal64 *SINAD_at_Hz,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_CalcLimRxSINAD (ViSession instrumentHandle,
                                            ViInt32 *AFVoltmeter,
                                            ViInt32 *AFSINAD,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_InitRxSINAD (ViSession instrumentHandle,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_AbortRxSINAD (ViSession instrumentHandle,
                                           ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_StopRxSINAD (ViSession instrumentHandle,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ContinueRxSINAD (ViSession instrumentHandle,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxHnContRep (ViSession instrumentHandle,
                                              ViInt32 repetition,
                                              ViInt32 stopCondition,
                                              ViInt32 stepMode,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxHnContDefault (ViSession instrumentHandle,
                                                  ViBoolean enabled,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxHnLimits (ViSession instrumentHandle,
                                             ViReal64 voltmetermin,
                                             ViReal64 voltmetermax,
                                             ViReal64 humNoise,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxHnLimitsDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxHnFilter (ViSession instrumentHandle,
                                             ViInt32 bandpass, ViInt32 weighting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxHnFilterDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitRxHn (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortRxHn (ViSession instrumentHandle,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopRxHn (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueRxHn (ViSession instrumentHandle,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchRxHnStatus (ViSession instrumentHandle,
                                              ViPInt32 measurementStatus,
                                              ViPInt32 counterforStatisticsCycle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxHnErep (ViSession instrumentHandle,
                                           ViInt32 measurementEventReporting,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalRxHn (ViSession instrumentHandle,
                                           ViPReal64 AFVoltmeterV,
                                           ViPReal64 humNoisedB,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalRxHn (ViSession instrumentHandle,
                                            ViPReal64 AFVoltmeterV,
                                            ViPReal64 humNoisedB,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalRxHn (ViSession instrumentHandle,
                                             ViPReal64 AFVoltmeterV,
                                             ViPReal64 humNoisedB,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalRxHn (ViSession instrumentHandle,
                                           ViPInt32 AFVoltmeter, ViPInt32 humNoise,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensTgtSinad (ViSession instrumentHandle,
                                                 ViReal64 SINAD,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensTgtSinadRange (ViSession instrumentHandle,
                                                      ViReal64 SINADErrorRange,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensContDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensLimits (ViSession instrumentHandle,
                                               ViReal64 voltmetermin,
                                               ViReal64 voltmetermax,
                                               ViReal64 SINAD,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensLimitsDefault (ViSession instrumentHandle,
                                                      ViBoolean enabled,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensFilter (ViSession instrumentHandle,
                                               ViInt32 bandpass, ViInt32 weighting,
                                               ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensFilterNotch (ViSession instrumentHandle,
                                                    ViInt32 notchFilter,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensFilterDefault (ViSession instrumentHandle,
                                                      ViBoolean enabled,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitRxSens (ViSession instrumentHandle,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortRxSens (ViSession instrumentHandle,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopRxSens (ViSession instrumentHandle,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueRxSens (ViSession instrumentHandle,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchRxSensStatus (ViSession instrumentHandle,
                                                ViPInt32 measurementStatus,
                                                ViPInt32 counterforStatisticsCycle,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensErep (ViSession instrumentHandle,
                                             ViInt32 measurementEventReporting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalRxSens (ViSession instrumentHandle,
                                             ViPReal64 AFVoltmeterV,
                                             ViPReal64 AFSINADdB,
                                             ViPReal64 sensitivitydBm,
                                             ViPReal64 audioFreqHz,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalRxSens (ViSession instrumentHandle,
                                              ViPReal64 AFVoltmeterV,
                                              ViPReal64 AFSINADdB,
                                              ViPReal64 sensitivitydBm,
                                              ViPReal64 audioFreqHz,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalRxSens (ViSession instrumentHandle,
                                               ViPReal64 AFVoltmeterV,
                                               ViPReal64 AFSINADdB,
                                               ViPReal64 sensitivitydBm,
                                               ViPReal64 audioFreqHz,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalRxSens (ViSession instrumentHandle,
                                             ViPInt32 AFVoltmeter, ViPInt32 AFSINAD,
                                             ViPInt32 sensitivity,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafContRep (ViSession instrumentHandle,
                                              ViInt32 repetition,
                                              ViInt32 stopCondition,
                                              ViInt32 stepMode,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_DispRxafContGrid (ViSession instrumentHandle,
                                               ViBoolean gridLines,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafRefLvl (ViSession instrumentHandle,
                                             ViReal64 level,
                                             ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafModgLev (ViSession instrumentHandle,
                                              ViInt32 MODGenControl,
                                              ViInt32 MODGenDeviationHz,
                                              ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafHoldoff (ViSession instrumentHandle,
                                              ViReal64 holdoffTime,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SourceRxafRefValue (ViSession instrumentHandle,
                                                 ViInt32 reference,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafContDefault (ViSession instrumentHandle,
                                                  ViBoolean enabled,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_DispRxafTraceScale (ViSession instrumentHandle,
                                                 ViReal64 min, ViReal64 max,
                                                 ViChar _VI_FAR errorMessage[]);
#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_AMPS_ConfSubRxafMode (ViSession instrumentHandle,
                                              ViInt32 mode,
                                              ViInt32 numberofSubranges,
                                              SUBARRAY subranges,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafLimitLines (ViSession instrumentHandle,
                                                 ViInt32 area, TEST_TONES tones,
                                                 ViChar _VI_FAR errorMessage[]);
#endif

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafLimitTone (ViSession instrumentHandle,
                                                ViInt32 area, ViInt32 tone,
                                                ViReal64 limit, ViBoolean enabled,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafLimitDefault (ViSession instrumentHandle,
                                                   ViBoolean enabled,
                                                   ViChar _VI_FAR errorMessage[]);
#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafTestTones (ViSession instrumentHandle,
                                                RXAF_TONE_DEF testTones,
                                                ViChar _VI_FAR errorMessage[]);
#endif

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafTestToneDefinition (ViSession instrumentHandle,
                                                         ViInt32 tone,
                                                         ViInt32 frequency,
                                                         ViInt32 deviation,
                                                         ViBoolean enabled,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafTestTonesDefault (ViSession instrumentHandle,
                                                       ViBoolean enabled,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafFilter (ViSession instrumentHandle,
                                             ViInt32 bandpass, ViInt32 weighting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafFilterDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_InitRxaf (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_AbortRxaf (ViSession instrumentHandle,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StopRxaf (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ContinueRxaf (ViSession instrumentHandle,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchRxafStatus (ViSession instrumentHandle,
                                              ViPInt32 measurementStatus,
                                              ViPInt32 counterforStatisticsCycle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafErep (ViSession instrumentHandle,
                                           ViInt32 measurementEventReporting,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadRxafTone (ViSession instrumentHandle, ViInt32 tone,
                                           ViPReal64 audioFrequency,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchRxafTone (ViSession instrumentHandle,
                                            ViInt32 tone, ViPReal64 audioFrequency,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleRxafTone (ViSession instrumentHandle,
                                             ViInt32 tone, ViPReal64 audioFrequency,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalRxafTone (ViSession instrumentHandle,
                                               ViInt32 tone, ViPInt32 limit,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadArrRxaf (ViSession instrumentHandle,
                                          ViReal64 _VI_FAR audioFrequency[],
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchArrRxaf (ViSession instrumentHandle,
                                           ViReal64 _VI_FAR audioFrequency[],
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleArrRxaf (ViSession instrumentHandle,
                                            ViReal64 _VI_FAR audioFrequency[],
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalcArrRxaf(   ViSession   instrSession,
                                            ViInt32     ULim[],
                                            ViInt32     LLim[],
                                            ViChar      errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReadSubRxaf (ViSession instrumentHandle,
                                          ViReal64 _VI_FAR audioFrequency[],
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_FetchSubRxaf (ViSession instrumentHandle,
                                           ViReal64 _VI_FAR audioFrequency[],
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SampleSubRxaf (ViSession instrumentHandle,
                                            ViReal64 _VI_FAR audioFrequency[],
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SigUnitChan (ViSession instrumentHandle, ViInt32 unit,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ProcSigAvcChannel (ViSession instrumentHandle,
                                                ViInt32 channel,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ProcBSSignalAvcLevel (ViSession instrumentHandle,
                                                  ViReal64 leveldBm,
                                                  ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ProcSigAvcMAC (ViSession instrumentHandle,
                                            ViInt32 level,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ProcSigAvcSatPeakDev (ViSession instrumentHandle,
                                                   ViInt32 SATPeakDeviation,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ProcSigAvcSatScc (ViSession instrumentHandle,
                                               ViInt32 SATColorCode,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ProcSigAction (ViSession instrumentHandle,
                                            ViInt32 action,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSGlobal (ViSession instrumentHandle,
                                           ViInt32 controlChannel,
                                           ViInt32 voiceChannel,
                                           ViInt32 controlChannelMAC,
                                           ViInt32 voiceChannelMAC,
                                           ViReal64 controlChannelRFLeveldBm,
                                           ViReal64 voiceChannelRFLeveldBm,
                                           ViInt32 SATColorCode,
                                           ViInt32 SATPeakDeviation, ViInt32 SID,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalAccChannel (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalAccLevel (ViSession instrumentHandle,
                                                   ViReal64 level,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalAvcChannel (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalAvcLevel (ViSession instrumentHandle,
                                                   ViReal64 level,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalSatPeakDev (ViSession instrumentHandle,
                                                     ViInt32 SATPeakDeviation,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalSatScc (ViSession instrumentHandle,
                                                 ViInt32 SATColorCode,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetIdSID (ViSession instrumentHandle, ViInt32 SID,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetIdDCC (ViSession instrumentHandle,
                                           ViInt32 digitalColorCode,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetSModeRegHome (ViSession instrumentHandle,
                                                  ViBoolean enabled,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetSModeRegRoam (ViSession instrumentHandle,
                                                  ViBoolean enabled,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetSigModeIDMIN (ViSession instrumentHandle,
                                                  ViChar _VI_FAR mobileID[],
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetReqSN (ViSession instrumentHandle,
                                           ViBoolean enabled,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetCMAC (ViSession instrumentHandle, ViInt32 MAC,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetVMAC (ViSession instrumentHandle, ViInt32 VMAC,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetRCFM (ViSession instrumentHandle,
                                          ViBoolean enabled,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetTimeoutLostConn (ViSession instrumentHandle,
                                                     ViInt32 timeout,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetTimeoutRegPeriod (ViSession instrumentHandle,
                                                      ViInt32 timeout,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_Registration (ViSession instrumentHandle,
                                           ViInt32 timeout,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_Origination (ViSession instrumentHandle,
                                          ViInt32 timeout,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_PagingCallToMS (ViSession instrumentHandle,
                                             ViInt32 timeout,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReleaseCallFromMS (ViSession instrumentHandle,
                                                ViInt32 timeout,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ReleaseCallFromBST (ViSession instrumentHandle,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ProcSigState (ViSession instrumentHandle,
                                           ViPInt32 state,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfHandoffToAMPS (ViSession instrumentHandle,
                                                ViInt32 voiceChannel,
                                                ViInt32 voiceChannelMAC,
                                                ViReal64 voiceChannelRFLeveldBm,
                                                ViInt32 SATPeakDeviation,
                                                ViInt32 SATColorCode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalAvcChannelOCH (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalAvcLevelOCH (ViSession instrumentHandle,
                                                     ViReal64 level,
                                                     ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalSatPeakDevOCH (ViSession instrumentHandle,
                                                       ViInt32 SATPeakDeviation,
                                                       ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfBSSignalSatSccOCH (ViSession instrumentHandle,
                                                   ViInt32 SATColorCode,
                                                   ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfNetVMACOCH (ViSession instrumentHandle, ViInt32 VMAC,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_Handoff (ViSession originatingHandle,
                                      ViSession destinationHandle, 
                                      ViInt32 Target,
                                      ViInt32 timeout,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseMobileInfoNum (ViSession instrumentHandle,
                                                 ViChar _VI_FAR number[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseMobileInfoSN (ViSession instrumentHandle,
                                                ViChar _VI_FAR serialNumber[],
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseMobileInfoPowClass (ViSession instrumentHandle,
                                                      ViPInt32 powerClass,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseMobileInfoBandwidth (ViSession instrumentHandle,
                                                       ViPInt32 bandwidth,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseMobileInfoMPCI (ViSession instrumentHandle,
                                                  ViPInt32 MPCI,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SenseMobileInfoDialledNum (ViSession instrumentHandle,
                                                     ViChar _VI_FAR dialledNumber[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_Close (ViSession instrumentHandleAMPS,
                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_CalculatePower (ViSession      instrumentHandle,
                                                ViReal64    nominalPowerdBm,
                                                ViReal64    tolerancePosdB,
                                                ViReal64    toleranceNegdB,
                                                ViReal64    powerdBm,
                                                ViInt32     *powerMatch,
                                                ViChar      errorMessage[]);                                   
/* Ex Functions (No structures) */

ViStatus _VI_FUNC RSCMU_AMPS_ConfSubTxafMode_Ex (ViSession instrumentHandle,
                                                 ViInt32 mode,
                                                 ViInt32 number_ofSubranges,
                                                 ViInt32 start[],
                                                 ViInt32 samples[],
                                                 ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfSubRxafMode_Ex (ViSession instrumentHandle,
                                                 ViInt32 mode,
                                                 ViInt32 number_ofSubranges,
                                                 ViInt32 start[],
                                                 ViInt32 samples[],
                                                 ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafLimitLines_Ex (ViSession instrumentHandle,
                                                    ViInt32 area,
                                                    ViReal64 limit[],
                                                    ViInt32 enabled[],
                                                    ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafLimitLines_Ex (ViSession instrumentHandle,
                                                    ViInt32 area,
                                                    ViReal64 limit[],
                                                    ViInt32 enabled[],
                                                    ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafTestTones_Ex (ViSession instrumentHandle,
                                                   ViInt32 frequency[],
                                                   ViReal64 level[],
                                                   ViInt32 enabled[],
                                                   ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafTestTones_Ex (ViSession instrumentHandle,
                                                   ViChar errorMessage[],
                                                   ViInt32 frequency[],
                                                   ViInt32 deviation[],
                                                   ViInt32 enabled[]);
ViStatus _VI_FUNC RSCMU_AMPS_GPIB_Timeout (ViSession instrumentHandle,
                                           ViUInt32 timeout_in_ms,
                                           ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_Reset (ViSession instrSession, ViUInt32 MAX_timeout_in_ms, ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_SetCmuVersion (ViSession instrumentHandle,
                                            ViChar firmwareVersion[],
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_StatOperSymbEnab (ViSession instrSession,
                                               ViBoolean CFM, 
                                               ViBoolean RFM,
                                               ViBoolean LORL, 
                                               ViBoolean MREG,
                                               ViBoolean MINV, 
                                               ViBoolean RFNS, 
                                               ViBoolean MDER, 
                                               ViBoolean TCH,
                                               ViBoolean RFIO,
                                               ViBoolean RFIU,
                                               ViBoolean AFIO,
                                               ViBoolean AFIU,
                                               ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_StatOperSymbEvent (ViSession   instrSession,
                                                ViInt32     *nb,
                                                ViInt32     *statusOperEvent,
                                                ViChar      SstatusOperEvent[],
                                                ViChar      errorMessage[]);

// JMG

ViStatus _VI_FUNC RSCMU_AMPS_SetConfProc (ViSession instrumentHandle,
                                          ViBoolean enabled,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLContPcom (ViSession instrumentHandle,
                                              ViBoolean enabled,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxFilterSfbw (ViSession instrumentHandle,
                                                  ViInt32 filter,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxFilterSfbw (ViSession instrumentHandle,
                                                 ViInt32 filter,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafLevCfac (ViSession instrumentHandle,
                                              ViInt32 crestCactor,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafModgCfac (ViSession instrumentHandle,
                                               ViInt32 crestCactor,
                                               ViChar _VI_FAR errorMessage[]);

#ifndef _REMVXIPNP

ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession, ViSession*);
ViStatus _VI_FUNC RSCMU_initAMPS (ViSession, ViSession, ViInt32);
ViStatus _VI_FUNC RSCMU_init (ViRsrc, ViBoolean, ViBoolean, ViPSession);
ViStatus _VI_FUNC RSCMU_reset (ViSession);    
ViStatus _VI_FUNC RSCMU_self_test (ViSession, ViPInt16, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_query (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_message (ViSession, ViStatus, ViChar[]);
ViStatus _VI_FUNC RSCMU_revision_query (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_close (ViSession);

#endif


#if defined(__cplusplus) || defined(__cplusplus__)
    }
#endif


#endif  // _RSCMUK2A_H_

