/******************************************************************************
 *
 * Copyright 2000, Rohde & Schwarz, Inc.  
 *
 * NAME:        rscmuk2a.c
 *
 * PURPOSE:     This file contains the routines used to implement the AMPS                
 *              device driver for the Rohde & Schwarz CMU.
 *
 * DESCRIPTION: There are multiple functions in this file.  
 *              Refer to their corresponding headers for more detailed 
 *              information.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 *
 ******************************************************************************
 * ----------------------------------------------------------------------------
 *                              REVISION HISTORY 
 * ----------------------------------------------------------------------------
 *  Date     | Author     | Description
 *   Release |    Company |            
 * ----------------------------------------------------------------------------
 *  23.10.00 | M.KOUTNY   | Addition (Splitted structures):
 *  V1.00    |            |   Function RSCMU_AMPS_ConfSubTxafMode_Ex
 *           |            |   Function RSCMU_AMPS_ConfSubRxafMode_Ex
 *           |            |   Function RSCMU_AMPS_ConfTxafLimitLines_Ex
 *           |            |   Function RSCMU_AMPS_ConfRxafLimitLines_Ex
 *           |            |   Function RSCMU_AMPS_ConfTxafTestTones_Ex
 *           |            |   Function RSCMU_AMPS_ConfRxafTestTones_Ex
 *           |            | Modification :
 *           |            |   Function RSCMU_AMPS_ConfSubTxafMode ... fixed if()
 *           |            |   statement for checking 3rd parameter.
 *           |            |   Function RSCMU_AMPS_ConfSubRxafMode ... fixed if()
 *           |            |   statement for checking 3rd parameter.
 *           |            |
 *  V1.10    |            |   Delivery Version 1.01
 * ----------------------------------------------------------------------------
 *  25.10.00 | J. SIMA    |  Additions: 
 *  V1.02    |            |     VXIplug&play support
 *           |            |  Modifications:
 *           |            |     Removed compiler warnings MSVC++ Level 1 except for parameter checking macros
 *           |            |  Delivery Version:
 *           |            |     1.02
 * ----------------------------------------------------------------------------
 *  3.1.01   | Z. RYKALA  | Addition
 *  V1.03    |            |     Function RSCMU_AMPS_GetResourceName
 *           |            |     (used only in LabVIEW init function)
 * ----------------------------------------------------------------------------
 *  26.1.01  | J. SIMA    | Modifications
 *  V1.13    |            |     Made changes to the driver source code based
 *           |            |     on the multithread proof version 1.12 from
 *           |            |     Christophe Petit.
 * ----------------------------------------------------------------------------
 *  06.02.01 | M. KAMMERER| Modifications                                    
 *  V1.14    |            |     Quick bugfix for CR#524: added parameters to total of 4
 * ----------------------------------------------------------------------------
 *  12.02.01 | J. SIMA    | Modifications                                    
 *  V1.15    |            |     Changed revision macro to RSCMUK2A_REVISION.
 * ----------------------------------------------------------------------------
 *  15.02.01 | J. SIMA    | Modifications                                    
 *  V1.16    |            |     RSCMU_revision_query now returns the instrument 
 *           |            |     driver revision.
 * ----------------------------------------------------------------------------
 *  19.02.01 | J. SIMA    | Modifications                                    
 *  V1.17    |            |     No modification to C code, this was due to
 *           |            |     a change in RSCMU_AMPS_revision_query.vi. Error
 *           |            |     Message parameter had to be removed from DLL call.
 * ----------------------------------------------------------------------------
 *  23.02.01 | J. SIMA    | Modifications                                    
 *  V1.18    |            |     Init now automatically assigns sec addr if
 *           |            |     func group not already assigned.
 * ----------------------------------------------------------------------------
 *  21.07.01 | JM GAYET   | Modifications                                    
 *    V1.181 |            |     RSCMU_Init_AMPS Timeout set to RSCMU_TMO_VALUE
 * ----------------------------------------------------------------------------
 *  22.07.01 | JM GAYET   | Modifications                                    
 *    V1.182 |            |     RSCMU_AMPS_Registration add 100 ms
 *           |            |     RSCMU_AMPS_Origination add 100 ms
 *           |            |     RSCMU_AMPS_PagingCallToMS add 100 ms
 *           |            |     RSCMU_AMPS_Handoff  Reduce delay to 25 ms before handoff
 * ----------------------------------------------------------------------------
 *  24.07.01 | JM GAYET   | Modifications                                    
 *    V1.183 |            |     RSCMU_AMPS_CalculatePower
 *           |            |     RSCMU_AMPS_ProcSigAction add Force ST
 * ----------------------------------------------------------------------------
 *  30.07.01 | JM GAYET   | Modifications RSCMUK2A.H                                   
 *    V1.184 |            |     #ifndef _RSCMUK2T_H_ should be valid
 * ----------------------------------------------------------------------------
 *  19.09.01 | R SCHMIDT  | Modifications RSCMUK2A.H                                   
 *    V1.185 |            |     Changed preprocessor definitions for multiple protocols 
 * ----------------------------------------------------------------------------
 *  27.11.01 | JM GAYET   | Modifications                                    
 *    V1.186 |            |     VXIPNP
 * ----------------------------------------------------------------------------
 *  09.12.01 | JM GAYET   | Creation                                    
 *    V1.187 |            |      RSCMU_AMPS_InitModTAD 
 *           |            |      RSCMU_AMPS_AbortModTAD 
 *           |            |      RSCMU_AMPS_StopModTAD
 *           |            |      RSCMU_AMPS_ContinueModTAD  
 *           |            |      RSCMU_AMPS_ConfModTADContRep
 *           |            |      RSCMU_AMPS_FetchModTADStatus 
 *           |            |      RSCMU_AMPS_ConfModTADErep
 *           |            |      RSCMU_AMPS_ReadScalModTAD
 *           |            |      RSCMU_AMPS_CalcScalModTAD
 *           |            |      RSCMU_AMPS_InitModCPOW
 *           |            |      RSCMU_AMPS_AbortModCPOW 
 *           |            |      RSCMU_AMPS_StopModCPOW
 *           |            |      RSCMU_AMPS_ContinueModCPOW  
 *           |            |      RSCMU_AMPS_ConfModCPOWContRep
 *           |            |      RSCMU_AMPS_FetchModCPOWStatus 
 *           |            |      RSCMU_AMPS_ConfModCPOWErep
 *           |            |      RSCMU_AMPS_ReadScalModCPOW
 *           |            |      RSCMU_AMPS_CalcScalModCPOW
 * ----------------------------------------------------------------------------
 *  19.02.02 | JM GAYET   | Creation                                    
 *    V1.188 |            |      
 *           |            |      RSCMU_AMPS_ConfRxSINADContRep 
 *           |            |      RSCMU_AMPS_ConfRxSINADMeasTim
 *           |            |      RSCMU_AMPS_ConfRxSINADContDef
 *           |            |      RSCMU_AMPS_ReadRxSINAD
 *           |            |      RSCMU_AMPS_FetchRxSINAD
 *           |            |      RSCMU_AMPS_SampleRxSINAD
 *           |            |      RSCMU_AMPS_CalcLimRxSINAD
 *           |            |      RSCMU_AMPS_InitRxSINAD
 *           |            |      RSCMU_AMPS_AbortRxSINAD
 *           |            |      RSCMU_AMPS_StopRxSINAD
 *           |            |      RSCMU_AMPS_ContinueRxSINAD
 *           |            |      RSCMU_AMPS_FetchRxSINADStatus
 *           |            |      RSCMU_AMPS_ConfRxSINADErep
 *           |            |      RSCMU_AMPS_SourceAfGSLev
 *           |            |      RSCMU_AMPS_AFModSource
 * ----------------------------------------------------------------------------
 *  01.04.02 | JM GAYET   |      Final release
 *    V1.189 |            | 
 * ----------------------------------------------------------------------------
 *  01.04.03 | JM GAYET   | Bug fix
 *    V1.190 |            |      // JMG 020403, "MANUAL", "AUTO"
 * ----------------------------------------------------------------------------
 *  16.10.02 |            | Modifications
 *    V1.191 |            |      RSCMU_Init_AMPS - bugfix
 *           |            |      RSCMU_initAMPS  - bugfix
 * ----------------------------------------------------------------------------
 *  5.11.02  |            | Changed revision number
 *  V3.07.2  |            |
 * ----------------------------------------------------------------------------
 *  31.12.02 | JM GAYET   | Bug fixes :
 *  V3.10RC00|            |      RSCMU_Init_AMPS
 *           |            |      RSCMU_AMPS_AbortStGenerator
 *           |            |      RSCMU_AMPS_ConfModTxFilter
 *           |            |      RSCMU_AMPS_CalcScalModTx
 *           |            |      RSCMU_AMPS_ConfAfLLimLineLevel
 *           |            |      RSCMU_AMPS_CalcScalAfL
 *           |            |      RSCMU_AMPS_SampleScalRxSens
 *           |            |      RSCMU_AMPS_ConfRxafHoldoff 
 *           |            |      RSCMU_AMPS_CalcArrRxaf 
 *           |            |      RSCMU_AMPS_CalcArrTxaf 
 *           |            |      RSCMU_AMPS_SenseLevModeRF function panel
 *           |            |      RSCMU_AMPS_ConfRxafTestToneDefinition
 *           |            |      RSCMU_AMPS_ConfRxafLimitLines
 *           |            |      RSCMU_AMPS_ConfTxafLimitLines
 *           |            |      RSCMU_AMPS_ConfTxafLimitLines_Ex
 *           |            |      RSCMU_AMPS_ConfRxafLimitLines_Ex
 *           |            |      RSCMU_AMPS_ConfTxafTestTones_Ex 
 *           |            |      RSCMU_AMPS_SenseLevDefaultAF 
 *           |            |      RSCMU_AMPS_TrigSeqSource 
 *           |            |      RSCMU_AMPS_TrigSeqThreshold 
 *           |            |      RSCMU_AMPS_TrigSeqDefault 
 *           |            |      RSCMU_AMPS_SenseLevDefaultRF 
 *           |            |      RSCMU_AMPS_ConfModTxContDefault
 *           |            |      RSCMU_AMPS_ConfModTxLimDefault 
 *           |            |      RSCMU_AMPS_ConfModTxFilterDefault 
 *           |            |      RSCMU_AMPS_ConfModCPOWContDefault
 *           |            |      RSCMU_AMPS_ConfModTADContDefault
 *           |            |      RSCMU_AMPS_ConfHnTxContDefault
 *           |            |      RSCMU_AMPS_ConfHnTxLimDefault
 *           |            |      RSCMU_AMPS_ConfHnTxFilterDefault
 *           |            |      RSCMU_AMPS_ConfAfLContDefault
 *           |            |      RSCMU_AMPS_ConfAfLLimLineDefault
 *           |            |      RSCMU_AMPS_ConfAfLFilterDefault
 *           |            |      RSCMU_AMPS_ConfTxafContDefault
 *           |            |      RSCMU_AMPS_ConfTxafLimitDefault
 *           |            |      RSCMU_AMPS_ConfTxafTestTonesDefault
 *           |            |      RSCMU_AMPS_ConfTxafFilterDefault
 *           |            |      RSCMU_AMPS_ConfRxAfanContDefault
 *           |            |      RSCMU_AMPS_ConfRxAfanLimitsDefault
 *           |            |      RSCMU_AMPS_ConfRxAfanFilterDefault
 *           |            |      RSCMU_AMPS_ConfRxSINADContDef
 *           |            |      RSCMU_AMPS_ConfRxHnContDefault
 *           |            |      RSCMU_AMPS_ConfRxHnLimitsDefault
 *           |            |      RSCMU_AMPS_ConfRxHnFilterDefault
 *           |            |      RSCMU_AMPS_ConfRxSensLimitsDefault 
 *           |            |      RSCMU_AMPS_ConfRxafContDefault
 *           |            |      RSCMU_AMPS_ConfRxafLimitDefault
 *           |            |      RSCMU_AMPS_ConfRxafTestTonesDefault
 *           |            |      RSCMU_AMPS_ConfRxafFilterDefault
 *           |            | Creation     
 *           |            |      RSCMU_AMPS_Reset 
 *           |            |      RSCMU_AMPS_GPIB_Timeout
 *           |            |      RSCMU_AMPS_CorrLossInpOutp
 *           |            |      RSCMU_AMPS_ConfRxafModgLev
 *           |            |      RSCMU_AMPS_StatOperSymbEnab
 *           |            |      RSCMU_AMPS_StatOperSymbEvent
 *           |            |      RSCMU_AMPS_SetCmuVersion
 * ----------------------------------------------------------------------------
 *  07.01.03 | JM GAYET   | Bug fixes :
 *  V3.10RC01|            |      RSCMU_Init_AMPS
 *           |            |      RSCMU_AMPS_StatOperSymbEvent
 * ---------------------------------------------------------------------------- 
 *  09.01.03 |W.Klotzsche | 
 *  V3.10.02 |            | Modifications
 *           |            |  Removed #pragma pack(1) from h file
 * ----------------------------------------------------------------------------
 *  23.01.03 | JM GAYET   | Modifications :
 * V3.10RC03 |            |      RSCMU_AMPS_StatOperSymbEnab
 *           |            |      RSCMU_AMPS_StatOperSymbEvent
 * ---------------------------------------------------------------------------- 
 *  31.01.03 |W.Klotzsche | 
 *  V3.10.03 |            | Modifications :
 *           |            | Renamed Revision to 3.10.03
 * ----------------------------------------------------------------------------
 *  31.07.03 |JM GAYET    | 
 *  V3.40.RC0|            | Modifications :
 *           |            | Renamed Revision to 3x40.00
 *           |            | Include VC++ 6.0 Include files
 *           |            | RSCMU_AMPS_ProcSigAvcChannel - Bug fixed
 *           |            | RSCMU_AMPS_ProcBSSignalAvcLevel - Bug fixed
 *           |            | RSCMU_AMPS_ProcSigAvcMAC - Bug fixed
 *           |            | RSCMU_AMPS_ProcSigAvcSatPeakDev - Bug fixed
 *           |            | RSCMU_AMPS_ProcSigAvcSatScc - Bug fixed
 *           |            | RSCMU_AMPS_StatOperSymbEvent - Bug fixed
 * ----------------------------------------------------------------------------
 *  15.12.03 |JM GAYET    | 
 *  V3.50.00 |            | Revision to 3.50.00
 *           |            | Creations :
 *           |            |      RSCMU_AMPS_ConfAfLTgDevType
 *           |            |      RSCMU_AMPS_ConfRxAfanFilterNotch  
 *           |            |      RSCMU_AMPS_ConfRxSensFilterNotch
 *           |            |      RSCMU_AMPS_SetConfProc
 * ----------------------------------------------------------------------------
 *  22.04.04 |JM GAYET    | 
 *  V3.52.00 |            | Revision to 3.52.00
 *           |            | Creations :   Wide Band Data
 *           |            |      RSCMU_AMPS_ConfModWBDContRep
 *           |            |      RSCMU_AMPS_ConfModWBDContDefault
 *           |            |      RSCMU_AMPS_ConfModWBDLim
 *           |            |      RSCMU_AMPS_ConfModWBDLimDefault
 *           |            |      RSCMU_AMPS_InitModWBD 
 *           |            |      RSCMU_AMPS_AbortModWBD
 *           |            |      RSCMU_AMPS_StopModWBD
 *           |            |      RSCMU_AMPS_ContinueModWBD
 *           |            |      RSCMU_AMPS_FetchModWBDStatus
 *           |            |      RSCMU_AMPS_ConfModWBDErep
 *           |            |      RSCMU_AMPS_ReadScalModWBD
 *           |            |      RSCMU_AMPS_FetchScalModWBD
 *           |            |      RSCMU_AMPS_SampleScalModWBD
 *           |            |      RSCMU_AMPS_CalcScalModWBD
 * ----------------------------------------------------------------------------
 *  27.01.05 | P.MARCALIK | 
 *  V3.60.00 |            | Additions:
 *           |            |      RSCMU_AMPS_ConfAfLContPcom
 *           |            |      RSCMU_AMPS_ConfModTxFilterSfbw  
 *           |            |      RSCMU_AMPS_ConfHnTxFilterSfbw
 *           |            |      RSCMU_AMPS_ConfTxafLevCfac
 *           |            |      RSCMU_AMPS_ConfRxafModgCfac
 *           |            | Modification:
 *           |            |      RSCMU_AMPS_AFModSource
 * ----------------------------------------------------------------------------
 *  13.09.05 | P.KOMINEK  | 
 *  V3.60.01 | J.KOMINEK  | - Remote commands added to FP help
 *           |            | - System locale are set to default "C"
 * ----------------------------------------------------------------------------
 *  08.02.06 | J.KOMINEK  | - Fixed function RSCMU_AMPS_ProcSigState()
 *  V3.60.02 |            | 
 *           |            | 
 * ----------------------------------------------------------------------------
 *  23.04.07 | J.KOMINEK  | - New installer, added .NET wrappers, fixed 
 *           |            |   installation issue with rscmu200 ver. 4.30 driver
 *  V3.60.03 |            | 
 * ----------------------------------------------------------------------------
 *  31.07.07 | J.KOMINEK  | - Fixed .NET wrappers
 *  V3.60.04 |            | 
 ******************************************************************************/

/* INCLUDE FILES */
// JMG
#include <locale.h>
#include "rscmuk2a.h"


/* DEFINES */
#define RSCMUK2A_REVISION  "Rev 3.60.04, 08/2007"  // Instrument Driver Revision

// Structure "RSCMU_AMPS_Globals" is initialized for each Session in an 'init' function
struct RSCMU_AMPS_Globals              
{
  struct RSCMU_SESSION_Globals RSCMU_tGlobal;
  struct RSCMU_HandOver        RSCMU_tHandOver;
};


/* FUNCTION PROTOTYPES */
static void     checkRange( ViInt32 cmd, ... );
static void     RSCMU_ReturnArrayValues( ViChar[], ViReal64[] );
static ViInt32  RSCMU_SeparateString( ViChar[], ViChar[], ViChar[15][30] );
static ViStatus getBuffers( ViSession, ViChar**, ViChar**, ViChar[] );
static ViStatus RSCMU_errorMessage( ViSession, ViStatus, ViChar[] );
static ViStatus RSCMU_GetMeasurementStatus( ViChar[], ViChar[], ViInt32 *, ViInt32 * );
static ViStatus RSCMU_GetMatchingLimit( ViInt32*, ViChar[15][30], ViInt32 );

/* SUBROUTINES CALLED */
/* JMG already declared export in rscmu200.h
ViStatus __declspec(dllimport) __stdcall _VI_FUNC RSCMU_Query( ViSession  instrSession
                                       , ViChar     wrtBuf[]
                                       , ViChar     rdBuf[]
                                       , ViBoolean  STBQuery
                                       , ViChar     errorMessage[]
                                       );
*/
/* EXTERNALLY DEFINED GLOBAL CONSTANTS */
/* NONE */

/* INTERNALLY DEFINED GLOBAL CONSTANTS */
/* NONE */

/* EXTERNALLY DEFINED GLOBAL VARIABLES */
/* NONE */ 

/* INTERNALLY DEFINED GLOBAL VARIABLES */
/* NONE */ 

/* STATIC CONSTANTS */
/* NONE */

/* STATIC VARIABLES */
/* NONE */

//*********************************************************************
// Strings for AMPS Remote Commands
//*********************************************************************

static LIST LimitArea = 
   { 2
   , "LOWER", "UPPER"
   };

static LIST mode = 
   { 3
   , "MANUAL", "AUT","VMAC"   
   };

static LIST LvlMode = 
   { 2
   , "MANUAL", "VMAC"
   };

static LIST  enable = 
   { 2
   , "OFF", "ON"
   };

static LIST attenuation = 
   { 3
   , "NORMAL", "LNOISE", "LDISTORTION"
   };

static LIST inpConn = 
   { 4
   , "RF1", "RF2", "RF4"
   };

static LIST outpConn = 
   { 3
   , "RF1", "RF2", "RF3"
   };

static LIST inpSrc = 
   { 3
   , "1", "2", "4"
   };

static LIST outpSrc = 
   { 3
   , "1", "2", "3"
   };

static LIST eventReport = 
   { 4
   , "OFF" , "SRQ", "SOPC", "SRSQ"
   };

static LIST trigSrc = 
   { 4
   , "FRUN", "RFPOWER", "IFPOWER", "EXTERN"
   };

static LIST threshold = 
   { 3
   , "LOW", "MEDIUM", "HIGH"
   };

static LIST FreqUnits =
   { 5
   , "HZ", "KHZ", "MHZ", "GHZ", "CH"
   };

static LIST Subarray = 
   { 4
   , "ALL", "ARIT", "MIN", "MAX"
   };

static LIST sigAction = 
   { 7
   , "SOFF", "SON", "CTM", "SMS", "CRELEASE", "OCALI", "FST"
   };

static LIST TxafRef = 
   { 21
   , "RDEV",  "TON1",  "TON2",  "TON3",  "TON4",  "TON5",  "TON6"
   , "TON7",  "TON8",  "TON9",  "TON10", "TON11", "TON12", "TON13"
   , "TON14", "TON15", "TON16", "TON17", "TON18", "TON19", "TON20"
   };
   
static LIST RxafRef = 
   { 21
   , "RLEV",  "TON1",  "TON2",  "TON3",  "TON4",  "TON5",  "TON6"
   , "TON7",  "TON8",  "TON9",  "TON10", "TON11", "TON12", "TON13"
   , "TON14", "TON15", "TON16", "TON17", "TON18", "TON19", "TON20"
   };
   
static LIST arrays =
   { 2
   , "ARRAY", "SUBARRAY"
   };

static LIST bandpass =
   { 18
   , "BP01", "BP02", "BP03", "BP04", "BP05", "BP06", "BP07"
   , "BP08", "BP09", "BP10", "BP11", "BP12", "BP13", "BP14"
   , "BP15", "BP16", "BP17", "BP18"
   };

static LIST weighting =
   { 3
   , "CME", "CCI", "OFF"
   };
   
static LIST repetition = 
   { 3
   , "CONTINUOUS", "SINGLESHOT", "RF4"
   };

static LIST stopCond = 
   { 2
   , "NONE", "SONERROR"
   };

static LIST stepMode = 
   { 2
   , "NONE", "STEP"
   };

static LIST ClkFreqMHz =
   { 4
   , "9.720", "12.960", "19.440", "38.880"
   };
   

static LIST AFModExt =
   { 2
   , "INT", "EXT"
   };


static LIST AFGMode =
   { 3
   , "TLEV", "SLEV" , "SRES"
   };
   
static char *HandoffTargets[] =
   { "\"IS136800MS\""
   ,  "\"IS136800MSFallback\""
   ,  "\"NONE\""
   };

static char *SRS[]=
   {"CFM","RFM","LORL","MREG","MINV","E5","RFNS","MDER","E8","TCH","MREP","RFIO","RFIU","AFIO","AFIU","E15","NONE"
   };

static LIST MODGen =
   { 2
   , "TDEV", "SDEV"
   };
   
static LIST NotchFilter  =
   { 2
   , "N05", "N01"
   };

static LIST   TargDevTyp =
   { 2
   , "RMS", "PEAK"
   };

static LIST  LimitDef =
   { 3
   , "DEF", "MAX", "MIN"
   };
static LIST BWFilter = 
   { 2
   , "F020", "F100"
   };
   
//*********************************
static PARAM_BLOCK limitdef = 
   { 1
   , INTEGER_TYPE, 0, 2, &LimitDef
   };
static LIST CRFactor = 
   { 2
   , "LOW", "MAX"
   };   
   
//*********************************

static PARAM_BLOCK Default = 
   { 1 
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK ModExt = 
   { 1 
   , INTEGER_TYPE, 0, 1, &AFModExt
   };

static PARAM_BLOCK AttLvl = 
   { 1 
   , INTEGER_TYPE, 0, 2, &attenuation
   };

static PARAM_BLOCK InpMode = 
   { 1 
   , INTEGER_TYPE, 0, 2, &mode
   };

static PARAM_BLOCK SigInpMode = 
   { 1 
   , INTEGER_TYPE, 0, 1, &LvlMode
   };

static PARAM_BLOCK AFLvl = 
   { 1 
   , FLOAT_TYPE, 0.0, 30.0, NULL
   };

static PARAM_BLOCK MaxLvl = 
   { 1 
   , FLOAT_TYPE, -37.0, 47.0, NULL
   };

static PARAM_BLOCK Input = 
   { 1 
   , INTEGER_TYPE, 0, 2, &inpConn
   };

static PARAM_BLOCK Output = 
   { 1 
   , INTEGER_TYPE, 0, 2, &outpConn
   };

static PARAM_BLOCK InpAtt = 
   { 2 
   , INTEGER_TYPE, 0,     2,    &inpSrc
   , FLOAT_TYPE,   -50.0, 50.0, NULL
   };

static PARAM_BLOCK OutpAtt = 
   { 2 
   , INTEGER_TYPE, 0,     2,    &outpSrc
   , FLOAT_TYPE,   -50.0, 50.0, NULL
   };

static PARAM_BLOCK InConn = 
   { 1 
   , INTEGER_TYPE, 0, 3, &inpConn
   };

static PARAM_BLOCK OutConn = 
   { 1 
   , INTEGER_TYPE, 0, 2, &outpConn
   };

static PARAM_BLOCK PeakDev = 
   { 1 
   , INTEGER_TYPE, 1, 20000, NULL
   };

static PARAM_BLOCK RFlvl = 
   { 1 
   , FLOAT_TYPE, -137.0, 13.0, NULL
   };

static PARAM_BLOCK Afglvl = 
   { 1 
   , FLOAT_TYPE, 0.0, 5.0, NULL
   };

static PARAM_BLOCK ModgDev = 
   { 1 
   , INTEGER_TYPE, 0, 20000, NULL
   };

static PARAM_BLOCK Units = 
   { 1 
   , INTEGER_TYPE, 0, 4, &FreqUnits
   };

static PARAM_BLOCK RfanFreq = 
   { 1
   , FLOAT_TYPE, 0.2, 2700, NULL
   };

static PARAM_BLOCK RfgFreq = 
   { 1
   , FLOAT_TYPE, 0.03, 2700, NULL
   };

static PARAM_BLOCK AfgFreq = 
   { 1
   , INTEGER_TYPE, 20, 20000, NULL
   };

static PARAM_BLOCK ModgFreq = 
   { 1
   , INTEGER_TYPE, 20, 15999, NULL
   };

static PARAM_BLOCK FreqOffset = 
   { 1 
   , FLOAT_TYPE, -15, 15, NULL
   };

static PARAM_BLOCK SCC = 
   { 1 
   , INTEGER_TYPE, 0, 2, NULL
   };

static PARAM_BLOCK EventReport = 
   { 1 
   , INTEGER_TYPE, 0, 3, &eventReport
   };

static PARAM_BLOCK ArrayType = 
   { 1 
   , INTEGER_TYPE, 0, 1, &arrays
   };

static PARAM_BLOCK CfgRep = 
   { 3
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };
static PARAM_BLOCK measureTime = 
   { 1
   , FLOAT_TYPE, 0.025, 1, NULL
   };

static PARAM_BLOCK DevType = 
   { 1
   , INTEGER_TYPE, 0, 1, &TargDevTyp
   };

static PARAM_BLOCK FilterNotch = 
   { 1
   , INTEGER_TYPE, 0, 1, &NotchFilter
   };

static PARAM_BLOCK Filter = 
   { 2
   , INTEGER_TYPE, 0, 17, &bandpass
   , INTEGER_TYPE, 0, 2,  &weighting
   };

static PARAM_BLOCK RxFilter = 
   { 2
   , INTEGER_TYPE, 0, 17, &bandpass
   , INTEGER_TYPE, 0, 2,  &weighting
   };

static PARAM_BLOCK TxModFilter = 
   { 4
   , INTEGER_TYPE, 0, 17, &bandpass
   , INTEGER_TYPE, 0, 1,  &enable
   , INTEGER_TYPE, 0, 1,  &enable
   , INTEGER_TYPE, 0, 2,  &weighting
   };

static PARAM_BLOCK TxFilter = 
   { 4
   , INTEGER_TYPE, 0, 17, &bandpass
   , INTEGER_TYPE, 0, 1,  &enable
   , INTEGER_TYPE, 0, 1,  &enable
   , INTEGER_TYPE, 0, 2,  &weighting
   };

static PARAM_BLOCK ClkMode = 
   { 1 
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK ClkFreq = 
   { 1 
   , INTEGER_TYPE, 0, 3, &ClkFreqMHz
   };

static PARAM_BLOCK TxModLimits = 
   { 8
   , INTEGER_TYPE, 0, 48000, NULL
   , INTEGER_TYPE, 0, 48000, NULL
   , FLOAT_TYPE,   0, 10000, NULL
   , INTEGER_TYPE, 0, 48000, NULL
   , FLOAT_TYPE,   0, 10000, NULL
   , INTEGER_TYPE, 0, 48000, NULL
   , FLOAT_TYPE,   0, 100,   NULL
   , FLOAT_TYPE,   0, 100,   NULL
   };

static PARAM_BLOCK TxHnLimits = 
   { 4
   , INTEGER_TYPE, 0, 48000, NULL
   , FLOAT_TYPE,   0, 10000, NULL
   , INTEGER_TYPE, 0, 48000, NULL
   , FLOAT_TYPE,   0, 100,   NULL
   };

static PARAM_BLOCK TxAflLimits = 
   { 1
   , INTEGER_TYPE, 0, 48000, NULL
   };

static PARAM_BLOCK AflDev = 
   { 1
   , INTEGER_TYPE, 0, 48000, NULL
   };

static PARAM_BLOCK TxafRefDev = 
   { 1
   , INTEGER_TYPE, 10, 20000, NULL
   };

static PARAM_BLOCK RxafRefLev = 
   { 1
   , FLOAT_TYPE, .001, 5, NULL
   };

static PARAM_BLOCK Scale = 
   { 2
   , FLOAT_TYPE, -150, 150, NULL
   , FLOAT_TYPE, -150, 150, NULL
   };

static PARAM_BLOCK TxafRefReq = 
   { 1
   , INTEGER_TYPE, 0, 20, &TxafRef
   };

static PARAM_BLOCK RxafRefReq = 
   { 1 
   , INTEGER_TYPE, 0, 20, &RxafRef
   };

static PARAM_BLOCK RxSensLimits = 
   { 3 
   , FLOAT_TYPE, 0,    30, NULL
   , FLOAT_TYPE, 0,    30, NULL
   , FLOAT_TYPE, -150, 0,  NULL
   };

static PARAM_BLOCK RxHnLimits = 
   { 3 
   , FLOAT_TYPE, 0,  30, NULL
   , FLOAT_TYPE, 0,  30, NULL
   , FLOAT_TYPE, 0, 100, NULL
   };


static PARAM_BLOCK RxafanLimits = 
   { 4 
   , FLOAT_TYPE, 0,    30, NULL
   , FLOAT_TYPE, 0,    30, NULL
   , FLOAT_TYPE, 0,   100, NULL
   , FLOAT_TYPE, -99, 100, NULL
   };

static PARAM_BLOCK TxTSinad = 
   { 1 
   , FLOAT_TYPE, -99, 200, NULL
   };

static PARAM_BLOCK TxTSERange = 
   { 1 
   , FLOAT_TYPE, 0, 100, NULL
   };

static PARAM_BLOCK LeadTime = 
   { 1 
   , FLOAT_TYPE, 0, 100.0, NULL
   };

static PARAM_BLOCK SigMac = 
   { 1 
   , INTEGER_TYPE, 0, 7, NULL
   };

static PARAM_BLOCK SigSatPeak = 
   { 1 
   , INTEGER_TYPE, 1, 20000, NULL
   };

static PARAM_BLOCK SigSatScc = 
   { 1
   , INTEGER_TYPE, 0, 2, NULL
   };

static PARAM_BLOCK SigChan = 
   { 1 
   , INTEGER_TYPE, 1, 1023, NULL
   };

static PARAM_BLOCK NetSID = 
   { 1 
   , INTEGER_TYPE, 0, 16383, NULL
   };

static PARAM_BLOCK NetDCC = 
   { 1 
   , INTEGER_TYPE, 0, 3, NULL
   };

static PARAM_BLOCK LossLink = 
   { 1 
   , INTEGER_TYPE, 1, 60, NULL
   };

static PARAM_BLOCK RegPeriod = 
   { 1 
   , INTEGER_TYPE, 0, 3600, NULL
   };

static PARAM_BLOCK SubMode = 
   { 2 
   , INTEGER_TYPE, 0, 3,  &Subarray
   , INTEGER_TYPE, 1, 32, NULL
   };

static PARAM_BLOCK LimitLines = 
   { 1 
   , INTEGER_TYPE, 0, 1, &LimitArea
   };

static PARAM_BLOCK TestTone = 
   { 4 
   , INTEGER_TYPE,   0,  1, &LimitArea
   , INTEGER_TYPE,   1, 20, NULL
   , FLOAT_TYPE,   -80, 80, NULL
   , INTEGER_TYPE,   0,  1, &enable
   };

static PARAM_BLOCK TdefTone = 
   { 4 
   , INTEGER_TYPE,  1,    20, NULL
   , INTEGER_TYPE, 10, 15999, NULL
   , FLOAT_TYPE,    0,     5, NULL
   , INTEGER_TYPE,  0,     1, &enable
   };

static PARAM_BLOCK Tone = 
   { 1 
   , INTEGER_TYPE, 1, 20, NULL
   };

static PARAM_BLOCK SignalAction = 
   { 1 
   , INTEGER_TYPE, 0, 6, &sigAction
   };

static PARAM_BLOCK sfbwFilter = 
   { 1 
   , INTEGER_TYPE, 0, 1, &BWFilter
   };
   
static PARAM_BLOCK cFactor = 
   { 1 
   , INTEGER_TYPE, 0, 1, &CRFactor
   };   
//*********************************************************************
// Rohde & Schwarz CMU Command Table for AMPS
//*********************************************************************

COMMAND_INFO AMPS[] =
{ 
  /* 000 */     "INP:STAT %s",                                                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &Input,       
                   NULL

  /* 001 */   , "OUTP:STAT %s",                                                                 
                   NULL,           
                   NULL,
                   NULL,       
                   &Output,       
                   NULL

  /* 002 */   , "SENS:CORR:LOSS:INP%s %lf",                                          
                   NULL,           
                   NULL,
                   NULL,       
                   &InpAtt,       
                   NULL

  /* 003 */   , "SOUR:CORR:LOSS:INP%s %lf",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &InpAtt,       
                   NULL

  /* 004 */   , "SENS:CORR:LOSS:OUTP%s %lf",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &OutpAtt,       
                   NULL

  /* 005 */   , "SOUR:CORR:LOSS:OUTP%s %lf",                                        
                   NULL,           
                   NULL,
                   NULL,       
                   &OutpAtt,       
                   NULL

  /* 006 */   , "SOUR:DM:CLOCK:STATE %s",                                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &ClkMode,       
                   NULL 
  
  /* 007 */   , "SOUR:DM:CLOCK:FREQ %s MHZ",
                   NULL,           
                   NULL,
                   NULL,       
                   &ClkFreq,       
                   NULL 

  /* 008 */   , "LEV:DEF %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL

  /* 009 */   , "LEV:MODE %s",                                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &InpMode,      
                   NULL

  /* 010 */   , "LEV:MAX %lf",                                                    
                   NULL,           
                   NULL,
                   NULL,       
                   &MaxLvl,      
                   NULL
  
  /* 011 */   , "LEV:ATT %s",                                                
                   NULL,           
                   NULL,
                   NULL,       
                   &AttLvl,      
                   NULL

  /* 012 */   , "AFL:MODE %s",                                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &InpMode,      
                   NULL
  
  /* 013 */   , "AFL:MAX %lf",                                                    
                   NULL,           
                   NULL,
                   NULL,       
                   &AFLvl,      
                   NULL

  /* 014 */   , "RFAN:FREQ:UNIT MHZ;:RFAN:FREQ %lf",                                     
                   NULL,           
                   NULL,
                   NULL,       
                   &RfanFreq,      
                   NULL

  /* 015 */   , "RFAN:FREQ:UNIT CH;:RFAN:FREQ %d",                                       
                   NULL,
                   NULL,
                   NULL,       
                   &SigChan,       
                   NULL

  /* 016 */   , "RFAN:FREQ:OFFS %lf KHZ",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqOffset,      
                   NULL

  /* 017 */   , "SOUR:SAT:SCC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SCC,      
                   NULL

  /* 018 */   , "SOUR:ST:DAT %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 019 */   , "SOUR:AFG:LEVEL %lf",                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &Afglvl,       
                   NULL
  
  /* 020 */   , "SOUR:AFG:FREQ %d HZ",                                   
                   NULL,           
                   NULL,
                   NULL,       
                   &AfgFreq,       
                   NULL

  /* 021 */   , "AFL:DEF %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL

  /* 022 */   , "CONF:BSS:OCH:SAT:PEAK %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &PeakDev,      
                   NULL

  /* 023 */   , "SOUR:MODG:DEVIATION %d HZ",                                   
                   NULL,           
                   NULL,
                   NULL,       
                   &ModgDev,       
                   NULL
 
  /* 024 */   , "SOUR:MODG:FREQ %d HZ",                                   
                   NULL,           
                   NULL,
                   NULL,       
                   &ModgFreq,       
                   NULL
  
  /* 025 */   , "CONF:BSS:OCH:SAT:SCC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigSatScc,      
                   NULL

  /* 026 */   , "SOUR:RFG:LEVEL %lf",                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &RFlvl,       
                   NULL

  /* 027 */   , "SOUR:RFG:FREQ:UNIT MHZ;:SOUR:RFG:FREQ %lf",                                   
                   NULL,           
                   NULL,
                   NULL,       
                   &RfgFreq,       
                   NULL

  /* 028 */   , "SOUR:RFG:FREQ:UNIT CH;:SOUR:RFG:FREQ %d",                                       
                   NULL,
                   NULL,
                   NULL,       
                   &SigChan,       
                   NULL

  /* 029 */   , "SOUR:RFG:FREQ:OFFS %lf KHZ",                                    
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqOffset,       
                   NULL

  /* 030 */   , "SOUR:SAT:PEAKDEV %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &PeakDev,      
                   NULL

  /* 031 */   , "SOUR:ST:PEAKDEV %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &PeakDev,      
                   NULL
                  
 /* 032 */   , "CONF:NETW:OCH:VMAC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigMac,      
                   NULL

  /* 033 */   , "INIT:AFG",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 034 */   , "INIT:MODG",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 035 */   , "INIT:RFG",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 036 */   , "INIT:SAT",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 037 */   , "INIT:ST",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 038 */   , "INIT:RXAF",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 039 */   , "INIT:RXT:AFAN",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 040 */   , "INIT:RXT:HNO",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 041 */   , "INIT:RXT:SENS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 042 */   , "INIT:TXAF",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 043 */   , "INIT:TXT:MOD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 044 */   , "INIT:TXT:HNO",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 045 */   , "INIT:TXT:AFLS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 046 */   , "ABOR:AFG",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 047 */   , "ABOR:MODG",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 048 */   , "ABOR:RFG",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 049 */   , "ABOR:SAT",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 050 */   , "ABOR:ST",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 051 */   , "ABOR:RXAF",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 052 */   , "ABOR:RXT:AFAN",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 053 */   , "ABOR:RXT:HNO",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 054 */   , "ABOR:RXT:SENS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 055 */   , "ABOR:TXAF",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 056 */   , "ABOR:TXT:MOD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 057 */   , "ABOR:TXT:HNO",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 058 */   , "ABOR:TXT:AFLS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 059 */   , "FETC:AFG:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 060 */   , "FETC:MODG:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 061 */   , "FETC:RFG:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 062 */   , "FETC:SAT:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 063 */   , "FETC:ST:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 064 */   , "STOP:RXAF",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 065 */   , "STOP:RXT:AFAN",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 066 */   , "STOP:RXT:HNO",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 067 */   , "STOP:RXT:SENS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 068 */   , "STOP:TXAF",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 069 */   , "STOP:TXT:MOD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 070 */   , "STOP:TXT:HNO",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 071 */   , "STOP:TXT:AFLS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 072 */   , "CONT:RXAF",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 073 */   , "CONT:RXT:AFAN",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 074 */   , "CONT:RXT:HNO",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 075 */   , "CONT:RXT:SENS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 076 */   , "CONT:TXAF",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 077 */   , "CONT:TXT:MOD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 078 */   , "CONT:TXT:HNO",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 079 */   , "CONT:TXT:AFLS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 080 */   , "CONF:RXAF:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
                   
  /* 081 */   , "CONF:RXAF:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 082 */   , "CONF:RXAF:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 

  /* 083 */   , "CONF:RXAF:CONT:MGL %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &LeadTime,      
                   NULL

  /* 084 */   , "CONF:RXAF:LIM:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 085 */   , "CONF:RXAF:LIM:%s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &LimitLines,      
                   NULL

  /* 086 */   , "CONF:RXAF:LIM:%s:TONE%d %lf, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TestTone,      
                   NULL

  /* 087 */   , "CONF:RXAF:TDEF",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 088 */   , "CONF:RXAF:TDEF:TONE%d %d,%d,%s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &TdefTone,      
                   NULL

  /* 089 */   , "CONF:RXAF:TDEF:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 090 */   , "CONF:RXAF:FILT %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Filter,      
                   NULL

  /* 091 */   , "CONF:RXAF:FILT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 092 */   , "CONF:SUB:RXAF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SubMode,      
                   NULL

  /* 093 */   , "CONF:RXT:AFAN:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
                   
  /* 094 */   , "CONF:RXT:AFAN:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 095 */   , "CONF:RXT:AFAN:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 

  /* 096 */   , "CONF:RXT:AFAN:LIM %lf, %lf, %lf, %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RxafanLimits,      
                   NULL

  /* 097 */   , "CONF:RXT:AFAN:LIM:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 098 */   , "CONF:RXT:AFAN:FILT %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RxFilter,      
                   NULL

  /* 099 */   , "CONF:RXT:AFAN:FILT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 100 */   , "CONF:TXAF:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
                   
  /* 101 */   , "CONF:TXAF:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 102 */   , "CONF:TXAF:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 

  /* 103 */   , "CONF:TXAF:CONT:AFGLEAD %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &LeadTime,      
                   NULL

  /* 104 */   , "DISP:TXAF:TRAC:Y:SCAL %lf, %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Scale,      
                   NULL

  /* 105 */   , "CONF:TXAF:CONT:RREQ %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TxafRefReq,      
                   NULL

  /* 106 */   , "CONF:TXAF:CONT:RDEV %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TxafRefDev,      
                   NULL

  /* 107 */   , "CONF:TXAF:LIM:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 108 */   , "CONF:TXAF:LIM:%s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &LimitLines,      
                   NULL

  /* 109 */   , "CONF:TXAF:LIM:%s:TONE%d %lf, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TestTone,      
                   NULL

  /* 110 */   , "CALC:TXAF:MATC:LIM:TONE%d?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Tone,      
                   NULL

  /* 111 */   , "CONF:TXAF:TDEF:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 112 */   , "READ:TXAF:TONE%d?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Tone,      
                   NULL 

  /* 113 */   , "CONF:SUB:TXAF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SubMode,      
                   NULL

  /* 114 */   , "CONF:TXAF:FILT %s, %s, %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TxFilter,      
                   NULL

  /* 115 */   , "CONF:TXAF:FILT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 116 */   , "CONF:TXT:MOD:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
                   
  /* 117 */   , "CONF:TXT:MOD:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 

  /* 118 */   , "CONF:TXT:MOD:LIM %d, %d, %lf, %d, %lf, %d, %lf, %lf",        
                   NULL,           
                   NULL,
                   NULL,       
                   &TxModLimits,       
                   NULL 

  /* 119 */   , "CONF:TXT:MOD:LIM:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 120 */   , "CONF:TXT:MOD:FILT %s, %s, %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TxModFilter,      
                   NULL

  /* 121 */   , "CONF:TXT:MOD:FILT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 122 */   , "DISPLAY:RXAF:WINDOW:TRACE:Y:SCALE %lf DBM, %lf DBM",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 123 */   , "DISPLAY:RXAF:CONT:GRID %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 124 */   , "DISPLAY:TXAF:CONT:GRID %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 125 */   , "FETC:RXAF:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 126 */   , "FETC:RXAF:TONE%d?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Tone,      
                   NULL 
                   
  /* 127 */   , "READ:RXAF:TONE%d?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Tone,      
                   NULL 

  /* 128 */   , "SAMPLE:RXAF:TONE%d?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Tone,      
                   NULL 

  /* 129 */   , "SAMP:TXAF:TONE%d?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Tone,      
                   NULL 

  /* 130 */   , "CALC:RXAF:MATC:LIM:TONE%d?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Tone,      
                   NULL 

  /* 131 */   , "PROC:BSS:AVC:LEV %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RFlvl,      
                   NULL
  
  /* 132 */   , "FETC:TXAF:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 133 */   , "FETC:TXAF:TONE%d?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Tone,      
                   NULL 

  /* 134 */   , "FETC:RXT:AFAN:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 135 */   , "FETC:RXT:AFAN?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 136 */   , "READ:RXT:AFAN?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 137 */   , "SAMP:RXT:AFAN?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 138 */   , "CALC:RXT:AFAN:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 139 */   , "FETC:TXT:MOD:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 140 */   , "FETC:TXT:MOD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 141 */   , "READ:TXT:MOD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 142 */   , "SAMPLE:TXT:MOD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 143 */   , "CALC:TXT:MOD:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 144 */   , "CONF:TXT:HNO:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
                   
  /* 145 */   , "CONF:TXT:HNO:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 

  /* 146 */   , "CONF:TXT:HNO:LIM %d, %d, %d, %lf",        
                   NULL,           
                   NULL,
                   NULL,       
                   &TxHnLimits,       
                   NULL 

  /* 147 */   , "CONF:TXT:HNO:LIM:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 148 */   , "CONF:TXT:HNO:FILT %s, %s, %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TxFilter,      
                   NULL

  /* 149 */   , "CONF:TXT:HNO:FILT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 150 */   , "CONF:TXT:AFLS:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
                   
  /* 151 */   , "PROC:SIGN:ACT %s",
                   NULL,
                   NULL,
                   NULL,
                   &SignalAction,
                   NULL

  /* 152 */   , "CONF:TXT:AFLS:LIM %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &TxAflLimits,       
                   NULL 

  /* 153 */   , "CONF:TXT:AFLS:LIM:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 154 */   , "CONF:TXT:AFLS:FILT %s, %s, %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TxFilter,      
                   NULL

  /* 155 */   , "CONF:TXT:AFLS:FILT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 156 */   , "CONF:TXT:MOD:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 157 */   , "CONF:TXT:HNO:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 158 */   , "CONF:TXT:AFLS:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 159 */   , "FETC:TXT:HNO:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 160 */   , "FETC:TXT:AFLS:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 161 */   , "CONF:TXT:AFLS:CONT:TAPD %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &AflDev,      
                   NULL

  /* 162 */   , "CONF:TXT:AFLS:CONT:TDER %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &AflDev,      
                   NULL

  /* 163 */   , "CONF:RXT:AFAN:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
                   
  /* 164 */   , "CONF:RXT:HNO:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 165 */   , "CONF:RXT:HNO:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 

  /* 166 */   , "CONF:RXT:HNO:LIM %lf, %lf, %lf",                                        
                   NULL,           
                   NULL,
                   NULL,       
                   &RxHnLimits,      
                   NULL

  /* 167 */   , "CONF:RXT:HNO:LIM:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 168 */   , "CONF:RXT:HNO:FILT %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Filter,      
                   NULL

  /* 169 */   , "CONF:RXT:HNO:FILT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 170 */   , "CONF:RXT:SENS:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
                   
  /* 171 */   , "CONF:RXT:SENS:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 172 */   , "SIGN:STAT?",                
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 

  /* 173 */   , "CONF:RXT:SENS:LIM %lf, %lf, %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RxSensLimits,      
                   NULL

  /* 174 */   , "CONF:RXT:SENS:LIM:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 175 */   , "CONF:RXT:SENS:FILT %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Filter,      
                   NULL

  /* 176 */   , "CONF:RXT:SENS:FILT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 177 */   , "FETC:RXT:HNO:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 178 */   , "FETC:RXT:SENS:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 179 */   , "CONF:RXT:SENS:CONT:TSIN %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &TxTSinad,      
                   NULL 

  /* 180 */   , "CONF:RXT:SENS:CONT:TSER %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &TxTSERange,      
                   NULL 

  /* 181 */   , "DISP:RXAF:TRAC:Y:SCAL %lf, %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Scale,      
                   NULL

  /* 182 */   , "CONF:RXAF:CONT:RREQ %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RxafRefReq,      
                   NULL

  /* 183 */   , "CONF:RXAF:CONT:RLEV %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RxafRefLev,      
                   NULL

  /* 184 */   , "UNIT:CHAN %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Units,      
                   NULL

  /* 185 */   , "PROC:SIGN:MAC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigMac,      
                   NULL

  /* 186 */   , "PROC:SIGN:SAT:PEAK %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigSatPeak,      
                   NULL

  /* 187 */   , "PROC:SIGN:SAT:SCC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigSatScc,      
                   NULL

  /* 188 */   , "PROC:SIGN:CHAN %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigChan,      
                   NULL

  /* 189 */   , "CONF:BSS:ACC:CHAN %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigChan,      
                   NULL

  /* 190 */   , "CONF:BSS:ACC:LEV %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RFlvl,      
                   NULL

  /* 191 */   , "CONF:BSS:AVC:CHAN %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigChan,      
                   NULL

  /* 192 */   , "CONF:BSS:AVC:LEV %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RFlvl,      
                   NULL

  /* 194 */   , "CONF:BSS:SAT:PEAK %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &PeakDev,      
                   NULL

  /* 194 */   , "CONF:BSS:SAT:SCC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigSatScc,      
                   NULL

  /* 195 */   , "CONF:NETW:IDEN:SID1 %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &NetSID,      
                   NULL

  /* 196 */   , "CONF:NETW:IDEN:DCC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &NetDCC,      
                   NULL

  /* 197 */   , "CONF:NETW:SMOD:REGH %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 198 */   , "CONF:NETW:SMOD:REGR %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 199 */   , "CONF:NETW:SMOD:IDM %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 200 */   , "CONF:NETW:REQ:SNUM %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 201 */   , "CONF:NETW:CMAC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigMac,      
                   NULL

  /* 202 */   , "CONF:NETW:VMAC %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigMac,      
                   NULL

  /* 203 */   , "CONF:NETW:RCFM %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL

  /* 204 */   , "CONF:NETW:TIM:LORLINK %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &LossLink,      
                   NULL

  /* 205 */   , "CONF:NETW:TIM:RPER %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &RegPeriod,      
                   NULL

  /* 206 */   , "MSS:MIN?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 207 */   , "MSS:SN?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 208 */   , "MSS:PCL?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 209 */   , "MSS:BAND?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 210 */   , "MSS:MPCI?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 211 */   , "MSS:DNUM?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 212 */   , "INIT:WPOW",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 213 */   , "ABOR:WPOW",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 214 */   , "STOP:WPOW",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 215 */   , "CONT:WPOW",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 216 */   , "CONF:WPOW:EREP %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,      
                   NULL

  /* 217 */   , "FETC:WPOW:STAT?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 218 */   , "CONF:WPOW:CONT:REP %s, %s, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,      
                   NULL

  /* 219 */   , "READ:WPOW?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 220 */   , "FETC:WPOW?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 221 */   , "SAMP:WPOW?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 222 */   , "FETC:TXT:HNO?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 223 */   , "READ:TXT:HNO?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 224 */   , "SAMPLE:TXT:HNO?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 225 */   , "CALC:TXT:HNO:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 226 */   , "FETC:TXT:AFLS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 227 */   , "READ:TXT:AFLS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 228 */   , "SAMPLE:TXT:AFLS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 229 */   , "CALC:TXT:AFLS:MATC?",  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 230 */   , "CONF:TXAF:TDEF",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 231 */   , "CONF:TXAF:TDEF:TONE%d %d, %lf, %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &TdefTone,      
                   NULL

  /* 232 */   , "READ:ARR:TXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 233 */   , "FETC:ARR:TXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 234 */   , "SAMP:ARR:TXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 235 */   , "READ:SUB:TXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 236 */   , "FETC:SUB:TXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 237 */   , "SAMP:SUB:TXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 238 */   , "READ:ARR:RXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 239 */   , "FETC:ARR:RXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 240 */   , "SAMP:ARR:RXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 241 */   , "READ:SUB:RXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 242 */   , "FETC:SUB:RXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 243 */   , "SAMP:SUB:RXAF?",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 244 */   , "FETC:RXT:HNO?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 245 */   , "READ:RXT:HNO?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 246 */   , "SAMP:RXT:HNO?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 247 */   , "CALC:RXT:HNO:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 248 */   , "FETC:RXT:SENS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 249 */   , "READ:RXT:SENS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 250 */   , "SAMP:RXT:SENS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 251 */   , "CALC:RXT:SENS:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 

  /* 252 */   , "CONF:HAND:TARGET %s",                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 

  /* 253 */   , "CONF:BSS:OCH:AVC:CHAN %d",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SigChan,      
                   NULL

  /* 254 */   , "CONF:BSS:OCH:AVC:LEV %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &RFlvl,      
                   NULL

  /* 255 */   , "CONF:BSS:OCH:SAT:PEAK %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &PeakDev,      
                   NULL

  /* 256 */   , "CONF:BSS:OCH:SAT:SCC %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigSatScc,      
                   NULL

  /* 257 */   , "CONF:NETW:OCH:VMAC %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigMac,      
                   NULL

  /* 258 */   , "PROC:BSS:AVC:LEV %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &RFlvl,      
                   NULL

  /* 259 */   , "READ:RXT:AFAN:VMS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 260 */   , "FETC:RXT:AFAN:VMS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 261 */   , "SAMP:RXT:AFAN:VMS?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 262 */   , "CALC:RXT:AFAN:VMS:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL

  /* 263 */   , "CONF:RXT:AFAN:VMS:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 

  /* 264 */   , "CONF:RXT:AFAN:VMS:CONT:MTIM %lf",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &measureTime,      
                   NULL
                   
  /* 265 */   , "CONF:RXT:AFAN:VMS:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL
  /* 266 */, "INIT:TXT:MOD:TAD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 267 */, "ABOR:TXT:MOD:TAD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 268 */, "STOP:TXT:MOD:TAD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 269 */, "CONT:TXT:MOD:TAD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 270 */, "CONF:TXT:MOD:TAD:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
  /* 271 */, "FETC:TXT:MOD:TAD:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 272 */, "CONF:TXT:MOD:TAD:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 
  /* 273 */, "CONF:TXT:MOD:TAD:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL
  /* 274 */, "READ:TXT:MOD:TAD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 275 */, "FETC:TXT:MOD:TAD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 276 */, "SAMPLE:TXT:MOD:TAD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 277 */, "CALC:TXT:MOD:TAD:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 278 */, "INIT:TXT:MOD:CPOW",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 279 */, "ABOR:TXT:MOD:CPOW",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 280 */, "STOP:TXT:MOD:CPOW",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 281 */, "CONT:TXT:MOD:CPOW",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 282 */, "CONF:TXT:MOD:CPOW:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
  /* 283 */, "FETC:TXT:MOD:CPOW:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 284 */, "CONF:TXT:MOD:CPOW:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 
  /* 285 */, "CONF:TXT:MOD:CPOW:CONT:DEF %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL
  /* 286 */, "READ:TXT:MOD:CPOW?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 287 */, "FETC:TXT:MOD:CPOW?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 288 */, "SAMPLE:TXT:MOD:CPOW?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 289 */, "CALC:TXT:MOD:CPOW:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 290 */, "INIT:RXT:AFAN:VMS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 291 */, "ABOR:RXT:AFAN:VMS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 292 */, "STOP:RXT:AFAN:VMS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 293 */, "CONT:RXT:AFAN:VMS",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 294 */, "FETC:RXT:AFAN:VMS:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 295 */   , "CONF:RXT:AFAN:VMS:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
  /* 296 */   , "SOUR:AFG:SLEV %lf",                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &Afglvl,       
                   NULL
  /* 297 */   , "AFC:MSOurce %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ModExt,       
                   NULL 
  /* 298 */   , "CONF:TXAF:AFG:LEV:LMOD %s",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 299 */   , "CONF:TXAF:AFG:LEV:TLEV %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &Afglvl,       
                   NULL 
  /* 300 */   , "SYST:RES:CURR",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 301 */  , "STAT:OPER:SYMB:ENAB %s",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 302 */  , "STAT:OPER:SYMB?;*CLS",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 303 */  , "CONF:RXAF:MODG:FDEV:FDM %s",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 304 */  , "CONF:RXAF:MODG:FDEV:TFD %d",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 305 */  , "CALC:ARR:RXAF:MATChing:LIM?", 
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 306 */  , "CONF:RXT:AFAN:FILT:NOTC %s", 
                   NULL,           
                   NULL,
                   NULL,       
                   &FilterNotch,       
                   NULL 
  /* 307 */  , "CONF:RXT:SENS:FILT:NOTC %s", 
                   NULL,           
                   NULL,
                   NULL,       
                   &FilterNotch,       
                   NULL 
  /* 308 */, "CONF:SDS:ENABle %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL
  /* 309 */  , "CONF:TXT:AFLS:TDType %s", 
                   NULL,           
                   NULL,
                   NULL,       
                   &DevType,       
                   NULL 
  /* 310 */, "CONF:TXT:WBD:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 
  /* 311 */, "DEF:TXT:WBD:CONT DEF",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL
  /* 312 */, "CONF:TXT:WBD:LIM %d HZ",
                   NULL,           
                   NULL,
                   NULL,       
                   &TxAflLimits,       
                   NULL 
  /* 313 */, "CONF:TXT:WBD:LIM %s",                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &limitdef,      
                   NULL
  /* 314 */, "INIT:TXT:WBD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 315 */, "ABOR:TXT:WBD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 316 */, "STOP:TXT:WBD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 317 */, "CONT:TXT:WBD",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL                    
  /* 318 */, "FETC:TXT:WBD:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 319 */, "CONF:TXT:WBD:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
  /* 320 */, "READ:TXT:WBD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 321 */, "FETC:TXT:WBD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 322 */, "SAMPLE:TXT:WBD?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 323 */, "CALC:TXT:WBD:RES:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,      
                   NULL 
  /* 324 */  , "CONF:TXT:AFLS:CONT:PCOM %s", 
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL 
  /* 325 */  , "CONF:TXT:MOD:FILT:SFBW %s", 
                   NULL,           
                   NULL,
                   NULL,       
                   &sfbwFilter,       
                   NULL                    
  /* 326 */  , "CONF:TXT:HNO:FILT:SFBW %s", 
                   NULL,           
                   NULL,
                   NULL,       
                   &sfbwFilter,       
                   NULL 
                                       
  /* 327 */  , "CONF:TXAF:AFG:LEV:CFAC %s", 
                   NULL,           
                   NULL,
                   NULL,       
                   &cFactor,       
                   NULL       
  /* 328 */  , "CONF:RXAF:MODG:FDEV:CFAC %s", 
                   NULL,           
                   NULL,
                   NULL,       
                   &cFactor,       
                   NULL                       
};

static ViInt16 NUM_CMDS = ( sizeof( AMPS ) / sizeof( COMMAND_INFO ) );

/**************************************************************************
 *
 * NAME:        RSCMU_Init_AMPS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC
   RSCMU_Init_AMPS( ViSession  instrSessionBase
                  , ViSession *instrSession
                  , ViInt32    AMPSFunctionGroup
                  , ViChar     errorMessage[]
                  )
{
   ViStatus    RSCMU_Status                  = VI_SUCCESS;  
   ViSession   globalSession                 = 0;
   ViInt32     secondAddr                    = RSCMU_SECONDARY_ADDRESS_INVALID;
   ViInt32     comp                          = 1; 
   ViInt32     firstFreeSecAddr              = RSCMU_SECONDARY_ADDRESS_INVALID;
   ViChar      FctGrpBuffer[MAX_BUFFER_SIZE] = "";
   ViChar      resource[25]                  = "";
   ViBoolean   Flag                          = RSCMU_OFF;
   ViSession   DefaultRM;
  
   struct RSCMU_Base_Globals  *p_globalvarBase;
   struct RSCMU_AMPS_Globals  *p_globalvarAMPS;

    /* --- Set standard "C" locale --- */
    {
        char *locale;

        locale = setlocale(LC_ALL, "C");
    }

   // Get a copy of the global data for this session.
   if( (RSCMU_Status = viGetAttribute( instrSessionBase
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarBase
                                     )) < 0 )
   {
      return RSCMU_errorMessage( instrSessionBase, RSCMU_Status, errorMessage );
   }
   DefaultRM = p_globalvarBase->RSCMU_tGlobal.RSCMU_RmSessionDefault;

   // Verify that the VISA Resource Manager has been opened.
   if( DefaultRM != 0 )
   {
      // Which Function Group does the User want?
      switch( AMPSFunctionGroup )
      {
      case RSCMU_AMPSMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"AMPSMS_NSig\"" );         
         break;

      case RSCMU_AMPSMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"AMPSMS_Sig\"" );
         break;

      default:
         break;
      }

      // Init the Error Message  
      strcpy( errorMessage, "No Error" );

      // Find the Secondary address
      while( (comp != 0) && (secondAddr <= RSCMU_SECONDARY_ADDRESS_MAX) )
      {
         secondAddr++;
         comp = strncmp( p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp
                       , FctGrpBuffer
                       , strlen(FctGrpBuffer)
                       );
         if( comp == 0 ) 
         {
            Flag = RSCMU_ON;
         }   
         else
         {
            ViInt32 comp1;
            comp1 = strncmp( p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp
                           , "NONE"
                           , 4
                           );  
            if( (comp1 == 0) && 
                (firstFreeSecAddr == RSCMU_SECONDARY_ADDRESS_INVALID)
              )
            {
               firstFreeSecAddr = secondAddr;
            }  
         }
      }
      
      if( Flag == RSCMU_OFF )
      {
         if( (RSCMU_Status = RSCMU_Base_SystRemAddrSec( instrSessionBase
                                                      , firstFreeSecAddr
                                                      , AMPSFunctionGroup
                                                      , errorMessage
                                                      )) < 0 )
         {
            return RSCMU_Base_errorMessage( instrSessionBase
                                          , RSCMU_ERROR_INVALID_FCT_GRP
                                          , errorMessage
                                          );
         }
         Flag       = RSCMU_ON;     
         secondAddr = firstFreeSecAddr;
      }
      
      // Hardware Connection
      if( strncmp( "GPIB"
                 ,p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                 , 4
                 ) == 0 )
      {
         sprintf( resource
                , "%s::%d::%d::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address
                , secondAddr
                );
      }
      else
      {
         sprintf( resource
                , "%s::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                );
      }
       
      // Open instrument session 
      if( (RSCMU_Status = viOpen( DefaultRM
                                , resource
                                , VI_NULL
                                , RSCMU_TMO_VALUE
                                , instrSession
                                )) < 0 )
      {
         if( (RSCMU_Status = viClose( DefaultRM )) < 0 )
         {
            return( RSCMU_Status );
         }
      }

      // Allocate space for "struct RSCMU_SESSION_Globals" 
      if( (p_globalvarAMPS =
            (struct RSCMU_AMPS_Globals *)
            malloc(sizeof(struct RSCMU_AMPS_Globals))) == 0 )
      {
         return RSCMU_initCleanUp( DefaultRM
                                 , *instrSession
                                 , RSCMU_Status
                                 );
      }
       
      // Which Function Group does the User want?
      switch( AMPSFunctionGroup )
      {
      case RSCMU_AMPSMS_NSIG:
         // No "HandOverName" for this group
         break;

      case RSCMU_AMPSMS_SIG:
         // Record the "HandOverName" for the actual Session.
         strcpy( p_globalvarAMPS->RSCMU_tHandOver.HandOverSessionName
               , "\"AMPSMS\""
               );
         break;

      default:
         break;
      }

      if( (RSCMU_Status = viSetAttribute( *instrSession
                                        , VI_ATTR_USER_DATA
                                        , (ViAttrState)p_globalvarAMPS
                                        )) < 0 )
      {
         return RSCMU_initCleanUp( DefaultRM
                                 , *instrSession
                                 , RSCMU_Status
                                 );
      }

      // Set initial values of variables for function Group 'AMPS' .    
      strcpy( p_globalvarAMPS->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer );
      strcpy( p_globalvarAMPS->RSCMU_tGlobal.RSCMU_SCPIConnection,      p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection );
      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_primary_address          =   p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;
      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_secondary_address        =   secondAddr;
      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_SessionNb                =   *instrSession;
      
      // Copy CMU FW
      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_FW_Version               =   p_globalvarBase->RSCMU_tGlobal.RSCMU_FW_Version;
      strcpy (p_globalvarAMPS->RSCMU_tGlobal.CmuVersion,                p_globalvarBase->RSCMU_tGlobal.CmuVersion);
      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_Type                     =   p_globalvarBase->RSCMU_tGlobal.RSCMU_Type;

      strcpy (p_globalvarAMPS->RSCMU_tGlobal.DrvVersion,                RSCMUK2A_REVISION);
      
      // If the RSCMU_Trace_ON has already been executed, record the characteristics of
      // the trace file, then the base can trace what's happening on the secondary address
      // initialized in THIS function.
      // NOTE:
      // It was not the case before: we were obliged to set the trace to ON 
      // after, and only after initialization of All the secondary addresses
      // we want to trace.

      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_TRACE                    =   p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_FileHandle               =   p_globalvarBase->RSCMU_tGlobal.RSCMU_FileHandle;
      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_AddrTargetFile           =  (ViAddr) p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;
      p_globalvarAMPS->RSCMU_tGlobal.RSCMU_StateTraceFile           =   p_globalvarBase->RSCMU_tGlobal.RSCMU_StateTraceFile;
   
      // Record the execution of this Init Function.    
      p_globalvarBase->RSCMU_tSecAddr[secondAddr].SessionNb         =   *instrSession;  
  
      // Timeout set to RSCMU_TMO_VALUE seconds
      if( (RSCMU_Status = viSetAttribute( *instrSession , VI_ATTR_TMO_VALUE, RSCMU_TMO_VALUE)) < 0 )
      {
         return( RSCMU_Status );
      }
      
      
      
   }
   else
   {
      RSCMU_Status = -1;
   }
   
   return( RSCMU_Status );

} // endof RSCMU_Init_AMPS()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InpState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession              -
 *              ViInt32   selectionOfInputConnector -
 *
 * OUTPUTS:     ViChar    errorMessage[]            -
 *
 * RETURN:      ViStatus  RSCMU_Status              -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InpState( ViSession instrSession
                      , ViInt32   selectionOfInputConnector
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( INP_STATE, &selectionOfInputConnector );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[INP_STATE].instrCommand
          , inpConn.list[selectionOfInputConnector]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_InpState()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_OutpState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession              -
 *              ViInt32   selectionOfInputConnector -
 *
 * OUTPUTS:     ViChar    errorMessage[]            -
 *
 * RETURN:      ViStatus  RSCMU_Status              -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_OutpState( ViSession instrSession
                       , ViInt32   selectionOfOutputConnector
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( OUTP_STATE, &selectionOfOutputConnector );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[OUTP_STATE].instrCommand
          , outpConn.list[selectionOfOutputConnector]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_OutpState()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseCorrLossInp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession              -
 *              ViInt32   selectionOfInputConnector -
 *              ViReal64  externalAttenuationdB     -
 *
 * OUTPUTS:     ViChar    errorMessage[]            -
 *
 * RETURN:      ViStatus  RSCMU_Status              -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseCorrLossInp( ViSession instrSession
                              , ViInt32   selectionOfInputConnector
                              , ViReal64  externalAttenuationdB
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SENSE_INP_CORR, &selectionOfInputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SENSE_INP_CORR].instrCommand
          , inpSrc.list[selectionOfInputConnector]          
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseCorrLossInp()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceCorrLossInp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession              -
 *              ViInt32   selectionOfInputConnector -
 *              ViReal64  externalAttenuationdB     -
 *
 * OUTPUTS:     ViChar    errorMessage[]            -
 *
 * RETURN:      ViStatus  RSCMU_Status              -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceCorrLossInp( ViSession instrSession
                               , ViInt32   selectionOfInputConnector
                               , ViReal64  externalAttenuationdB
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SRC_INP_CORR, &selectionOfInputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SRC_INP_CORR].instrCommand
          , inpSrc.list[selectionOfInputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceCorrLossInp()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseCorrLossOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession              -
 *              ViInt32   selectionOfInputConnector -
 *              ViReal64  externalAttenuationdB     -
 *
 * OUTPUTS:     ViChar    errorMessage[]            -
 *
 * RETURN:      ViStatus  RSCMU_Status              -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseCorrLossOutp( ViSession instrSession
                               , ViInt32   selectionOfOutputConnector
                               , ViReal64  externalAttenuationdB
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SENSE_OUTP_CORR, &selectionOfOutputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SENSE_OUTP_CORR].instrCommand
          , outpSrc.list[selectionOfOutputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseCorrLossOutp()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceCorrLossOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession              -
 *              ViInt32   selectionOfInputConnector -
 *              ViReal64  externalAttenuationdB     -
 *
 * OUTPUTS:     ViChar    errorMessage[]            -
 *
 * RETURN:      ViStatus  RSCMU_Status              -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceCorrLossOutp( ViSession instrSession
                                , ViInt32   selectionOfOutputConnector
                                , ViReal64  externalAttenuationdB
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SRC_OUTP_CORR, &selectionOfOutputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SRC_OUTP_CORR].instrCommand
          , outpSrc.list[selectionOfOutputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceCorrLossOutp()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CorrLossInpOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_CorrLossInpOutp (ViSession instrumentHandle,
                                                ViInt32 selection_ofOutputConnector,
                                                ViReal64 Output_Attenuation_dB,
                                                ViInt32 selection_ofInputConnector,
                                                ViReal64 Input_Attenuation_dB,
                                                ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status   = VI_SUCCESS; 
   ViChar    Format[80]     = "\0"; // JMG {NULL};
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   
   checkRange( SRC_OUTP_CORR,   &selection_ofOutputConnector,   &Output_Attenuation_dB );
   checkRange( SENSE_INP_CORR,  &selection_ofInputConnector,    &Input_Attenuation_dB );
   
   getBuffers( instrumentHandle
                 , &wrtBuf
                 , &rdBuf
                 , errorMessage
                 );
                                 
   
   strcpy(Format,AMPS[SRC_OUTP_CORR].instrCommand );
   strcat(Format,";:\0");
   strcat(Format,AMPS[SENSE_INP_CORR].instrCommand);
   strcat(Format,"\0");
   
   sprintf( wrtBuf
                  , Format
                  , outpSrc.list[selection_ofOutputConnector]
                  , Output_Attenuation_dB
                  , inpSrc.list[selection_ofInputConnector]
                  , Input_Attenuation_dB
                  
                  );

   
     
   
   RSCMU_Status = RSCMU_Query( instrumentHandle
                 , wrtBuf
                 , rdBuf
                 , RSCMU_STB_ON
                 , errorMessage
                 );

   return( RSCMU_Status );


}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceDmClockState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession           -
 *              ViBoolean referenceFreqAtREFOUT2 -
 *              ViReal64  externalAttenuationdB  -
 *
 * OUTPUTS:     ViChar    errorMessage[]         -
 *
 * RETURN:      ViStatus  RSCMU_Status           -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceDmClockState( ViSession instrSession
                                , ViBoolean referenceFreqAtREFOUT2
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( DM_CLK_STATE, &referenceFreqAtREFOUT2 );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[DM_CLK_STATE].instrCommand
          , enable.list[referenceFreqAtREFOUT2]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceDmClockState()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceDmClockFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession          -
 *              ViInt32   referenceFrequencyMHz -
 *
 * OUTPUTS:     ViChar    errorMessage[]        -
 *
 * RETURN:      ViStatus  RSCMU_Status          -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceDmClockFreq( ViSession instrSession
                               , ViInt32   referenceFrequencyMHz
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( DM_CLK_FREQ, &referenceFrequencyMHz );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[DM_CLK_FREQ].instrCommand
          , ClkFreqMHz.list[referenceFrequencyMHz]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceDmClockFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseLevModeRF
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseLevModeRF( ViSession instrSession
                            , ViInt32   inputLevelSetting
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( LEV_MODE_RF, &inputLevelSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[LEV_MODE_RF].instrCommand
          , mode.list[inputLevelSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}
 // endof RSCMU_AMPS_SenseLevModeRF()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseLevMaxRF
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseLevMaxRF( ViSession instrSession
                           , ViReal64  inputLevelMaximumdBm
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( LEV_MAX_RF, &inputLevelMaximumdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[LEV_MAX_RF].instrCommand
          , inputLevelMaximumdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseLevMaxRF()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseLevDefaultRF
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseLevDefaultRF( ViSession instrSession
                               , ViBoolean enabled
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( SENS_LEV_RF_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SENS_LEV_RF_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseLevDefaultRF()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseLevAttRF
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseLevAttRF( ViSession instrSession
                           , ViInt32   inputLevelAttenuation
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( LEV_ATT_RF, &inputLevelAttenuation );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[LEV_ATT_RF].instrCommand
          , attenuation.list[inputLevelAttenuation]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseLevAttRF()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AFModSource
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_AFModSource (ViSession instrSession,
                                          ViBoolean enabled,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   checkRange( AFG_MOD_EXT, &enabled );   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFG_MOD_EXT].instrCommand
          , AFModExt.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseLevModeAF
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseLevModeAF( ViSession instrSession
                            , ViInt32   inputLevelSetting
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( LEV_MODE_AF, &inputLevelSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[LEV_MODE_AF].instrCommand
          , mode.list[inputLevelSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseLevModeAF()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseLevMaxAF
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseLevMaxAF( ViSession instrSession
                           , ViReal64  inputLevelMaximumdBm
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( LEV_MAX_AF, &inputLevelMaximumdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[LEV_MAX_AF].instrCommand
          , inputLevelMaximumdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseLevMaxAF()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseLevDefaultAF
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseLevDefaultAF( ViSession instrSession
                               , ViBoolean enabled
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( SENS_LEV_AF_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SENS_LEV_AF_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseLevDefaultAF()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_TrigSeqSource
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_TrigSeqSource( ViSession instrSession
                           , ViInt32   triggerMode
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
// JMG  ViChar   *wrtBuf;
// JMG  ViChar   *rdBuf;

   RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );

   
/*   
   checkRange( TRIG_SEQ_SRC, &triggerMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TRIG_SEQ_SRC].instrCommand
          , trigSrc.list[triggerMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
*/    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_TrigSeqSource()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_TrigSeqThreshold
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_TrigSeqThreshold( ViSession instrSession
                              , ViInt32   triggerThreshold
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
// JMG   ViChar   *wrtBuf;
// JMG   ViChar   *rdBuf;

   RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );

   
/*   checkRange( TRIG_SEQ_THRESH, &triggerThreshold );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TRIG_SEQ_THRESH].instrCommand
          , threshold.list[triggerThreshold]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
*/    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_TrigSeqThreshold()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_TrigSeqDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_TrigSeqDefault( ViSession instrSession
                            , ViBoolean enabled
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
// JMG   ViChar   *wrtBuf;
// JMG   ViChar   *rdBuf;

   RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );   
/*   checkRange( TRIG_SEQ_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TRIG_SEQ_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
*/    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_TrigSeqDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseRfanFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseRfanFreq( ViSession instrSession
                           , ViReal64  frequency
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RFAN_FREQ, &frequency );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RFAN_FREQ].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseRfanFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseRfanChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseRfanChan( ViSession instrSession
                           , ViInt32   channel
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RFAN_FREQ_CHAN, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RFAN_FREQ_CHAN].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseRfanChan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseRfanFreqOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseRfanFreqOffset( ViSession instrSession
                                 , ViReal64  frequencyOffsetkHz
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RFAN_FREQ_OFFSET, &frequencyOffsetkHz );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RFAN_FREQ_OFFSET].instrCommand
          , frequencyOffsetkHz
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseRfanFreqOffset()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceRfGLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceRfGLev( ViSession instrSession
                          , ViReal64  inputLevelMaximumdBm
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RFG_LEV, &inputLevelMaximumdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RFG_LEV].instrCommand
          , inputLevelMaximumdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceRfGLev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseRfGFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseRfGFreq( ViSession instrSession
                          , ViReal64  frequency
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RFG_FREQ, &frequency );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RFG_FREQ].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseRfGFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseRfGFreqChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseRfGFreqChan( ViSession instrSession
                              , ViInt32   channel
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RFG_FREQ_CHAN, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RFG_FREQ_CHAN].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseRfGFreqChan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseRfGFreqOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseRfGFreqOffset( ViSession instrSession
                                , ViReal64  frequencyOffsetkHz
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RFG_FREQ_OFFSET, &frequencyOffsetkHz );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RFG_FREQ_OFFSET].instrCommand
          , frequencyOffsetkHz
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseRfGFreqOffset()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitRfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitRfGenerator( ViSession instrSession
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_RFG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitRfGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortRfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortRfGenerator( ViSession instrSession
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_RFG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortRfGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchRfGeneratorStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchRfGeneratorStatus( ViSession  instrSession
                                    , ViInt32   *generatorStatus
                                    , ViChar     errorMessage[]
                                    )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   // Fetch the generator status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[RFG_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
      // Get the generator status:
      if( strncmp( "OFF", rdBuf, 3 ) == 0 ) 
      {
         *generatorStatus = RSCMU_GEN_STAT_OFF;
      }
      else if( strncmp( "RUN", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_RUN;
      }
      else if( strncmp( "ERR", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_ERR;
      }
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchRfGeneratorStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceAfGLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceAfGLev( ViSession instrSession
                          , ViReal64  inputLevelMaximumdBm
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( AFG_LEV, &inputLevelMaximumdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFG_LEV].instrCommand
          , inputLevelMaximumdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceAfGLev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseAfGFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseAfGFreq( ViSession instrSession
                          , ViInt32   frequency
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( AFG_FREQ, &frequency );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFG_FREQ].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseAfGFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitAfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitAfGenerator( ViSession instrSession
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_AFG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitAfGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortAfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortAfGenerator( ViSession instrSession
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_AFG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortAfGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchAfGeneratorStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchAfGeneratorStatus( ViSession  instrSession
                                    , ViInt32   *generatorStatus
                                    , ViChar     errorMessage[]
                                    )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   // Fetch the generator status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[AFG_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
      // Get the generator status:
      if( strncmp( "OFF", rdBuf, 3 ) == 0 ) 
      {
         *generatorStatus = RSCMU_GEN_STAT_OFF;
      }
      else if( strncmp( "RUN", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_RUN;
      }
      else if( strncmp( "ERR", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_ERR;
      }
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchAfGeneratorStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceModGDev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceModGDev( ViSession instrSession
                           , ViInt32   freqDeviation
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( MODG_DEV, &freqDeviation );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MODG_DEV].instrCommand
          , freqDeviation
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceModGDev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseModGFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseModGFreq( ViSession instrSession
                           , ViInt32   frequency
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( MODG_FREQ, &frequency );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MODG_FREQ].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseModGFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitModGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitModGenerator( ViSession instrSession
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_MODG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitModGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortModGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortModGenerator( ViSession instrSession
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_MODG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortModGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchModGeneratorStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchModGeneratorStatus( ViSession  instrSession
                                     , ViInt32   *generatorStatus
                                     , ViChar     errorMessage[]
                                     )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   // Fetch the generator status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[MODG_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
      // Get the generator status:
      if( strncmp( "OFF", rdBuf, 3 ) == 0 ) 
      {
         *generatorStatus = RSCMU_GEN_STAT_OFF;
      }
      else if( strncmp( "RUN", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_RUN;
      }
      else if( strncmp( "ERR", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_ERR;
      }
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchModGeneratorStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceSatPeakDev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceSatPeakDev( ViSession instrSession
                              , ViInt32   peakDev
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SAT_PEAK_DEV, &peakDev );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SAT_PEAK_DEV].instrCommand
          , peakDev
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceSatPeakDev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceSatScc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceSatScc( ViSession instrSession
                          , ViInt32   SCC
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SAT_SCC, &SCC );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SAT_SCC].instrCommand
          , SCC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceSatScc()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitSatGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitSatGenerator( ViSession instrSession
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_SATG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitSatGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortSatGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortSatGenerator( ViSession instrSession
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_SATG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortSatGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchSatGeneratorStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchSatGeneratorStatus( ViSession  instrSession
                                     , ViInt32   *generatorStatus
                                     , ViChar     errorMessage[]
                                     )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   // Fetch the generator status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[SAT_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
      // Get the generator status:
      if( strncmp( "OFF", rdBuf, 3 ) == 0 ) 
      {
         *generatorStatus = RSCMU_GEN_STAT_OFF;
      }
      else if( strncmp( "RUN", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_RUN;
      }
      else if( strncmp( "ERR", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_ERR;
      }
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchSatGeneratorStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceStPeakDev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceStPeakDev( ViSession instrSession
                             , ViInt32   peakDeviation
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( ST_PEAK_DEV, &peakDeviation );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[ST_PEAK_DEV].instrCommand
          , peakDeviation
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceStPeakDev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceStDat
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceStDat( ViSession instrSession
                         , ViBoolean enabled
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( ST_DAT, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[ST_DAT].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceStDat()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitStGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitStGenerator( ViSession instrSession
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_STG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitStGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortStGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortStGenerator( ViSession instrSession
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_STG].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortStGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchStGeneratorStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchStGeneratorStatus( ViSession  instrSession
                                    , ViInt32   *generatorStatus
                                    , ViChar     errorMessage[]
                                    )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   // Fetch the generator status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ST_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
      // Get the generator status:
      if( strncmp( "OFF", rdBuf, 3 ) == 0 ) 
      {
         *generatorStatus = RSCMU_GEN_STAT_OFF;
      }
      else if( strncmp( "RUN", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_RUN;
      }
      else if( strncmp( "ERR", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_ERR;
      }
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchStGeneratorStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTxContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfModTxContRep( ViSession instrSession
                              , ViInt32   rep
                              , ViInt32   stopCondition
                              , ViInt32   step
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( MOD_TX_REP, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModTxContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTxContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfModTxContDefault( ViSession instrSession
                                  , ViBoolean enabled
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
        
   checkRange( MOD_TX_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModTxContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTxLimLineLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfModTxLimLineLevel( ViSession instrSession
                                   , ViInt32   carrFreqErrRange
                                   , ViInt32   totPeakDevMax
                                   , ViReal64  SATFreqErrRange
                                   , ViInt32   SATPeakDevErrRange
                                   , ViReal64  STFreqErrRange
                                   , ViInt32   STPeakDevErrRange
                                   , ViReal64  modDistNoise
                                   , ViReal64  ResAM
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( MOD_TX_LIMITS
             , &carrFreqErrRange
             , &totPeakDevMax
             , &SATFreqErrRange
             , &SATPeakDevErrRange
             , &STFreqErrRange
             , &STPeakDevErrRange
             , &modDistNoise
             , &ResAM
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_LIMITS].instrCommand
          , carrFreqErrRange
          , totPeakDevMax
          , SATFreqErrRange
          , SATPeakDevErrRange
          , STFreqErrRange
          , STPeakDevErrRange
          , modDistNoise
          , ResAM
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModTxLimLineLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTxLimDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfModTxLimDefault( ViSession instrSession
                                 , ViBoolean enabled
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( MOD_TX_LIM_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_LIM_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModTxLimDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTxFilter
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfModTxFilter( ViSession instrSession
                             , ViInt32   Bandpass
                             , ViBoolean deemphasis
                             , ViBoolean expandor
                             , ViInt32   Weighting
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( MOD_TX_FILT, &Bandpass, &deemphasis, &expandor, &Weighting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_FILT].instrCommand
          , bandpass.list[Bandpass]
          , enable.list[deemphasis]
          , enable.list[expandor]
          , weighting.list[Weighting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModTxFilter()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTxFilterSfbw
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTxFilterSfbw (ViSession instrumentHandle,
                                               ViInt32 filter,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   checkRange( MOD_TX_FILT_SFBW, &filter );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_FILT_SFBW].instrCommand
          , BWFilter.list[filter]
          );
   
   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ConfModTxFilterSfbw()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTxFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfModTxFilterDefault( ViSession instrSession
                                    , ViBoolean enabled
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

      if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( MOD_TX_FILT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_FILT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModTxFilterDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitModTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitModTx( ViSession instrSession
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_MOD_TX].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitModTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortModTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortModTx( ViSession instrSession
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_MOD_TX].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortModTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopModTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopModTx( ViSession instrSession
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_MOD_TX].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopModTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueModTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueModTx( ViSession instrSession
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_MOD_TX].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueModTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchModTxStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchModTxStatus( ViSession  instrSession
                              , ViInt32   *measurementStatus
                              , ViInt32   *CurrentStatCycleCount
                              , ViChar     errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[MOD_TX_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchModTxStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTxErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession
 *              ViInt32   measurementEventReporting
 *
 * OUTPUTS:     ViChar    errorMessage[]
 *
 * RETURN:      ViStatus  RSCMU_Status
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfModTxErep( ViSession instrSession
                           , ViInt32   measurementEventReporting
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( MOD_TX_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModTxErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalModTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadScalModTx( ViSession  instrSession
                           , ViReal64  *carrierFreqError
                           , ViReal64  *totalPeakDeviation
                           , ViReal64  *SATFreqError
                           , ViReal64  *SATPeakDeviation
                           , ViReal64  *STFreqError
                           , ViReal64  *STPeakDeviation
                           , ViReal64  *audioPeakDeviation
                           , ViReal64  *audioRMSDeviation
                           , ViReal64  *modDistNoise
                           , ViReal64  *carrierPower
                           , ViReal64  *residualAM
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[READ_MOD_TX].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPeakDeviation );
   }
   else 
   {
      *totalPeakDeviation = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SATFreqError );
   }
   else
   {
      *SATFreqError = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", SATPeakDeviation );
   }
   else
   {
      *SATPeakDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", STFreqError );
   }
   else
   {
      *STFreqError = RSCMU_NAN;
   }
    
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", STPeakDeviation );
   }
   else
   {
      *STPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", modDistNoise );
   }
   else
   {
      *modDistNoise = RSCMU_NAN;
   }
    
   if( strcmp( tab[9], "NAN" ) != 0 )
   {
      sscanf( tab[9], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   if( strcmp( tab[10], "NAN" ) != 0 )
   {
      sscanf( tab[10], "%lf", residualAM );
   }
   else
   {
      *residualAM = RSCMU_NAN;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadScalModTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalModTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchScalModTx( ViSession  instrSession
                            , ViReal64  *carrierFreqError
                            , ViReal64  *totalPeakDeviation
                            , ViReal64  *SATFreqError
                            , ViReal64  *SATPeakDeviation
                            , ViReal64  *STFreqError
                            , ViReal64  *STPeakDeviation
                            , ViReal64  *audioPeakDeviation
                            , ViReal64  *audioRMSDeviation
                            , ViReal64  *modDistNoise
                            , ViReal64  *carrierPower
                            , ViReal64  *residualAM
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[FETCH_MOD_TX].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPeakDeviation );
   }
   else 
   {
      *totalPeakDeviation = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SATFreqError );
   }
   else
   {
      *SATFreqError = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", SATPeakDeviation );
   }
   else
   {
      *SATPeakDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", STFreqError );
   }
   else
   {
      *STFreqError = RSCMU_NAN;
   }
    
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", STPeakDeviation );
   }
   else
   {
      *STPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", modDistNoise );
   }
   else
   {
      *modDistNoise = RSCMU_NAN;
   }
    
   if( strcmp( tab[9], "NAN" ) != 0 )
   {
      sscanf( tab[9], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   if( strcmp( tab[10], "NAN" ) != 0 )
   {
      sscanf( tab[10], "%lf", residualAM );
   }
   else
   {
      *residualAM = RSCMU_NAN;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchScalModTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalModTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleScalModTx( ViSession  instrSession
                             , ViReal64  *carrierFreqError
                             , ViReal64  *totalPeakDeviation
                             , ViReal64  *SATFreqError
                             , ViReal64  *SATPeakDeviation
                             , ViReal64  *STFreqError
                             , ViReal64  *STPeakDeviation
                             , ViReal64  *audioPeakDeviation
                             , ViReal64  *audioRMSDeviation
                             , ViReal64  *modDistNoise
                             , ViReal64  *carrierPower
                             , ViReal64  *residualAM
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[SAMPLE_MOD_TX].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPeakDeviation );
   }
   else 
   {
      *totalPeakDeviation = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SATFreqError );
   }
   else
   {
      *SATFreqError = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", SATPeakDeviation );
   }
   else
   {
      *SATPeakDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", STFreqError );
   }
   else
   {
      *STFreqError = RSCMU_NAN;
   }
    
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", STPeakDeviation );
   }
   else
   {
      *STPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", modDistNoise );
   }
   else
   {
      *modDistNoise = RSCMU_NAN;
   }
    
   if( strcmp( tab[9], "NAN" ) != 0 )
   {
      sscanf( tab[9], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   if( strcmp( tab[10], "NAN" ) != 0 )
   {
      sscanf( tab[10], "%lf", residualAM );
   }
   else
   {
      *residualAM = RSCMU_NAN;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleScalModTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalModTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcScalModTx( ViSession  instrSession
                           , ViInt32   *carrierFreqError
                           , ViInt32   *totalPeakDeviation
                           , ViInt32   *SATFreqError
                           , ViInt32   *SATPeakDeviation
                           , ViInt32   *STFreqError
                           , ViInt32   *STPeakDeviation
                           , ViInt32   *audioPeakDeviation
                           , ViInt32   *audioRMSDeviation
                           , ViInt32   *modDistNoise
                           , ViInt32   *carrierPower
                           , ViInt32   *residualAM
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_MOD_TX].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( carrierFreqError,   tab, 0 );
   RSCMU_GetMatchingLimit( totalPeakDeviation, tab, 1 );
   RSCMU_GetMatchingLimit( SATFreqError,       tab, 2 );
   RSCMU_GetMatchingLimit( SATPeakDeviation,   tab, 3 );
   RSCMU_GetMatchingLimit( STFreqError,        tab, 4 );
   RSCMU_GetMatchingLimit( STPeakDeviation,    tab, 5 );
   RSCMU_GetMatchingLimit( audioPeakDeviation, tab, 6 );
   RSCMU_GetMatchingLimit( audioRMSDeviation,  tab, 7 );
   RSCMU_GetMatchingLimit( modDistNoise,       tab, 8 );
   RSCMU_GetMatchingLimit( residualAM,         tab, 9 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalModTx()



/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModCPOWContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ConfModCPOWContRep (ViSession instrumentHandle,
                                                 ViInt32 rep,
                                                 ViInt32 stopCondition,
                                                 ViInt32 step,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   checkRange( MOD_CPOW_REP, &rep, &stopCondition, &step );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_CPOW_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
    
} // endof RSCMU_AMPS_ConfModCPOWContRep()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModCPOWContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ConfModCPOWContDefault (ViSession instrumentHandle,
                                                     ViBoolean enabled,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrumentHandle, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   
   checkRange( MOD_CPOW_DEF, &enabled );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_CPOW_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_CalcScalModTx()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitModCPOW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_InitModCPOW (ViSession instrumentHandle,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[INIT_MOD_CPOW].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_InitModCPOW()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortModCPOW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_AbortModCPOW (ViSession instrumentHandle,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[ABOR_MOD_CPOW].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_AbortModCPOW()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopModCPOW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_StopModCPOW (ViSession instrumentHandle,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[STOP_MOD_CPOW].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_StopModCPOW()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueModCPOW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ContinueModCPOW (ViSession instrumentHandle,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[CONT_MOD_CPOW].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ContinueModCPOW()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchModCPOWStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_FetchModCPOWStatus (ViSession instrumentHandle,
                                                 ViInt32 *measurementStatus,
                                                 ViInt32 *CurrentStatCycleCount,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[MOD_CPOW_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
   return( RSCMU_Status );  
   
} // endof RSCMU_AMPS_FetchModCPOWStatus()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModCPOWErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ConfModCPOWErep (ViSession instrumentHandle,
                                              ViInt32 measurementEventReporting,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   checkRange( MOD_CPOW_EREP, &measurementEventReporting );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_CPOW_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
   return( RSCMU_Status );  
   
} // endof RSCMU_AMPS_ConfModCPOWErep()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalModCPOW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalModCPOW (ViSession instrumentHandle,
                                              ViReal64 *carrierFreqError,
                                              ViReal64 *carrierPower,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[READ_MOD_CPOW].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
    
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   
   return( RSCMU_Status );

    
} // endof RSCMU_AMPS_ReadScalModCPOW()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalModCPOW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalModCPOW (ViSession instrumentHandle,
                                               ViReal64 *carrierFreqError,
                                               ViReal64 *carrierPower,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[FETC_MOD_CPOW].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
    
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   
   return( RSCMU_Status );

    
} // endof RSCMU_AMPS_FetchScalModCPOW()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalModCPOW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalModCPOW (ViSession instrumentHandle,
                                                ViReal64 *carrierFreqError,
                                                ViReal64 *carrierPower,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[SAMP_MOD_CPOW].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
    
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   
   return( RSCMU_Status );

    
} // endof RSCMU_AMPS_SampleScalModCPOW()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalModCPOW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalModCPOW (ViSession instrumentHandle,
                                              ViInt32 *carrierFreqError,
                                              ViInt32 *carrierPower,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[CALC_MOD_CPOW].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( carrierFreqError, tab, 0 );
   RSCMU_GetMatchingLimit( carrierPower, tab, 1 );
   
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_CalcScalModCPOW()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTADContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC RSCMU_AMPS_ConfModTADContRep (ViSession instrumentHandle,
                                                ViInt32 rep,
                                                ViInt32 stopCondition,
                                                ViInt32 step,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   checkRange( MOD_TAD_REP, &rep, &stopCondition, &step );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TAD_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}  //   RSCMU_AMPS_ConfModTADContRep

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTADContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTADContDefault (ViSession instrumentHandle,
                                                    ViBoolean enabled,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrumentHandle, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( MOD_TAD_DEF, &enabled );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TAD_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

    
} // endof RSCMU_AMPS_ConfModTADContDefault()  

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitModTAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_InitModTAD (ViSession instrumentHandle,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[INIT_MOD_TAD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitModTAD()
    

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortModTAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_AbortModTAD (ViSession instrumentHandle,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[ABOR_MOD_TAD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_AbortModTAD() 

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopModTAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_StopModTAD (ViSession instrumentHandle,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[STOP_MOD_TAD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );    
} // endof RSCMU_AMPS_StopModTAD()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueModTAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ContinueModTAD (ViSession instrumentHandle,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[CONT_MOD_TAD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );    
} // endof RSCMU_AMPS_ContinueModTAD()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchModTADStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_FetchModTADStatus (ViSession instrumentHandle,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *CurrentStatCycleCount,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[MOD_TAD_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

    
} // endof RSCMU_AMPS_FetchModTADStatus()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModTADErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ConfModTADErep (ViSession instrumentHandle,
                                             ViInt32 measurementEventReporting,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   checkRange( MOD_TAD_EREP, &measurementEventReporting );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TAD_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );    
} // endof RSCMU_AMPS_ConfModTADErep()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalModTAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalModTAD (ViSession instrumentHandle,
                                             ViReal64 *totalPeakDeviation,
                                             ViReal64 *audioPeakDeviation,
                                             ViReal64 *audioRMSDeviation,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[READ_MOD_TAD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPeakDeviation );
   }
   else 
   {
      *totalPeakDeviation = RSCMU_NAN; 
   }
    
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN;
   }
    
    
   return( RSCMU_Status );

    
} // RSCMU_AMPS_ReadScalModTAD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalModTAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalModTAD (ViSession instrumentHandle,
                                              ViReal64 *totalPeakDeviation,
                                              ViReal64 *audioPeakDeviation,
                                              ViReal64 *audioRMSDeviation,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[FETC_MOD_TAD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPeakDeviation );
   }
   else 
   {
      *totalPeakDeviation = RSCMU_NAN; 
   }
    
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN;
   }
    
    
   return( RSCMU_Status );
    
} // RSCMU_AMPS_FetchScalModTAD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalModTAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalModTAD (ViSession instrumentHandle,
                                               ViReal64 *totalPeakDeviation,
                                               ViReal64 *audioPeakDeviation,
                                               ViReal64 *audioRMSDeviation,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[SAMP_MOD_TAD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPeakDeviation );
   }
   else 
   {
      *totalPeakDeviation = RSCMU_NAN; 
   }
    
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN;
   }
    
    
   return( RSCMU_Status );    
} // RSCMU_AMPS_FetchScalModTAD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalModTAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_CalcScalModTAD (ViSession instrumentHandle,
                                             ViInt32 *totalPeakDeviation,
                                             ViInt32 *audioPeakDeviation,
                                             ViInt32 *audioRMSDeviation,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[CALC_MOD_TAD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( totalPeakDeviation, tab, 0 );
   RSCMU_GetMatchingLimit( audioPeakDeviation, tab, 1 );
   RSCMU_GetMatchingLimit( audioRMSDeviation, tab, 2 );    
   return( RSCMU_Status );
    
} //  RSCMU_AMPS_CalcScalModTAD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModWBDContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDContRep (ViSession instrumentHandle,
                                                ViInt32 rep,
                                                ViInt32 stopCondition,
                                                ViInt32 step,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 

   checkRange( WBD_REP, &rep, &stopCondition, &step );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[WBD_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModWBDContRep()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModWBDContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDContDefault (ViSession instrumentHandle,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 


   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[WBD_DEF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
       
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModWBDContDefault

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModWBDLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDLim (ViSession instrSession,
                                            ViInt32 carrierFreqErrorRange_Hz,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 


   checkRange( WDB_DEV_LIMITS, &carrierFreqErrorRange_Hz);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[WDB_DEV_LIMITS].instrCommand
          , carrierFreqErrorRange_Hz
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModWBDLim

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModWBDLimDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDLimDefault (ViSession instrumentHandle,
                                                   ViInt32 Limit,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 

   checkRange( WDB_LIM_DEF, &Limit);
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[WDB_LIM_DEF].instrCommand
          , LimitDef.list[Limit]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );    
     
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfModWBDLimDefault


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitModWBD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_InitModWBD (ViSession instrumentHandle,
                                         ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[INIT_WBD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitModWBD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortModWBD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_AbortModWBD (ViSession instrumentHandle,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[ABOR_WBD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
} // endof  RSCMU_AMPS_AbortModWBD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopModWBD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_StopModWBD (ViSession instrumentHandle,
                                         ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[STOP_WBD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof  RSCMU_AMPS_StopModWBD


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueModWBD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_ContinueModWBD (ViSession instrumentHandle,
                                             ViChar errorMessage[])
{
    ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[CONT_WBD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );   
} // endof RSCMU_AMPS_ContinueModWBD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchModWBDStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_FetchModWBDStatus (ViSession instrumentHandle,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *CurrentStatCycleCount,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)AMPS[WBD_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
   return( RSCMU_Status ); 
   
}  // endof RSCMU_AMPS_FetchModWBDStatus

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfModWBDErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_ConfModWBDErep (ViSession instrumentHandle,
                                             ViInt32 measurementEventReporting,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 

   checkRange( WBD_EREP, &measurementEventReporting );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[WBD_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
   return( RSCMU_Status );  
    
}// endof RSCMU_AMPS_ConfModWBDErep

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalModWBD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_ReadScalModWBD (ViSession instrumentHandle,
                                             ViInt32  *WordSync,
                                             ViReal64 *carrierFreqError,
                                             ViReal64 *carrierPower,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[READ_WBD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   // For All Measured Values
   if( strncmp( "Ok", tab[0], 2 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NAN", tab[0], 3 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_INV;
   }
   else if( strncmp( "FAIL", tab[0], 4 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_NMAT;
   }

   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
    
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   
   return( RSCMU_Status );    
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalModWBD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_FetchScalModWBD (ViSession instrumentHandle,
                                              ViInt32 *WordSync,
                                              ViReal64 *carrierFreqError,
                                              ViReal64 *carrierPower,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[FETC_WBD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   // For All Measured Values
   if( strncmp( "Ok", tab[0], 2 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NAN", tab[0], 3 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_INV;
   }
   else if( strncmp( "FAIL", tab[0], 4 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_NMAT;
   }

   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
    
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   
   return( RSCMU_Status );        
}    // endof RSCMU_AMPS_FetchScalModWBD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalModWBD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
// JMG 040422
ViStatus _VI_FUNC RSCMU_AMPS_SampleScalModWBD (ViSession instrumentHandle,
                                               ViInt32 *WordSync,
                                               ViReal64 *carrierFreqError,
                                               ViReal64 *carrierPower,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[SAMP_WBD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   // For All Measured Values
   if( strncmp( "OK", tab[0], 2 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NAN", tab[0], 3 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_INV;
   }
   else if( strncmp( "FAIL", tab[0], 4 ) == 0 )
   {
      *WordSync = RSCMU_MATCH_NMAT;
   }

   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
    
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   
   return( RSCMU_Status );        
}  // endof RSCMU_AMPS_SampleScalModWBD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalModWBD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC RSCMU_AMPS_CalcScalModWBD (ViSession instrumentHandle,
                                             ViInt32 *limitMATCH,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_52, errorMessage); 
      
   // Check if the function is correctly used:               
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Retreive the Measurement.
   if( RSCMU_Status = RSCMU_Query( instrumentHandle
                                 , (ViChar *)AMPS[CALC_LIM_WBD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   // For All Measured Values
   if( strncmp( "OK", tab[0], 2 ) == 0 )
   {
      *limitMATCH = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NAN", tab[0], 3 ) == 0 )
   {
      *limitMATCH = RSCMU_MATCH_INV;
   }
   else if( strncmp( "FAIL", tab[0], 4 ) == 0 )
   {
      *limitMATCH = RSCMU_MATCH_NMAT;
   }
   return( RSCMU_Status );     
}  // endof   RSCMU_AMPS_CalcScalModWBD

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHnTxContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfHnTxContRep( ViSession instrSession
                             , ViInt32   rep
                             , ViInt32   stopCondition
                             , ViInt32   step
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( HN_TX_REP, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[HN_TX_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfHnTxContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHnTxContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfHnTxContDefault( ViSession instrSession
                                 , ViBoolean enabled
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }


   checkRange( HN_TX_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[HN_TX_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfHnTxContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHnTxLimLineLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfHnTxLimLineLevel( ViSession instrSession
                                  , ViInt32   carrFreqErrRange
                                  , ViInt32   SATFreqErrRange
                                  , ViInt32   SATPeakDevErrRange
                                  , ViReal64  HumNoise
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( HN_TX_LIMITS
             , &carrFreqErrRange
             , &SATFreqErrRange
             , &SATPeakDevErrRange
             , &HumNoise
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[HN_TX_LIMITS].instrCommand
          , carrFreqErrRange
          , SATFreqErrRange
          , SATPeakDevErrRange
          , HumNoise
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfHnTxLimLineLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHnTxLimDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfHnTxLimDefault( ViSession instrSession
                                , ViBoolean enabled
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( HN_TX_LIM_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[MOD_TX_LIM_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfHnTxLimDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHnTxFilter
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfHnTxFilter( ViSession instrSession
                            , ViInt32   Bandpass
                            , ViBoolean deemphasis
                            , ViBoolean expandor
                            , ViInt32   Weighting
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( HN_TX_FILT, &Bandpass, &deemphasis, &expandor, &Weighting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[HN_TX_FILT].instrCommand
          , bandpass.list[Bandpass]
          , enable.list[deemphasis]
          , enable.list[expandor]
          , weighting.list[Weighting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfHnTxFilter()



/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHnTxFilterSfbw
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_ConfHnTxFilterSfbw (ViSession instrumentHandle,
                                               ViInt32 filter,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   checkRange( HN_TX_FILT_SFBW, &filter );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[HN_TX_FILT_SFBW].instrCommand
          , BWFilter.list[filter]
          );
   
   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ConfHnTxFilterSfbw()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHnTxFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfHnTxFilterDefault( ViSession instrSession
                                   , ViBoolean enabled
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( HN_TX_FILT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[HN_TX_FILT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfHnTxFilterDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitHnTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitHnTx( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_HN_TX].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitHnTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortHnTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortHnTx( ViSession instrSession
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_HN_TX].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortHnTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopHnTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopHnTx( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_HN_TX].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopHnTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueHnTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueHnTx( ViSession instrSession
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_HN_TX].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueHnTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchHnTxStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchHnTxStatus( ViSession  instrSession
                             , ViInt32   *measurementStatus
                             , ViInt32   *CurrentStatCycleCount
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[HN_TX_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchHnTxStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHnTxErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfHnTxErep( ViSession instrSession
                          , ViInt32   measurementEventReporting
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( HN_TX_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[HN_TX_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfHnTxErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalHnTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadScalHnTx( ViSession  instrSession
                          , ViReal64  *carrierFreqError
                          , ViReal64  *SATFreqError
                          , ViReal64  *SATPeakDeviation
                          , ViReal64  *humandNoise
                          , ViReal64  *carrierPower
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[READ_TX_HN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", SATFreqError );
   }
   else
   {
      *SATFreqError = RSCMU_NAN;
   }
    
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SATPeakDeviation );
   }
   else
   {
      *SATPeakDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", humandNoise );
   }
   else
   {
      *humandNoise = RSCMU_NAN;
   }
    
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   return( RSCMU_Status );

}
 // endof RSCMU_AMPS_ReadScalHnTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalHnTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchScalHnTx( ViSession  instrSession
                           , ViReal64  *carrierFreqError
                           , ViReal64  *SATFreqError
                           , ViReal64  *SATPeakDeviation
                           , ViReal64  *humandNoise
                           , ViReal64  *carrierPower
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[FETCH_TX_HN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", SATFreqError );
   }
   else
   {
      *SATFreqError = RSCMU_NAN;
   }
    
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SATPeakDeviation );
   }
   else
   {
      *SATPeakDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", humandNoise );
   }
   else
   {
      *humandNoise = RSCMU_NAN;
   }
    
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   return( RSCMU_Status );
    
}
 // endof RSCMU_AMPS_FetchScalHnTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalHnTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleScalHnTx( ViSession  instrSession
                            , ViReal64  *carrierFreqError
                            , ViReal64  *SATFreqError
                            , ViReal64  *SATPeakDeviation
                            , ViReal64  *humandNoise
                            , ViReal64  *carrierPower
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[SAMPLE_TX_HN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", SATFreqError );
   }
   else
   {
      *SATFreqError = RSCMU_NAN;
   }
    
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SATPeakDeviation );
   }
   else
   {
      *SATPeakDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", humandNoise );
   }
   else
   {
      *humandNoise = RSCMU_NAN;
   }
    
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   return( RSCMU_Status );
    
}
 // endof RSCMU_AMPS_SampleScalHnTx()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalHnTx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcScalHnTx( ViSession instrSession
                          , ViInt32   *carrierFreqError
                          , ViInt32   *SATFreqError
                          , ViInt32   *SATPeakDeviation
                          , ViInt32   *humNoise
                          , ViInt32   *carrierPower
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_TX_HN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( carrierFreqError, tab, 0 );
   RSCMU_GetMatchingLimit( SATFreqError,     tab, 1 );
   RSCMU_GetMatchingLimit( SATPeakDeviation, tab, 2 );
   RSCMU_GetMatchingLimit( humNoise,         tab, 3 );
   RSCMU_GetMatchingLimit( carrierPower,     tab, 4 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalHnTx()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceAfGSLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC RSCMU_AMPS_SourceAfGSLev (ViSession instrSession,
                                            ViReal64 AFGeneratorLevel_V,
                                            ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   checkRange( AFG_LEV, &AFGeneratorLevel_V );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFG_SLEV].instrCommand
          , AFGeneratorLevel_V
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLTapDev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLTapDev( ViSession instrSession
                           , ViInt32   TargetDev
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( AFL_TX_TAP_DEV, &TargetDev );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFL_TX_TAP_DEV].instrCommand
          , TargetDev
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfAfLTapDev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLTgtErrRange
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLTgtErrRange( ViSession instrSession
                                , ViInt32   ErrRange
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( AFL_TX_ERR_RANGE, &ErrRange );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFL_TX_ERR_RANGE].instrCommand
          , ErrRange
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfAfLTgtErrRange()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLContPcom
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLContPcom( ViSession instrSession
                               , ViBoolean enabled
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   
   checkRange( TXAF_AFG_LEV_PCOM, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_AFG_LEV_PCOM].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfAfLContPcom()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_ConfAfLTgDevType (ViSession instrumentHandle,
                                               ViInt32 targetDeviationType,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
    
   if (p_globalvarBase->RSCMU_FW_Version <= RSCMU200_V3_50)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_50, errorMessage); 

   checkRange( TARG_DEV_TYP, &targetDeviationType );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TARG_DEV_TYP].instrCommand
          , TargDevTyp.list[targetDeviationType]
          );
   
   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ConfAfLTgDevType()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLContDefault( ViSession instrSession
                                , ViBoolean enabled
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( AFL_TX_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFL_TX_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfAfLContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLLimLineLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLLimLineLevel( ViSession instrSession
                                 , ViInt32   carrierFreqErr
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( AFL_TX_LIMITS, &carrierFreqErr);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFL_TX_LIMITS].instrCommand
          , carrierFreqErr
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfAfLLimLineLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLLimLineDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLLimLineDefault( ViSession instrSession
                                   , ViBoolean enabled
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   
   checkRange( AFL_TX_LIMITS_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFL_TX_LIMITS_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // RSCMU_AMPS_ConfAfLLimLineDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLFilter
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLFilter( ViSession instrSession
                           , ViInt32   Bandpass
                           , ViBoolean deemphasis
                           , ViBoolean expandor
                           , ViInt32   Weighting
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( AFL_TX_FILT, &Bandpass, &deemphasis, &expandor, &Weighting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFL_TX_FILT].instrCommand
          , bandpass.list[Bandpass]
          , enable.list[deemphasis]
          , enable.list[expandor]
          , weighting.list[Weighting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfAfLFilter()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLFilterDefault( ViSession instrSession
                                  , ViBoolean enabled
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   
   checkRange( AFL_TX_FILT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFL_TX_FILT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfAfLFilterDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitAfL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitAfL( ViSession instrSession
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_AFL].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitAfL()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortAfL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortAfL( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_AFL].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortAfL()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopAfL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopAfL( ViSession instrSession
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_AFL].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopAfL()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueAfL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueAfL( ViSession instrSession
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_AFL].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueAfL()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchAfLStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchAfLStatus( ViSession  instrSession
                            , ViInt32   *measurementStatus
                            , ViInt32   *CurrentStatCycleCount
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[AFL_TX_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchAfLStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfAfLErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfAfLErep( ViSession instrSession
                         , ViInt32   measurementEventReporting
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( AFL_TX_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[AFL_TX_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfAfLErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalAfL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadScalAfL( ViSession  instrSession
                         , ViReal64  *carrierFreqError
                         , ViReal64  *audioPeakDeviation
                         , ViReal64  *audioRMSDeviation
                         , ViReal64  *carrierPower
                         , ViReal64  *AFSearchLevel
                         , ViChar     errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[READ_TX_AFL].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", AFSearchLevel );
   }
   else
   {
      *AFSearchLevel = RSCMU_NAN;
   }
    
   return( RSCMU_Status );
    
}
 // endof RSCMU_AMPS_ReadScalAfL()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalAfL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchScalAfL( ViSession  instrSession
                          , ViReal64  *carrierFreqError
                          , ViReal64  *audioPeakDeviation
                          , ViReal64  *audioRMSDeviation
                          , ViReal64  *carrierPower
                          , ViReal64  *AFSearchLevel
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[FETCH_TX_AFL].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", AFSearchLevel );
   }
   else
   {
      *AFSearchLevel = RSCMU_NAN;
   }
    
   return( RSCMU_Status );
    
}
 // endof RSCMU_AMPS_FetchScalAfL()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalAfL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleScalAfL( ViSession instrSession
                           , ViReal64  *carrierFreqError
                           , ViReal64  *audioPeakDeviation
                           , ViReal64  *audioRMSDeviation
                           , ViReal64  *carrierPower
                           , ViReal64  *AFSearchLevel
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[SAMPLE_TX_AFL].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", carrierFreqError );
   }
   else 
   {
      *carrierFreqError = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", audioPeakDeviation );
   }
   else
   {
      *audioPeakDeviation = RSCMU_NAN;
   }
    
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", audioRMSDeviation );
   }
   else
   {
      *audioRMSDeviation = RSCMU_NAN; 
   }
  
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", carrierPower );
   }
   else
   {
      *carrierPower = RSCMU_NAN;
   }
    
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", AFSearchLevel );
   }
   else
   {
      *AFSearchLevel = RSCMU_NAN;
   }
    
   return( RSCMU_Status );
    
}
 // endof RSCMU_AMPS_SampleScalAfL()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalAfL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcScalAfL( ViSession  instrSession
                         , ViInt32   *carrierFreqError
                         , ViInt32   *audioDevPeak
                         , ViInt32   *audioDevRMS
                         , ViChar     errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_TX_AFL].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( carrierFreqError, tab, 0 );
   RSCMU_GetMatchingLimit( audioDevPeak,     tab, 1 );
   RSCMU_GetMatchingLimit( audioDevRMS,      tab, 2 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalAfL()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafContRep( ViSession instrSession
                             , ViInt32   rep
                             , ViInt32   stopCondition
                             , ViInt32   step
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_REP, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_DispTxafContGrid
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_DispTxafContGrid( ViSession instrSession
                              , ViBoolean gridLines
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_GRID, &gridLines );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_GRID].instrCommand
          , enable.list[gridLines]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_DispTxafContGrid()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafRefDev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafRefDev( ViSession instrSession
                            , ViInt32   refDev
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_REF_DEV, &refDev );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_REF_DEV].instrCommand
          , refDev
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafRefDev()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafAfgLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafAfgLev (ViSession instrSession,
                                             ViInt32 AFGControl,
                                             ViReal64 AFGLevel_mV,
                                             ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar   Format[WR_BUFFER_SIZE] = "\0";

   
  // checkRange( TXAF_HOLDOFF, &holdoffTime );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   switch( AFGControl)
   {
   case  RSCMU_AMPS_AFG_TLEV:
   
       
       strcpy(Format,AMPS[TXAF_AFG_MODE].instrCommand);
       strcat(Format,";:\0");
       strcat(Format,AMPS[TXAF_AFG_LEV].instrCommand);
       
       sprintf (wrtBuf, Format, AFGMode.list[AFGControl],AFGLevel_mV);
       
   break;
   
   case  RSCMU_AMPS_AFG_SLEV:
   
       sprintf( wrtBuf
          , AMPS[TXAF_AFG_MODE].instrCommand
          , AFGMode.list[AFGControl]
          );
    
   break;


   case  RSCMU_AMPS_AFG_SRES:

       sprintf( wrtBuf
          , AMPS[TXAF_AFG_MODE].instrCommand
          , AFGMode.list[AFGControl]
          );
    
   break;
   }
   
   
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );    
    
} // endof RSCMU_AMPS_ConfTxafAfgLev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafLevCfac
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafLevCfac (ViSession instrumentHandle,
                                               ViInt32 crestFactor,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    
   checkRange( TXAF_CFACT, &crestFactor );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_CFACT].instrCommand
          , CRFactor.list[crestFactor]
          );
   
   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ConfTxafLevCfac()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafHoldoff
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafHoldoff( ViSession instrSession
                             , ViReal64  holdoffTime
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_HOLDOFF, &holdoffTime );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_HOLDOFF].instrCommand
          , holdoffTime * 1E-3
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafHoldoff()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceTxafRefValue
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceTxafRefValue( ViSession instrSession
                                , ViInt32   reference
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_REF, &reference );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_REF].instrCommand
          , TxafRef.list[reference]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceTxafRefValue()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafContDefault( ViSession instrSession
                                 , ViBoolean enabled
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( TXAF_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_DispTxafTraceScale
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_DispTxafTraceScale( ViSession instrSession
                                , ViReal64  min
                                , ViReal64  max
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_SCALE, &min, &max );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_SCALE].instrCommand
          , min
          , max
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_DispTxafTraceScale()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfSubTxafMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfSubTxafMode( ViSession instrSession
                             , ViInt32   measurement
                             , ViInt32   numberofSubranges
                             , SUBARRAY  subranges
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[20];
   ViInt32   i;

   if( measurement < 1 )
   {
      return RSCMU_errorMessage( instrSession, RSCMU_ERROR_PARAMETER3, errorMessage );
   }
   
   checkRange( TXAF_SUBARR, &measurement, &numberofSubranges );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_SUBARR].instrCommand
          , Subarray.list[measurement]
          );

   // Handle variable number of subranges, max 32
   for( i = 0; i < numberofSubranges; i++ )
   {
      sprintf( temp
             , ", %d,%d"
             , subranges.elements[i].Start
             , subranges.elements[i].Samples
             );
      strcat( wrtBuf, temp );
   }
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfSubTxafMode()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafLimitLines
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafLimitLines( ViSession  instrSession
                                , ViInt32    area
                                , TEST_TONES tone
                                , ViChar     errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[40] = "\0";
//   ViChar  buffout[512] = "\0";
   ViInt32   i;

//   checkRange( TXAF_LIMIT_TONE, &area );
    checkRange( TXAF_LIMIT_LINES, &area);

   
   for(i=0;i<20;i++) 
    checkRange( TXAF_LIMIT_TONE, &area, &i, &tone.element[i].Limit, &tone.element[i].Enabled );    

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_LIMIT_LINES].instrCommand
          , LimitArea.list[area]
          );
          
   strcat(wrtBuf, "\0");

   // Handle section, max 20 tones
   for( i = 0; i < 20; i++ )
   {
      sprintf( temp
             , (i==0?" %6.2lf,%s\0":",%6.2lf,%s\0")
             , tone.element[i].Limit
             , enable.list[tone.element[i].Enabled]
             );
             
      strcat( wrtBuf, temp );
   }
   
   strcat( wrtBuf, "\0");
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafLimitLines()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafLimitTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafLimitTone( ViSession instrSession
                               , ViInt32   area
                               , ViInt32   tone
                               , ViReal64  limit
                               , ViBoolean enabled
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_LIMIT_TONE, &area, &tone, &limit, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_LIMIT_TONE].instrCommand
          , LimitArea.list[area]
          , tone
          , limit
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafLimitTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafLimitDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafLimitDefault( ViSession instrSession
                                  , ViBoolean enabled
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( TXAF_LIMIT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_LIMIT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafLimitDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafTestTones
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafTestTones( ViSession     instrSession
                               , TXAF_TONE_DEF tone
                               , ViChar        errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar   buffout[RD_BUFFER_SIZE_ARRAY]="\0";
   ViChar    temp[20];
   ViInt32   i;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   strcpy( buffout, AMPS[TXAF_TDEF].instrCommand );

   // Handle section, max 20 tones
   for( i = 0; i < 20; i++ )
   {
      if( i == 0 )
      {
         sprintf( temp
               , " %d,%6.4lf,%s"
               , tone.element[i].Freq
               , tone.element[i].Level
               , enable.list[tone.element[i].Enabled]
               );
      }
      else
      {
         sprintf( temp
               , ", %d,%6.4lf,%s"
               , tone.element[i].Freq
               , tone.element[i].Level
               , enable.list[tone.element[i].Enabled]
               );
      }
      strcat( buffout, temp );
   }
   
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , buffout
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             



   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafTestTones()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafTestToneDefinition
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafTestToneDefinition( ViSession instrSession
                                        , ViInt32   tone
                                        , ViInt32   freq
                                        , ViReal64  level
                                        , ViBoolean enabled
                                        , ViChar    errorMessage[]
                                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_TDEF_TONE, &tone, &freq, &level, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_TDEF_TONE].instrCommand
          , tone
          , freq
          , level
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafTestToneDefinition()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafTestTonesDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafTestTonesDefault( ViSession instrSession
                                      , ViBoolean enabled
                                      , ViChar    errorMessage[]
                                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( TXAF_TTONES_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_TTONES_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafTestTonesDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafFilter
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafFilter( ViSession instrSession
                            , ViInt32   Bandpass
                            , ViBoolean deemphasis
                            , ViBoolean expandor
                            , ViInt32   Weighting
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_FILT, &Bandpass, &deemphasis, &expandor, &Weighting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_FILT].instrCommand
          , bandpass.list[Bandpass]
          , enable.list[deemphasis]
          , enable.list[expandor]
          , weighting.list[Weighting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafFilter()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafFilterDefault( ViSession instrSession
                                   , ViBoolean enabled
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( TXAF_FILT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_FILT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafFilterDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitTxaf( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_TXAF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortTxaf( ViSession instrSession
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_TXAF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopTxaf( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_TXAF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueTxaf( ViSession instrSession
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_TXAF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchTxafStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchTxafStatus( ViSession  instrSession
                             , ViInt32   *measurementStatus
                             , ViInt32   *CurrentStatCycleCount
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[TXAF_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchTxafStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfTxafErep( ViSession instrSession
                          , ViInt32   measurementEventReporting
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( TXAF_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfTxafErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadTxafTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadTxafTone( ViSession  instrSession
                          , ViInt32    tone
                          , ViReal64  *freq
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( READ_TXAF_TONE, &tone );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[READ_TXAF_TONE].instrCommand
          , tone
          );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , wrtBuf
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", freq );
   }
   else 
   {
      *freq = RSCMU_NAN; 
   }
   
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadTxafTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchTxafTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchTxafTone( ViSession  instrSession
                           , ViInt32    tone
                           , ViReal64  *freq
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( FETCH_TXAF_TONE, &tone );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[FETCH_TXAF_TONE].instrCommand
          , tone
          );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , wrtBuf
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", freq );
   }
   else 
   {
      *freq = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchTxafTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleTxafTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleTxafTone( ViSession  instrSession
                           , ViInt32    tone
                           , ViReal64  *freq
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SAMPLE_TXAF_TONE, &tone );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SAMPLE_TXAF_TONE].instrCommand
          , tone
          );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , wrtBuf
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", freq );
   }
   else 
   {
      *freq = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleTxafTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalTxafTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcScalTxafTone( ViSession  instrSession
                              , ViInt32    tone
                              , ViInt32   *limit
                              , ViChar     errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   checkRange( CALC_TXAF_TONE, &tone );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CALC_TXAF_TONE].instrCommand
          , tone
          );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , wrtBuf
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( limit, tab, 0 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalTxafTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadArrTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadArrTxaf( ViSession instrSession
                         , ViReal64  frequency[]
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[READ_TXAF_ARR].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[READ_TXAF_ARR].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[READ_TXAF_ARR].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadArrTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchArrTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchArrTxaf( ViSession instrSession
                          , ViReal64  frequency[]
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[FETCH_TXAF_ARR].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[FETCH_TXAF_ARR].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[FETCH_TXAF_ARR].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchArrTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleArrTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleArrTxaf( ViSession instrSession
                           , ViReal64  frequency[]
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[SAMPLE_TXAF_ARR].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[SAMPLE_TXAF_ARR].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[SAMPLE_TXAF_ARR].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleArrTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcArrTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcArrTxaf( ViSession instrSession,
                            ViInt32     ULim[],
                            ViInt32     LLim[],
                            ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status   = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[20][30];
   ViInt32   i              = 0;
   ViInt32   iU             = 0;
   ViInt32   iL             = 0;    
   ViInt32   mask           = 0;

      
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_RXAF].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // test upper lim
   sscanf(tab[0],"%d", &iU);
   sscanf(tab[1],"%d", &iL);
   
   
   for (i=0;i<20;i++)
   {

     mask = 1;
     if (i != 0)
      mask <<= i;
      
     if ((iU & mask) == mask)
        ULim[i] =  RSCMU_MEAS_MATCH_NMAU;
     else
        ULim[i] =  RSCMU_MEAS_MATCH_OK;
        
     if ((iL & mask) == mask)
        LLim[i] =  RSCMU_MEAS_MATCH_NMAL;
     else
        LLim[i] =  RSCMU_MEAS_MATCH_OK;
      
   }
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcArrTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadSubTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadSubTxaf( ViSession instrSession
                         , ViReal64  frequency[]
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[READ_TXAF_SUB].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[READ_TXAF_SUB].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[READ_TXAF_SUB].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadSubTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchSubTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchSubTxaf( ViSession instrSession
                          , ViReal64  frequency[]
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[FETCH_TXAF_SUB].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[FETCH_TXAF_SUB].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[FETCH_TXAF_SUB].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchSubTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleSubTxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleSubTxaf( ViSession instrSession
                           , ViReal64  frequency[]
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[SAMPLE_TXAF_SUB].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[SAMPLE_TXAF_SUB].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[SAMPLE_TXAF_SUB].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleSubTxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxAfanContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxAfanContRep( ViSession instrSession
                               , ViInt32   rep
                               , ViInt32   stopCondition
                               , ViInt32   step
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAFAN_REP, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxAfanContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxAfanContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxAfanContDefault( ViSession instrSession
                                   , ViBoolean enabled
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( RXAFAN_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxAfanContDefault()



/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxAfanLimits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxAfanLimits( ViSession instrSession
                              , ViReal64  min
                              , ViReal64  max
                              , ViReal64  distortion
                              , ViReal64  SINAD
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAFAN_LIMITS, &min, &max, &distortion, &SINAD );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_LIMITS].instrCommand
          , min
          , max
          , distortion
          , SINAD
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxAfanLimits()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxAfanLimitsDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxAfanLimitsDefault( ViSession instrSession
                                     , ViBoolean enabled
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( RXAFAN_LIMIT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_LIMIT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxAfanLimitsDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxAfanFilter
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxAfanFilter( ViSession instrSession
                              , ViInt32   Bandpass
                              , ViInt32   Weighting
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAFAN_FILT, &Bandpass, &Weighting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_FILT].instrCommand
          , bandpass.list[Bandpass]
          , weighting.list[Weighting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxAfanFilter()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxAfanFilterNotch
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxAfanFilterNotch (ViSession instrumentHandle,
                                                    ViInt32 NFilter,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
    
   if (p_globalvarBase->RSCMU_FW_Version <= RSCMU200_V3_50)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_50, errorMessage); 

   checkRange( RXAFAN_NOTCHFILT, &NFilter );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_NOTCHFILT].instrCommand
          , NotchFilter.list[NFilter]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );    

} // endof RSCMU_AMPS_ConfRxAfanFilterNotch()  

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxAfanFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxAfanFilterDefault( ViSession instrSession
                                     , ViBoolean enabled
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( RXAFAN_FILT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_FILT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxAfanFilterDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitRxAfan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitRxAfan( ViSession instrSession
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_RXAFAN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitRxAfan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortRxAfan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortRxAfan( ViSession instrSession
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_RXAFAN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortRxAfan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopRxAfan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopRxAfan( ViSession instrSession
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_RXAFAN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopRxAfan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueRxAfan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueRxAfan( ViSession instrSession
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_RXAFAN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueRxAfan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchRxAfanStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchRxAfanStatus( ViSession  instrSession
                               , ViInt32   *measurementStatus
                               , ViInt32   *CurrentStatCycleCount
                               , ViChar     errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[RXAFAN_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchRxAfanStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxAfanErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxAfanErep( ViSession instrSession
                            , ViInt32   measurementEventReporting
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAFAN_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxAfanErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalRxAfan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadScalRxAfan( ViSession  instrSession
                            , ViReal64  *AFVoltmeterV
                            , ViReal64  *AFSINADdB
                            , ViReal64  *AFDistortion
                            , ViReal64  *AFaudioFreq
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[READ_RXAFAN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINADdB );
   }
   else 
   {
      *AFSINADdB = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", AFDistortion );
   }
   else
   {
      *AFDistortion = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", AFaudioFreq );
   }
   else
   {
      *AFaudioFreq = RSCMU_NAN; 
   }
  
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadScalRxAfan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalRxAfan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchScalRxAfan( ViSession  instrSession
                             , ViReal64  *AFVoltmeterV
                             , ViReal64  *AFSINADdB
                             , ViReal64  *AFDistortion
                             , ViReal64  *AFaudioFreq
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[FETCH_RXAFAN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINADdB );
   }
   else 
   {
      *AFSINADdB = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", AFDistortion );
   }
   else
   {
      *AFDistortion = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", AFaudioFreq );
   }
   else
   {
      *AFaudioFreq = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchScalRxAfan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalRxAfan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleScalRxAfan( ViSession  instrSession
                              , ViReal64  *AFVoltmeterV
                              , ViReal64  *AFSINADdB
                              , ViReal64  *AFDistortion
                              , ViReal64  *AFaudioFreq
                              , ViChar     errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[SAMPLE_RXAFAN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINADdB );
   }
   else 
   {
      *AFSINADdB = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", AFDistortion );
   }
   else
   {
      *AFDistortion = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", AFaudioFreq );
   }
   else
   {
      *AFaudioFreq = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleScalRxAfan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalRxAfan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcScalRxAfan( ViSession  instrSession
                            , ViInt32   *AFVoltmeter
                            , ViInt32   *AFSINAD
                            , ViInt32   *AFDistortion
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_RXAFAN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( AFVoltmeter,  tab, 0 );
   RSCMU_GetMatchingLimit( AFSINAD,      tab, 1 );
   RSCMU_GetMatchingLimit( AFDistortion, tab, 2 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalRxAfan()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSINADContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSINADContRep( ViSession instrSession
                                      , ViInt32   rep
                                      , ViInt32   stopCondition
                                      , ViInt32   step
                                      , ViChar    errorMessage[]
                                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    


   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   checkRange( RX_SINAD_REP, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SINAD_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSINADContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSINADMeasTime
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSINADMeasTime( ViSession instrSession
                                    , ViReal64  measurementTime
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;
   
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   if( measurementTime < 0.025 )
   {
      measurementTime = 0.025;
   }
   else if( measurementTime > 1.0 )
   {
      measurementTime = 1.0;
   }
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SINAD_MTIME].instrCommand
          , measurementTime
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSINADMeasTime()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSINADContDef
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSINADContDef( ViSession instrSession
                                      , ViBoolean enabled
                                      , ViChar    errorMessage[]
                                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

      // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( RX_SINAD_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SINAD_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSINADContDef()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchRxSINADStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_FetchRxSINADStatus (ViSession instrSession,
                                                 ViInt32 *measurementStatus,
                                                 ViInt32 *CurrentStatCycleCount,
                                                 ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[RX_SINAD_STAT].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );


}


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSINADErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSINADErep (ViSession instrSession,
                                              ViInt32 measurementEventReporting,
                                              ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;    
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   checkRange( RX_SINAD_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SINAD_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadRxSINAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadRxSINAD( ViSession  instrSession
                                   , ViReal64  *AFVoltmeter_V
                                   , ViReal64  *AFSINAD_dB
                                   , ViReal64  *SINAD_at_Hz
                                   , ViChar     errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;    
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 
      
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[READ_RX_SINAD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeter_V );
   }
   else 
   {
      *AFVoltmeter_V = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINAD_dB );
   }
   else 
   {
      *AFSINAD_dB = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SINAD_at_Hz );
   }
   else
   {
      *SINAD_at_Hz = RSCMU_NAN;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadScalRxAfanVMSinad()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchRxSINAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchRxSINAD( ViSession  instrSession
                                    , ViReal64  *AFVoltmeter_V
                                    , ViReal64  *AFSINAD_dB
                                    , ViReal64  *SINAD_at_Hz
                                    , ViChar     errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;    
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 
      
 
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[FETCH_RX_SINAD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeter_V );
   }
   else 
   {
      *AFVoltmeter_V = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINAD_dB );
   }
   else 
   {
      *AFSINAD_dB = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SINAD_at_Hz );
   }
   else
   {
      *SINAD_at_Hz = RSCMU_NAN;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchScalRxAfanVMSinad()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleRxSINAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleRxSINAD( ViSession  instrSession
                                     , ViReal64  *AFVoltmeter_V
                                     , ViReal64  *AFSINAD_dB
                                     , ViReal64  *SINAD_at_Hz
                                     , ViChar     errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[SAMPLE_RX_SINAD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeter_V );
   }
   else 
   {
      *AFVoltmeter_V = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINAD_dB );
   }
   else 
   {
      *AFSINAD_dB = RSCMU_NAN; 
   }
  
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", SINAD_at_Hz );
   }
   else
   {
      *SINAD_at_Hz = RSCMU_NAN;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleScalRxAfanVMSinad()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcLimRxSINAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcLimRxSINAD( ViSession  instrSession
                                   , ViInt32   *AFVoltmeter
                                   , ViInt32   *AFSINAD
                                   , ViChar     errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;    
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_RX_SINAD].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( AFVoltmeter,  tab, 0 );
   RSCMU_GetMatchingLimit( AFSINAD,      tab, 1 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalRxAfanVMSinad()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitRxSINAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_InitRxSINAD (ViSession instrSession,
                                          ViChar errorMessage[])
{


   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_RX_SINAD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}
/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortRxSINAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC RSCMU_AMPS_AbortRxSINAD (ViSession instrSession,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;  
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 
 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABOR_RX_SINAD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}
/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopRxSINAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_StopRxSINAD (ViSession instrSession,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
    
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_RX_SINAD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueRxSINAD
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ContinueRxSINAD (ViSession instrSession,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;
 
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;    
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_RX_SINAD].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxHnContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxHnContRep( ViSession instrSession
                             , ViInt32   rep
                             , ViInt32   stopCondition
                             , ViInt32   step
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_HN_REP, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_HN_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxHnContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxHnContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxHnContDefault( ViSession instrSession
                                 , ViBoolean enabled
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( RX_HN_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_HN_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxHnContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxHnLimits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxHnLimits( ViSession instrSession
                            , ViReal64  min
                            , ViReal64  max
                            , ViReal64  humNoise
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_HN_LIMITS, &min, &max, &humNoise );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_HN_LIMITS].instrCommand
          , min
          , max
          , humNoise
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxHnLimits()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxHnLimitsDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxHnLimitsDefault( ViSession instrSession
                                   , ViBoolean enabled
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( RX_HN_LIMIT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_HN_LIMIT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxHnLimitsDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxHnFilter
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxHnFilter( ViSession instrSession
                            , ViInt32   Bandpass
                            , ViInt32   Weighting
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_HN_FILT, &Bandpass, &Weighting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_HN_FILT].instrCommand
          , bandpass.list[Bandpass]
          , weighting.list[Weighting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxHnFilter()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxHnFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxHnFilterDefault( ViSession instrSession
                                   , ViBoolean enabled
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( RX_HN_FILT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_HN_FILT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxHnFilterDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitRxHn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitRxHn( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_RX_HN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitRxHn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortRxHn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortRxHn( ViSession instrSession
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_RX_HN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortRxHn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopRxHn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopRxHn( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_RX_HN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopRxHn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueRxHn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueRxHn( ViSession instrSession
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_RX_HN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueRxHn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchRxHnStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchRxHnStatus( ViSession  instrSession
                             , ViInt32   *measurementStatus
                             , ViInt32   *CurrentStatCycleCount
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[RX_HN_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchRxHnStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxHnErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxHnErep( ViSession instrSession
                          , ViInt32   measurementEventReporting
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_HN_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_HN_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxHnErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalRxHn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadScalRxHn( ViSession  instrSession
                          , ViReal64  *AFVoltmeterV
                          , ViReal64  *humNoisedB
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[READ_RX_HN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", humNoisedB );
   }
   else 
   {
      *humNoisedB = RSCMU_NAN; 
   }
  
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadScalRxHn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalRxHn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchScalRxHn( ViSession  instrSession
                           , ViReal64  *AFVoltmeterV
                           , ViReal64  *humNoisedB
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[FETCH_RX_HN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", humNoisedB );
   }
   else 
   {
      *humNoisedB = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchScalRxHn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalRxHn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleScalRxHn( ViSession  instrSession
                            , ViReal64  *AFVoltmeterV
                            , ViReal64  *humNoisedB
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[SAMPLE_RX_HN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", humNoisedB );
   }
   else 
   {
      *humNoisedB = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleScalRxHn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalRxHn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcScalRxHn( ViSession  instrSession
                          , ViInt32   *AFVoltmeter
                          , ViInt32   *humNoise
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_RX_HN].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( AFVoltmeter, tab, 0 );
   RSCMU_GetMatchingLimit( humNoise,    tab, 1 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalRxHn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensTgtSinad
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSensTgtSinad( ViSession instrSession
                                , ViReal64  SINAD
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_SENS_SINAD, &SINAD );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SENS_SINAD].instrCommand
          , SINAD
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSensTgtSinad()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensTgtSinadRange
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSensTgtSinadRange( ViSession instrSession
                                     , ViReal64  range
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_SENS_TSE_RANGE, &range );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SENS_TSE_RANGE].instrCommand
          , range
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSensTgtSinadRange()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSensContDefault( ViSession instrSession
                                   , ViBoolean enabled
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( RX_SENS_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SENS_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSensContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensLimits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSensLimits( ViSession instrSession
                              , ViReal64  min
                              , ViReal64  max
                              , ViReal64  SINAD
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_SENS_LIMITS, &min, &max, &SINAD );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SENS_LIMITS].instrCommand
          , min
          , max
          , SINAD
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSensLimits()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensLimitsDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSensLimitsDefault( ViSession instrSession
                                     , ViBoolean enabled
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( RX_SENS_LIMIT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SENS_LIMIT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSensLimitsDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensFilter
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSensFilter( ViSession instrSession
                              , ViInt32   Bandpass
                              , ViInt32   Weighting
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_SENS_FILT, &Bandpass, &Weighting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SENS_FILT].instrCommand
          , bandpass.list[Bandpass]
          , weighting.list[Weighting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSensFilter()



/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxSensFilterNotch (ViSession instrumentHandle,
                                                    ViInt32 NFilter,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
    
   if (p_globalvarBase->RSCMU_FW_Version <= RSCMU200_V3_50)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_50, errorMessage); 

   checkRange( RXSENS_NOTCHFILT, &NFilter );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAFAN_NOTCHFILT].instrCommand
          , NotchFilter.list[NFilter]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );    


} // RSCMU_AMPS_ConfRxSensFilterNotch

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSensFilterDefault( ViSession instrSession
                                     , ViBoolean enabled
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }


   checkRange( RX_SENS_FILT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SENS_FILT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSensFilterDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitRxSens
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitRxSens( ViSession instrSession
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_RX_SENS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitRxSens()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortRxSens
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortRxSens( ViSession instrSession
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_RX_SENS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortRxSens()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopRxSens
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopRxSens( ViSession instrSession
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_RX_SENS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopRxSens()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueRxSens
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueRxSens( ViSession instrSession
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_RX_SENS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueRxSens()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchRxSensStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchRxSensStatus( ViSession  instrSession
                               , ViInt32   *measurementStatus
                               , ViInt32   *CurrentStatCycleCount
                               , ViChar     errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[RX_SENS_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchRxSensStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxSensErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxSensErep( ViSession instrSession
                            , ViInt32   measurementEventReporting
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RX_SENS_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RX_SENS_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxSensErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalRxSens
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadScalRxSens( ViSession  instrSession
                            , ViReal64  *AFVoltmeterV
                            , ViReal64  *AFSINADdB
                            , ViReal64  *sensitivitydBm
                            , ViReal64  *audioFreqHz
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
   ViInt32   attrTO;   
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Change Timeout to 10 sec
   RSCMU_Status = viGetAttribute( instrSession, VI_ATTR_TMO_VALUE, &attrTO );
   RSCMU_Status = viSetAttribute( instrSession, VI_ATTR_TMO_VALUE, 10000);

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[READ_RX_SENS].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Reset Timeout Value
   viSetAttribute( instrSession , VI_ATTR_TMO_VALUE, attrTO );
   
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINADdB );
   }
   else 
   {
      *AFSINADdB = RSCMU_NAN; 
   }

   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", sensitivitydBm );
   }
   else
   {
      *sensitivitydBm = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", audioFreqHz );
   }
   else
   {
      *audioFreqHz = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadScalRxSens()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalRxSens
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchScalRxSens( ViSession  instrSession
                             , ViReal64  *AFVoltmeterV
                             , ViReal64  *AFSINADdB
                             , ViReal64  *sensitivitydBm
                             , ViReal64  *audioFreqHz
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[FETCH_RX_SENS].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINADdB );
   }
   else 
   {
      *AFSINADdB = RSCMU_NAN; 
   }

   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", sensitivitydBm );
   }
   else
   {
      *sensitivitydBm = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", audioFreqHz );
   }
   else
   {
      *audioFreqHz = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchScalRxSens()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalRxSens
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleScalRxSens( ViSession  instrSession
                              , ViReal64  *AFVoltmeterV
                              , ViReal64  *AFSINADdB
                              , ViReal64  *sensitivitydBm
                              , ViReal64  *audioFreqHz
                              , ViChar     errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[SAMPLE_RX_SENS].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the response data
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", AFVoltmeterV );
   }
   else 
   {
      *AFVoltmeterV = RSCMU_NAN; 
   }
  
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", AFSINADdB );
   }
   else 
   {
      *AFSINADdB = RSCMU_NAN; 
   }

   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", sensitivitydBm );
   }
   else
   {
      *sensitivitydBm = RSCMU_NAN;
   }
    
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", audioFreqHz );
   }
   else
   {
      *audioFreqHz = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleScalRxSens()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalRxSens
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcScalRxSens( ViSession  instrSession
                            , ViInt32   *AFVoltmeter
                            , ViInt32   *AFSINAD
                            , ViInt32   *sensitivity
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_RX_SENS].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( AFVoltmeter, tab, 0 );
   RSCMU_GetMatchingLimit( AFSINAD,     tab, 1 );
   RSCMU_GetMatchingLimit( sensitivity, tab, 2 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalRxSens()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafContRep( ViSession instrSession
                             , ViInt32   rep
                             , ViInt32   stopCondition
                             , ViInt32   step
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_REP, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_DispRxafContGrid
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_DispRxafContGrid( ViSession instrSession
                              , ViBoolean gridLines
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_GRID, &gridLines );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_GRID].instrCommand
          , enable.list[gridLines]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_DispRxafContGrid()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafRefLvl
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafRefLvl( ViSession instrSession
                            , ViReal64  refLvl
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_REF_LVL, &refLvl );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_REF_LVL].instrCommand
          , refLvl
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafRefLvl()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafModgLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafModgLev (ViSession instrSession,
                                              ViInt32   MODGenControl,
                                              ViInt32   MODGenDeviationHz,
                                              ViChar    errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar   Format[WR_BUFFER_SIZE] = "\0";

   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   switch( MODGenControl)
   {
   case  RSCMU_AMPS_MODG_TLEV:
   
       
       strcpy(Format,AMPS[RXAF_MODG_FMOD].instrCommand);
       strcat(Format,";:\0");
       strcat(Format,AMPS[RXAF_MODG_TFD].instrCommand);
       
       sprintf (wrtBuf, Format, MODGen.list[MODGenControl],MODGenDeviationHz);
       
   break;
   
   case  RSCMU_AMPS_AFG_SLEV:
   
       sprintf( wrtBuf
          , AMPS[RXAF_MODG_FMOD].instrCommand
          , MODGen.list[MODGenControl]
          );
    
   break;
   }

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );   
                             
  return( RSCMU_Status );                             

} // end of RSCMU_AMPS_ConfRxafModgLev

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafModgCfac
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafModgCfac (ViSession instrumentHandle,
                                               ViInt32 crestFactor,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    
   checkRange( RXAF_CFACT, &crestFactor );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_CFACT].instrCommand
          , CRFactor.list[crestFactor]
          );
   
   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ConfRxafModgCfac()

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafHoldoff
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafHoldoff( ViSession instrSession
                             , ViReal64  holdoffTime
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_HOLDOFF, &holdoffTime );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_HOLDOFF].instrCommand
          , holdoffTime * 1E-3
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafHoldoff()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SourceRxafRefValue
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SourceRxafRefValue( ViSession instrSession
                                , ViInt32   reference
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_REF, &reference );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_REF].instrCommand
          , RxafRef.list[reference]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SourceRxafRefValue()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafContDefault( ViSession instrSession
                                 , ViBoolean enabled
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( RXAF_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_DispRxafTraceScale
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_DispRxafTraceScale( ViSession instrSession
                                , ViReal64  min
                                , ViReal64  max
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_SCALE, &min, &max );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_SCALE].instrCommand
          , min
          , max
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_DispRxafTraceScale()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfSubRxafMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfSubRxafMode( ViSession instrSession
                             , ViInt32   measurement
                             , ViInt32   numberofSubranges
                             , SUBARRAY  subranges
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[20];
   ViInt32   i;

   if( measurement < 1 )
   {
      return RSCMU_errorMessage( instrSession, RSCMU_ERROR_PARAMETER3, errorMessage );
   }
   
   checkRange( RXAF_SUBARR, &measurement, &numberofSubranges );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_SUBARR].instrCommand
          , Subarray.list[measurement]
          );

   // Handle variable number of subranges, max 32
   for( i = 0; i < numberofSubranges; i++ )
   {
      sprintf( temp
             , ", %d,%d"
             , subranges.elements[i].Start
             , subranges.elements[i].Samples
             );
      strcat( wrtBuf, temp );
   }
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfSubRxafMode()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafLimitLines
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafLimitLines( ViSession  instrSession
                                , ViInt32    area
                                , TEST_TONES tone
                                , ViChar     errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[40] = "\0";
   ViInt32   i;

   //checkRange( RXAF_LIMIT_TONE, &area );
   checkRange( RXAF_LIMIT_LINES, &area);

   
   for(i=0;i<20;i++) 
    checkRange( RXAF_LIMIT_TONE, &area, &i, &tone.element[i].Limit, &tone.element[i].Enabled );    
 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_LIMIT_LINES].instrCommand
          , LimitArea.list[area]
          );
   
   strcat(wrtBuf, "\0");
   
   // Handle section, max 20 tones
   for( i = 0; i < 20; i++ )
   {
      sprintf( temp
             , (i==0?" %lf,%s\0":", %lf,%s\0")
             , tone.element[i].Limit
             , enable.list[tone.element[i].Enabled]
             );
      strcat( wrtBuf, temp );
   }
   
   strcat( wrtBuf, "\0" );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafLimitLines()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafLimitTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafLimitTone( ViSession instrSession
                               , ViInt32   area
                               , ViInt32   tone
                               , ViReal64  limit
                               , ViBoolean enabled
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_LIMIT_TONE, &area, &tone, &limit, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_LIMIT_TONE].instrCommand
          , LimitArea.list[area]
          , tone
          , limit
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafLimitTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafLimitDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafLimitDefault( ViSession instrSession
                                  , ViBoolean enabled
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( RXAF_LIMIT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_LIMIT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafLimitDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafTestTones
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafTestTones( ViSession     instrSession
                               , RXAF_TONE_DEF tone
                               , ViChar        errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[20];
   ViInt32   i;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   strcpy( wrtBuf, AMPS[RXAF_TDEF].instrCommand );

   // Handle section, max 20 tones
   for( i = 0; i < 20; i++ )
   {
      if( i == 0 )
      {
         sprintf( temp
               , " %d,%d,%s"
               , tone.element[i].Freq
               , tone.element[i].Deviation
               , enable.list[tone.element[i].Enabled]
               );
      }
      else
      {
         sprintf( temp
               , ",%d,%d,%s"
               , tone.element[i].Freq
               , tone.element[i].Deviation
               , enable.list[tone.element[i].Enabled]
               );
      }
      strcat( wrtBuf, temp );
   }
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafTestTones()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafTestToneDefinition
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafTestToneDefinition( ViSession instrSession
                                        , ViInt32   tone
                                        , ViInt32   freq
                                        , ViInt32   deviation
                                        , ViBoolean enabled
                                        , ViChar    errorMessage[]
                                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_TDEF_TONE, &tone, &freq, &deviation, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_TDEF_TONE].instrCommand
          , tone
          , freq
          , deviation
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafTestToneDefinition()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafTestTonesDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafTestTonesDefault( ViSession instrSession
                                      , ViBoolean enabled
                                      , ViChar    errorMessage[]
                                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   checkRange( RXAF_TTONES_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_TTONES_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafTestTonesDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafFilter
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafFilter( ViSession instrSession
                            , ViInt32   Bandpass
                            , ViInt32   Weighting
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_FILT, &Bandpass, &Weighting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_FILT].instrCommand
          , bandpass.list[Bandpass]
          , weighting.list[Weighting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafFilter()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafFilterDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/
ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafFilterDefault( ViSession instrSession
                                   , ViBoolean enabled
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (enabled == RSCMU_OFF)
   {
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_AMPS_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( RXAF_FILT_DEF, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_FILT_DEF].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafFilterDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitRxaf( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_RXAF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortRxaf( ViSession instrSession
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_RXAF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopRxaf( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_RXAF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueRxaf( ViSession instrSession
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_RXAF].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchRxafStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchRxafStatus( ViSession  instrSession
                             , ViInt32   *measurementStatus
                             , ViInt32   *CurrentStatCycleCount
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[RXAF_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchRxafStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfRxafErep( ViSession instrSession
                          , ViInt32   measurementEventReporting
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( RXAF_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfRxafErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadRxafTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadRxafTone( ViSession  instrSession
                          , ViInt32    tone
                          , ViReal64  *freq
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( READ_RXAF_TONE, &tone );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[READ_RXAF_TONE].instrCommand
          , tone
          );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , wrtBuf
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", freq );
   }
   else 
   {
      *freq = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadRxafTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchRxafTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchRxafTone( ViSession  instrSession
                          , ViInt32    tone
                          , ViReal64  *freq
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( FETCH_RXAF_TONE, &tone );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[FETCH_RXAF_TONE].instrCommand
          , tone
          );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , wrtBuf
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", freq );
   }
   else 
   {
      *freq = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchRxafTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleRxafTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleRxafTone( ViSession  instrSession
                          , ViInt32    tone
                          , ViReal64  *freq
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SAMPLE_RXAF_TONE, &tone );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SAMPLE_RXAF_TONE].instrCommand
          , tone
          );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , wrtBuf
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", freq );
   }
   else 
   {
      *freq = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleRxafTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcScalRxafTone
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcScalRxafTone( ViSession  instrSession
                              , ViInt32    tone
                              , ViInt32   *limit
                              , ViChar     errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[15][30];
      
   checkRange( CALC_RXAF_TONE, &tone );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CALC_RXAF_TONE].instrCommand
          , tone
          );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , wrtBuf
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Evaluate the response data.
   RSCMU_GetMatchingLimit( limit, tab, 0 );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcScalRxafTone()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadArrRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadArrRxaf( ViSession instrSession
                         , ViReal64  frequency[]
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[READ_RXAF_ARR].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[READ_RXAF_ARR].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[READ_RXAF_ARR].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadArrRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchArrRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchArrRxaf( ViSession instrSession
                          , ViReal64  frequency[]
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[FETCH_RXAF_ARR].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[FETCH_RXAF_ARR].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[FETCH_RXAF_ARR].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endofRSCMU_AMPS_FetchArrRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleArrRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleArrRxaf( ViSession instrSession
                           , ViReal64  frequency[]
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[SAMPLE_RXAF_ARR].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[SAMPLE_RXAF_ARR].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[SAMPLE_RXAF_ARR].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleArrRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalcArrRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_CalcArrRxaf(  ViSession   instrSession,
                            ViInt32     ULim[],
                            ViInt32     LLim[],
                            ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status   = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[20][30];
   ViInt32   i              = 0;
   ViInt32   iU             = 0;
   ViInt32   iL             = 0;    
   ViInt32   mask           = 0;

      
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[CALC_RXAF].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // test upper lim
   sscanf(tab[0],"%d", &iU);
   sscanf(tab[1],"%d", &iL);
   
   
   for (i=0;i<20;i++)
   {

     mask = 1;
     if (i != 0)
      mask <<= i;
      
     if ((iU & mask) == mask)
        ULim[i] =  RSCMU_MEAS_MATCH_NMAU;
     else
        ULim[i] =  RSCMU_MEAS_MATCH_OK;
        
     if ((iL & mask) == mask)
        LLim[i] =  RSCMU_MEAS_MATCH_NMAL;
     else
        LLim[i] =  RSCMU_MEAS_MATCH_OK;
      
   }
   
   return( RSCMU_Status );

} // endof RSCMU_AMPS_CalcArrRxaf()
        

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadSubRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadSubRxaf( ViSession instrSession
                         , ViReal64  frequency[]
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[READ_RXAF_SUB].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[READ_RXAF_SUB].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[READ_RXAF_SUB].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadSubRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchSubRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchSubRxaf( ViSession instrSession
                          , ViReal64  frequency[]
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[FETCH_RXAF_SUB].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[FETCH_RXAF_SUB].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[FETCH_RXAF_SUB].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchSubRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleSubRxaf
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleSubRxaf( ViSession instrSession
                           , ViReal64  frequency[]
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , (ViChar *)AMPS[SAMPLE_RXAF_SUB].instrCommand
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if( (RSCMU_Status = RSCMU_Write( instrSession
                                     , (ViChar *)AMPS[SAMPLE_RXAF_SUB].instrCommand
                                     , RSCMU_STB_ON
                                     , strlen((ViChar *)AMPS[SAMPLE_RXAF_SUB].instrCommand)
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , frequency
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleSubRxaf()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SigUnitChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SigUnitChan( ViSession instrSession
                         , ViInt32   unit
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SIG_UNIT, &unit );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SIG_UNIT].instrCommand
          , FreqUnits.list[unit]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SigUnitChan()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ProcSigAvcChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus  _VI_FUNC // JMG CVIFUNC 
   RSCMU_AMPS_ProcSigAvcChannel( ViSession instrSession
                               , ViInt32   channel
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SIG_CHAN, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SIG_CHAN].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ProcSigAvcChannel()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ProcSigAvcChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus  _VI_FUNC // JMG CVIFUNC 
   RSCMU_AMPS_ProcBSSignalAvcLevel( ViSession instrSession
                                  , ViReal64  leveldBm
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( PROC_BSS_AVC_LVL, &leveldBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[PROC_BSS_AVC_LVL].instrCommand
          , leveldBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

}


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ProcSigAvcMAC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus  _VI_FUNC // JMG CVIFUNC 
   RSCMU_AMPS_ProcSigAvcMAC( ViSession instrSession
                           , ViInt32   MAC
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SIG_MAC, &MAC );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SIG_MAC].instrCommand
          , MAC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ProcSigAvcMAC()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ProcSigAvcSatPeakDev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus  _VI_FUNC // JMG CVIFUNC 
   RSCMU_AMPS_ProcSigAvcSatPeakDev( ViSession instrSession
                                  , ViInt32   SATPeakDeviation
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SIG_SAT_PEAK_DEV, &SATPeakDeviation );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SIG_SAT_PEAK_DEV].instrCommand
          , SATPeakDeviation
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ProcSigAvcSatPeakDev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ProcSigAvcSatScc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus  _VI_FUNC // JMG CVIFUNC 
   RSCMU_AMPS_ProcSigAvcSatScc( ViSession instrSession
                              , ViInt32   SATColorCode
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( SIG_SAT_SCC, &SATColorCode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SIG_SAT_SCC].instrCommand
          , SATColorCode
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
} // endof RSCMU_AMPS_ProcSigAvcSatScc()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ProcSigAction
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ProcSigAction( ViSession instrSession
                           , ViInt32   signallingState
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViInt32   currState;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if( (RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession
                                              , &currState
                                              , errorMessage
                                              )) < 0 )
   {
      return( RSCMU_Status );
   }

   checkRange( SIGNAL_ACTION, &signallingState );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   switch( signallingState )
   {
   case RSCMU_SON:
      // Be sure that CMU is in SOFF
      if( currState != RSCMU_AMPS_STATE_SOFF )
      {
         // do nothing
         return RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_INVALID_SIGN_STAT, errorMessage );
      }
      break;

   case RSCMU_SOFF:
      break;

   case RSCMU_CTM:   // Call to mobile
      // Be sure that CMU is in SON, REG and not in CEST.
      if( ((currState != RSCMU_AMPS_STATE_SON) && (currState != RSCMU_AMPS_STATE_REG)) || 
          (currState == RSCMU_AMPS_STATE_CEST) )
      {
         return RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_INVALID_SIGN_STAT, errorMessage );
      }
      break;

   case RSCMU_SMS:
      // Be sure that CMU is in REG state
      if( currState != RSCMU_AMPS_STATE_REG )
      {
         return RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_INVALID_SIGN_STAT, errorMessage );
      }
      break;

   case RSCMU_CREL:  // Release the call
      // Be sure that CMU is in CEST.
      if( currState != RSCMU_AMPS_STATE_CEST )
      {
        return RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_INVALID_SIGN_STAT, errorMessage);
      }
      break;
      
   case RSCMU_AMPS_FST:
      break;
      
   default:
      return RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_INVALID_SIGN_STAT, errorMessage);
   }
                             
   // Send command ONLY if no errors in the signalling state were detected!
   sprintf( wrtBuf
          , AMPS[SIGNAL_ACTION].instrCommand
          , sigAction.list[signallingState]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ProcSigAction()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSGlobal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSGlobal( ViSession instrSession
                          , ViInt32   controlChannel
                          , ViInt32   voiceChannel
                          , ViInt32   controlChannelMAC
                          , ViInt32   voiceChannelMAC
                          , ViReal64  controlChannelRFLeveldBm
                          , ViReal64  voiceChannelRFLeveldBm
                          , ViInt32   SATColorCode
                          , ViInt32   SATPeakDeviation
                          , ViInt32   SID
                          , ViChar    errorMessage[]
                          )
{
   ViStatus    RSCMU_Status = VI_SUCCESS;
   
   RSCMU_AMPS_ConfBSSignalAccChannel( instrSession, controlChannel, errorMessage );
   RSCMU_AMPS_ConfBSSignalAccLevel( instrSession, controlChannelRFLeveldBm, errorMessage );
   RSCMU_AMPS_ConfBSSignalAvcChannel( instrSession, voiceChannel, errorMessage );
   RSCMU_AMPS_ConfBSSignalAvcLevel( instrSession, voiceChannelRFLeveldBm, errorMessage );
   RSCMU_AMPS_ConfBSSignalSatPeakDev( instrSession, SATPeakDeviation, errorMessage );
   RSCMU_AMPS_ConfBSSignalSatScc( instrSession, SATColorCode, errorMessage );
   RSCMU_AMPS_ConfNetIdSID( instrSession, SID, errorMessage );
   RSCMU_AMPS_ConfNetCMAC( instrSession, controlChannelMAC, errorMessage );
   RSCMU_AMPS_ConfNetVMAC( instrSession, voiceChannelMAC, errorMessage );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfBSGlobal()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalAccChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalAccChannel( ViSession instrSession
                                    , ViInt32   channel
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_ACC_CHAN, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_ACC_CHAN].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfBSSignalAccChannel()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalAccLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalAccLevel( ViSession instrSession
                                  , ViReal64  level
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_ACC_LVL, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_ACC_LVL].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfBSSignalAccLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalAvcChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalAvcChannel( ViSession instrSession
                                    , ViInt32   channel
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_AVC_CHAN, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_AVC_CHAN].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfBSSignalAvcChannel()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalAvcLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalAvcLevel( ViSession instrSession
                                  , ViReal64  level
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_AVC_LVL, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_AVC_LVL].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfBSSignalAvcLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalSatPeakDev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalSatPeakDev( ViSession instrSession
                                    , ViInt32   peakDev
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_SAT_PEAK_DEV, &peakDev );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_SAT_PEAK_DEV].instrCommand
          , peakDev
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfBSSignalSatPeakDev()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalSatScc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalSatScc( ViSession instrSession
                                , ViInt32   SCC
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_SAT_SCC, &SCC );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_SAT_SCC].instrCommand
          , SCC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfBSSignalSatScc()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetIdSID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetIdSID( ViSession instrSession
                          , ViInt32   SID
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_ID_SID, &SID );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_ID_SID].instrCommand
          , SID
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_NetIdSID()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetIdDCC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetIdDCC( ViSession instrSession
                          , ViInt32   digitalColorCode
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_ID_DCC, &digitalColorCode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_ID_DCC].instrCommand
          , digitalColorCode
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetIdDCC()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetSModeRegHome
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetSModeRegHome( ViSession instrSession
                                 , ViBoolean enabled
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_REG_HOME, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_REG_HOME].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetSModeRegHome()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetSModeRegRoam
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetSModeRegRoam( ViSession instrSession
                                 , ViBoolean enabled
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_REG_ROAM, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_REG_ROAM].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetSModeRegRoam()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetSigModeIDMIN
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetSigModeIDMIN( ViSession  instrSession
                                 , ViChar    *SignalChan
                                 , ViChar     errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_SIG_IDMIN].instrCommand
          , SignalChan
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetSigModeIDMIN()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetReqSN
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetReqSN( ViSession instrSession
                          , ViBoolean enabled
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_REQ_SN, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_REQ_SN].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetReqSN()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetCMAC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetCMAC( ViSession instrSession
                         , ViInt32   level
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_CMAC, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_CMAC].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetCMAC()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetVMAC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetVMAC( ViSession instrSession
                         , ViInt32   level
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_VMAC, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_VMAC].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetVMAC()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetRCFM
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetRCFM( ViSession instrSession
                         , ViBoolean enabled
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_RCFM, &enabled );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_RCFM].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetRCFM()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetTimeoutLostConn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetTimeoutLostConn( ViSession instrSession
                                    , ViInt32   timeout
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_LORLINK, &timeout );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_LORLINK].instrCommand
          , timeout
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetTimeoutLostConn()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetTimeoutRegPeriod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetTimeoutRegPeriod( ViSession instrSession
                                     , ViInt32   timeout
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_RPERIOD, &timeout );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_RPERIOD].instrCommand
          , timeout
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetTimeoutRegPeriod()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_Registration
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_Registration( ViSession instrSession
                          , ViInt32   timeout
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Check timeout is between 1 and 60 seconds.
   if( timeout < 1 )
   {
      timeout = 1;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

  if( RSCMU_Status == VI_SUCCESS )
   {
      // Wait for mobile registration
      StartTime = clock() / CLOCKS_PER_SEC;
      while( (state != RSCMU_AMPS_STATE_REG) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
      {
         
         RSCMU_Delay(0.100);
         
         RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession
                                               , &state
                                               , errorMessage
                                               );
         DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
         if( DeltaTime >= timeout )
         {
            TimerExpired = RSCMU_TRUE;
         }
      }

      if( TimerExpired )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
      }
      else if( RSCMU_Status != VI_SUCCESS )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_CALL_FROM_MS_FAILED, errorMessage );
      }
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_Registration()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_Origination
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_Origination( ViSession instrSession
                         , ViInt32   timeout
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Check timeout is between 1 and 60 seconds.
   if( timeout < 1 )
   {
      timeout = 1;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   if( RSCMU_Status == VI_SUCCESS )
   {
      // Wait for mobile registration
      StartTime = clock() / CLOCKS_PER_SEC;
      while( (state != RSCMU_AMPS_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
      {
         
         RSCMU_Delay(0.1);

         
         RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession
                                               , &state
                                               , errorMessage
                                               );
         DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
         if( DeltaTime >= timeout )
         {
            TimerExpired = RSCMU_TRUE;
         }
      }

      if( TimerExpired )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
      }
      else if( RSCMU_Status != VI_SUCCESS )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_CALL_FROM_MS_FAILED, errorMessage );
      }
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_Origination()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_PagingCallToMS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_PagingCallToMS( ViSession instrSession
                            , ViInt32   timeout
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViStatus  status;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   ViInt32   attrTO;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Check timeout is between 1 and 60 seconds.
   if( timeout < 5 )
   {
      timeout = 5;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   RSCMU_Status = viGetAttribute( instrSession, VI_ATTR_TMO_VALUE, &attrTO );

   if( attrTO < (timeout * 1000) )
   {
      RSCMU_Status = viSetAttribute( instrSession
                                   , VI_ATTR_TMO_VALUE
                                   , timeout * 1000
                                   );
   }
   
   // Paging (call to MS).
   RSCMU_Status = RSCMU_AMPS_ProcSigAction( instrSession
                                          , RSCMU_CTM
                                          , errorMessage
                                          );
   
   // Wait for call released from MS
   StartTime = clock() / CLOCKS_PER_SEC;
   RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession
                                         , &state
                                         , errorMessage
                                         );
   while( (state != RSCMU_AMPS_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {
      
      RSCMU_Delay(0.1);
    
      
      RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= timeout )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   // Determine if the test passed.
   if( state != RSCMU_AMPS_STATE_CEST )
   {
      RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_CALL_TO_MS_FAILED, errorMessage );
   }
   else if( TimerExpired )
   {
      RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   
   // DO NOT use RSCMU_Status since we want to return the status of
   // the paging function!!
   status = viSetAttribute( instrSession , VI_ATTR_TMO_VALUE, attrTO );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_PagingCallToMS()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReleaseCallFromMS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReleaseCallFromMS( ViSession instrSession
                               , ViInt32   timeout
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Verify CMU is in CEST.
   RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession, &state, errorMessage );
   if( state != RSCMU_AMPS_STATE_CEST )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_AMPS_ERROR_INVALID_SIGN_STAT
                               , errorMessage
                               );
   }
   
   // Check timeout is between 1 and 60 seconds.
   if( timeout < 1 )
   {
      timeout = 1;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   // Wait for call released from MS
   StartTime = clock() / CLOCKS_PER_SEC;
   while( (state == RSCMU_AMPS_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {
      
     
     RSCMU_Delay(0.1);
      
      
      RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= timeout )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   if( TimerExpired )
   {
      RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   else if( RSCMU_Status != VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_RELEASE_TO_MS_FAILED, errorMessage );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReleaseCallFromMS()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReleaseCallFromBST
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReleaseCallFromBST( ViSession instrSession
                                , ViChar    errorMessage[]
                                )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViInt32  state        = 0;

   // Verify CMU is in CEST.
   RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession, &state, errorMessage );
   if( state != RSCMU_AMPS_STATE_CEST )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_AMPS_ERROR_INVALID_SIGN_STAT
                               , errorMessage
                               );
   }
   
   // Release the call.
   RSCMU_Status = RSCMU_AMPS_ProcSigAction( instrSession
                                          , RSCMU_CREL
                                          , errorMessage
                                          );

   if( RSCMU_Status == VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      if( state == RSCMU_AMPS_STATE_CEST )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_RELEASE_TO_MS_FAILED, errorMessage );
      }
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReleaseCallFromBST()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ProcSigState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ProcSigState( ViSession  instrSession
                          , ViInt32   *state
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[SIGNAL_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get signalling state
   if( strncmp( "SOFF", rdBuf, 4 ) == 0 )
   {
     *state = RSCMU_AMPS_STATE_SOFF;
   }
   else if( strncmp( "SON", rdBuf, 3 ) == 0 )  
   {
      *state = RSCMU_AMPS_STATE_SON;
   }
   else if( strncmp( "REG", rdBuf, 3 ) == 0 ) 
   {
      *state = RSCMU_AMPS_STATE_REG;  
   }
   else if( strncmp( "ALER", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_AMPS_STATE_ALRT;  
   }
   else if( strncmp( "CEST", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_AMPS_STATE_CEST;  
   }
   else if( strncmp( "CPEN", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_AMPS_STATE_CPEN;  
   }
   else if( strncmp( "RPEN", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_AMPS_STATE_RPEN;  
   }
    
   else if( strncmp( "FPEN", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_AMPS_STATE_FPEN;  
   }

   return( RSCMU_Status );

} // endof RSCMU_AMPS_ProcSigState()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfHandoffToAMPS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfHandoffToAMPS( ViSession instrSession
                               , ViInt32   voiceChannel
                               , ViInt32   voiceChannelMAC
                               , ViReal64  voiceChannelRFLeveldBm
                               , ViInt32   SATPeakDeviation
                               , ViInt32   SATColorCode
                               , ViChar    errorMessage[]
                               )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   
   RSCMU_AMPS_ConfBSSignalAvcChannelOCH( instrSession, voiceChannel, errorMessage );
   RSCMU_AMPS_ConfBSSignalAvcLevelOCH( instrSession, voiceChannelRFLeveldBm, errorMessage );
   RSCMU_AMPS_ConfBSSignalSatPeakDevOCH( instrSession, SATPeakDeviation, errorMessage );
   RSCMU_AMPS_ConfBSSignalSatSccOCH( instrSession, SATColorCode, errorMessage );
   RSCMU_AMPS_ConfNetVMACOCH( instrSession, voiceChannelMAC, errorMessage );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfHandoffToAMPS()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalAvcChannelOCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalAvcChannelOCH( ViSession instrSession
                                       , ViInt32   channel
                                       , ViChar    errorMessage[]
                                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_AVC_CHAN_OCH, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_AVC_CHAN_OCH].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
   
} // endof RSCMU_AMPS_ConfBSSignalAvcChannelOCH()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalAvcLevelOCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalAvcLevelOCH( ViSession instrSession
                                     , ViReal64  level
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_AVC_LVL_OCH, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_AVC_LVL_OCH].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
   
} // endof RSCMU_AMPS_ConfBSSignalAvcLevelOCH()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalSatPeakDevOCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalSatPeakDevOCH( ViSession instrSession
                                       , ViInt32   SATPeakDeviation
                                       , ViChar    errorMessage[]
                                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_SAT_PEAK_DEV_OCH, &SATPeakDeviation );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_SAT_PEAK_DEV_OCH].instrCommand
          , SATPeakDeviation
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
   
} // endof RSCMU_AMPS_ConfBSSignalSatPeakDevOCH()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfBSSignalSatSccOCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfBSSignalSatSccOCH( ViSession instrSession
                                   , ViInt32   SATColorCode
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( BSS_SAT_SCC_OCH, &SATColorCode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[BSS_SAT_SCC_OCH].instrCommand
          , SATColorCode
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
   
} // endof RSCMU_AMPS_ConfBSSignalSatSccOCH()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfNetVMACOCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfNetVMACOCH( ViSession instrSession
                            , ViInt32   level
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( CONF_NET_VMAC_OCH, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[CONF_NET_VMAC_OCH].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfNetVMACOCH()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_Handoff
 *
 * DESCRIPTION: This routine performs a handover from the Original Network 
 *              Session Handle (instrSession) to the Destination Network 
 *              Session Handle (DestinationHandle).
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_Handoff( ViSession instrSession
                     , ViSession DestinationHandle
                     , ViInt32   Target
                     , ViInt32   Timeout
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status   = VI_SUCCESS;
   ViBoolean Found          = RSCMU_FALSE;
   ViBoolean TimerExpired   = RSCMU_FALSE;
   ViChar    TargetName[30] = "";
   ViInt32   state          = 0;
   ViInt32   cnt            = 0;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   clock_t   StartTime;
   clock_t   DeltaTime;
   ViInt16   i;
   ViChar    tab[35][30];  

   if( Timeout < 5 )
   {
      Timeout = 5;
   }
   else if( Timeout > 60 )
   {
      Timeout = 60;
   }
   
   if( DestinationHandle == (ViSession)NULL )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_AMPS_ERROR_INVALID_HANDOVER_TARGET
                               , errorMessage
                               );
   }

   if( instrSession == (ViSession)NULL )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_ERROR_PARAMETER1
                               , errorMessage
                               );
   }

   // Get the 'HandOverSessionName' of the TargetSession
   strncpy( TargetName
          , HandoffTargets[Target]
          , strlen( HandoffTargets[Target] )
          );

   // Get pointers to buffers.
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   // Extract HandOver TargetList, compare TargetHandle with it.  
   if( (RSCMU_Status = RSCMU_Query( instrSession
                                  , "STATUS:HANDOFF:TARGET:LIST?"
                                  , rdBuf
                                  , RSCMU_STB_ON
                                  , errorMessage
                                  ) ) < 0 )
   {
      return( RSCMU_Status );
   }
 
   // Separate the CMU response:
   cnt = RSCMU_SeparateString( rdBuf, ",", tab );

   // Determine if the destination target was found in the list.
   for( i = 0; i < cnt; i++ )
   {
      if( strncmp( TargetName, tab[i], strlen(tab[i]) ) == 0 )
      {
         Found = RSCMU_TRUE;
      }
   }

   if( !Found )
   {
      return RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_INVALID_HANDOVER_TARGET, errorMessage ); 
   }

   // Be sured that RSCMU is in CEST.
   if( RSCMU_Status = RSCMU_AMPS_ProcSigState( instrSession, &state, errorMessage ) )
   {
      return( RSCMU_Status );
   }

   if( state != RSCMU_AMPS_STATE_CEST )
   {
      return RSCMU_errorMessage( instrSession, RSCMU_AMPS_ERROR_INVALID_SIGN_STAT, errorMessage );
   }
   
   // Configure basestation for a Handoff to an alternate network.
   sprintf( wrtBuf
          , AMPS[CONF_HANDOFF].instrCommand
          , TargetName
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Perform Handoff to alternate network.
   RSCMU_Status = RSCMU_Query( instrSession
                             , "PROC:SIGN:ACT HAND"
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Delay 1 second to allow CMU to process the message.
   StartTime = clock() / CLOCKS_PER_SEC;
   while( !TimerExpired )
   {
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= 0.025 )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }
   TimerExpired = RSCMU_FALSE;

   // Wait for handoff to be completed.
   RSCMU_Status = RSCMU_AMPS_ProcSigState( DestinationHandle
                                         , &state
                                         , errorMessage
                                         );
   StartTime = clock() / CLOCKS_PER_SEC;
   while( (state != RSCMU_AMPS_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {
      RSCMU_Status = RSCMU_AMPS_ProcSigState( DestinationHandle
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= Timeout )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   if( TimerExpired )
   {
      RSCMU_Status = RSCMU_errorMessage( DestinationHandle, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   else if( RSCMU_Status != VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_errorMessage( DestinationHandle, RSCMU_AMPS_ERROR_INVALID_HANDOVER_TARGET, errorMessage );
   }
   
   return( RSCMU_Status );
   

} // endof RSCMU_AMPS_Handoff()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseMobileInfoNum
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseMobileInfoNum( ViSession instrSession
                                , ViChar    infoNum[]
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[MSINFO_MIN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Number.
   // Remove leading and trailing " and add line terminator.
   strncpy( infoNum, &rdBuf[1], strlen(rdBuf) - 2 );
   infoNum[strlen(rdBuf) - 2] = '\0';
   
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseMobileInfoNum()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseMobileInfoSN
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseMobileInfoSN( ViSession instrSession
                               , ViChar    SN[]
                               , ViChar    errorMessage[]
                               )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[MSINFO_SN].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the ESN.
   // Remove leading and trailing " and add line terminator.
   strncpy( SN, &rdBuf[1], strlen(rdBuf) - 2 );
   SN[strlen(rdBuf) - 2] = '\0';
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseMobileInfoSN()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseMobileInfoPowClass
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseMobileInfoPowClass( ViSession  instrSession
                                     , ViInt32   *PowerClass
                                     , ViChar     errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[MSINFO_POW_CLASS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Number
   if( strcmp( &rdBuf[0], "NAN" ) != 0 )
   {
      sscanf( &rdBuf[0], "%d", PowerClass );
   }
   else 
   {
      *PowerClass = RSCMU_NAN_VI_INT32; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseMobileInfoPowClass()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseMobileInfoBandwidth
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseMobileInfoBandwidth( ViSession  instrSession
                                      , ViInt32   *bandwidth
                                      , ViChar     errorMessage[]
                                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[MSINFO_BAND].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Type
   if( strncmp( "NAN", rdBuf, 3 ) == 0 ) 
   {
      *bandwidth = 0;
   }
   else if( strncmp( "MH20", rdBuf, 4 ) == 0 )
   {
      *bandwidth = 1;
   }
   else if( strncmp( "MH25", rdBuf, 4 ) == 0 )
   {
      *bandwidth = 2;
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseMobileInfoBandwidth()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseMobileInfoMPCI
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseMobileInfoMPCI( ViSession  instrSession
                                 , ViInt32   *MPCI
                                 , ViChar     errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[MSINFO_MPCI].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported MPCI Type
   if( strcmp( &rdBuf[0], "NAN" ) != 0 )
   {
      sscanf( &rdBuf[0], "%d", MPCI );
   }
   else 
   {
      *MPCI = RSCMU_NAN_VI_INT32; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SenseMobileInfoMPCI()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SenseMobileInfoDialledNum
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SenseMobileInfoDialledNum( ViSession instrSession
                                       , ViChar    DialledNumber[]
                                       , ViChar    errorMessage[]
                                       )
{
   ViStatus RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[MSINFO_DIAL_NUM].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Number
   strncpy( DialledNumber, &rdBuf[1], strlen(rdBuf) - 2 );
   DialledNumber[strlen(rdBuf) - 2] = '\0';
    
   return( RSCMU_Status );

} // endofRSCMU_AMPS_SenseMobileInfoDialledNum()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfWPowContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfWPowContRep( ViSession instrSession
                             , ViInt32   rep
                             , ViInt32   stopCondition
                             , ViInt32   step
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( WPOW_REP, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[WPOW_REP].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfWPowContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_InitWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_InitWPow( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[INIT_WPOW].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_InitWPow()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_AbortWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_AbortWPow( ViSession instrSession
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[ABORT_WPOW].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_AbortWPow()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StopWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_StopWPow( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[STOP_WPOW].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_StopWPow()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ContinueWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      ViSession instrSession -
 *
 * OUTPUTS:     ViChar    errorMessage[]   -
 *
 * RETURN:      ViStatus  RSCMU_Status     -
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ContinueWPow( ViSession instrSession
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[CONT_WPOW].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ContinueWPow()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchWPowStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchWPowStatus( ViSession  instrSession
                             , ViInt32   *measurementStatus
                             , ViInt32   *CurrentStatCycleCount
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[WPOW_STATUS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Get the measurement status.
       RSCMU_Status = RSCMU_GetMeasurementStatus( rdBuf
                                                , ","
                                                , measurementStatus
                                                , CurrentStatCycleCount
                                                );
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchWPowStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfWPowErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ConfWPowErep( ViSession instrSession
                          , ViInt32   measurementEventReporting
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( WPOW_EREP, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[WPOW_EREP].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ConfWPowErep()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ReadScalWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_ReadScalWPow( ViSession  instrSession
                          , ViReal64  *burstPower
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[READ_WPOW].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", burstPower );
   }
   else 
   {
      *burstPower = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_ReadScalWPow()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_FetchScalWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_FetchScalWPow( ViSession  instrSession
                           , ViReal64  *burstPower
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[FETCH_WPOW].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", burstPower );
   }
   else 
   {
      *burstPower = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_FetchScalWPow()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SampleScalWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_SampleScalWPow( ViSession  instrSession
                            , ViReal64  *burstPower
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
      
   // Check if the function is correctly used:               
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   if( RSCMU_Status = RSCMU_Query( instrSession
                                 , (ViChar *)AMPS[SAMPLE_WPOW].instrCommand
                                 , rdBuf
                                 , RSCMU_STB_ON
                                 , errorMessage
                                 ) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Get the response data
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", burstPower );
   }
   else 
   {
      *burstPower = RSCMU_NAN; 
   }
    
   return( RSCMU_Status );

} // endof RSCMU_AMPS_SampleScalWPow()




/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_Close
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC 
   RSCMU_AMPS_Close( ViSession instrSession
                   , ViChar    errorMessage[]
                   )
{
   ViStatus RSCMU_Status = VI_SUCCESS;  
   struct RSCMU_AMPS_Globals *p_globalvarAMPS;

   if( (RSCMU_Status = viGetAttribute( instrSession
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarAMPS
                                     )) < 0 )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_Status
                               , errorMessage
                               );
   }

   // Deallocate all system resources allocated to the AMPS Session:
   if( (RSCMU_Status = viClose( instrSession )) < 0 )
   {
      return( RSCMU_Status );
   }
    
   // Deallocate the space pointed by p_globalvarAMPS:
   if( p_globalvarAMPS )
   {
      free( p_globalvarAMPS );
   }

   return( RSCMU_Status );

} // endof RSCMU_AMPS_Close()


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_CalculatePower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC RSCMU_AMPS_CalculatePower (ViSession      instrumentHandle,
                                                ViReal64    nominalPowerdBm,
                                                ViReal64    tolerancePosdB,
                                                ViReal64    toleranceNegdB,
                                                ViReal64    powerdBm,
                                                ViInt32     *powerMatch,
                                                ViChar      errorMessage[])
{
   
   ViStatus RSCMU_Status = VI_SUCCESS;  
      
      if ((powerdBm >= nominalPowerdBm + toleranceNegdB) && (powerdBm <= nominalPowerdBm + tolerancePosdB))
         *powerMatch = VI_ON;
      else
         *powerMatch = VI_OFF;
         
      
      return( RSCMU_Status ); 
   
} // endof RSCMU_AMPS_CalculatePower()

/**************************************************************************
 *
 * NAME:        checkRange
 *
 * DESCRIPTION: This routine is responsible for range limiting the 
 *              parameters to be within the defined legal values for a
 *              variable number of arguments.
 *
 * INPUTS:      ViInt32 cmd - index into the AMPS command table
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       This routine is passed a variable number of parameters based
 *              on the command to be executed.
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

static void checkRange( ViInt32 cmd, ... )
{
   va_list     params;
   ViInt32     i;
   ViInt32     type;
   ViInt32    *iValue;
   ViReal64   *fValue;

   // init variable arguments
   va_start( params, cmd );
   
   // range check each parameter
   for( i = 0; i < AMPS[cmd].xmit->num; i++ )
   {
      // determine variable type
      type = AMPS[cmd].xmit->p[i].i.type;
      switch( type )
      {
      case INTEGER_TYPE:
         iValue = va_arg( params, ViInt32* );         
      
         if( *iValue > AMPS[cmd].xmit->p[ i ].i.max )
         {
            *iValue = AMPS[cmd].xmit->p[ i ].i.max;
         }
         else if( *iValue < AMPS[cmd].xmit->p[ i ].i.min )
         {
            *iValue = AMPS[cmd].xmit->p[ i ].i.min;
         }
         break;
         
      case FLOAT_TYPE:
         fValue = va_arg( params, ViReal64* );
        
         if( *fValue > AMPS[cmd].xmit->p[ i ].i.max )
         {
            *fValue = AMPS[cmd].xmit->p[ i ].i.max;
         }
         else if( *fValue < AMPS[cmd].xmit->p[ i ].i.min )
         {
            *fValue = AMPS[cmd].xmit->p[ i ].i.min;
         }
         break;
         
      case STRING_30_TYPE:
      default:
         break;
      }
   }
   
   // reset variable arguments
   va_end( params );
   
} // endof checkRange()


/**************************************************************************
 *
 * NAME:        getBuffers
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

static ViStatus getBuffers( ViSession   instrSession
                          , ViChar    **wrtBuf
                          , ViChar    **rdBuf
                          , ViChar      errorMessage[]
                          )
{
   ViStatus RSCMU_Status = VI_SUCCESS;  
   struct RSCMU_AMPS_Globals *p_globalvarAMPS;

   if( (RSCMU_Status = viGetAttribute( instrSession
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarAMPS
                                     )) < 0 )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_Status
                               , errorMessage
                               );
   }
   
   *wrtBuf = &(p_globalvarAMPS->RSCMU_tGlobal.wrtBuf[0]);
   *rdBuf  = &(p_globalvarAMPS->RSCMU_tGlobal.rdBuf[0]);

   return( RSCMU_Status );

} // endof getBufers()


/**************************************************************************
 *
 * NAME:        RSCMU_errorMessage
 *
 * DESCRIPTION: This function translates the error return value from the
 *              instrument driver into a user-readable string.   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

static ViStatus RSCMU_errorMessage( ViSession       instrSession
                                  , ViStatus        statusCode
                                  , ViChar _VI_FAR  message[]
                                  )
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViInt16  i;
    
    /*************************************************************************/
    /* RSCMU_stringValPair is used in the RSCMU_errorMessage function
    /*************************************************************************/
    typedef struct  RSCMU_stringValPair
    {
        ViStatus stringVal;
        ViString stringName;
    }  RSCMU_tStringValPair;
    
    #define AMPS_EXPAND(id, value, text) {id, text},
    RSCMU_tStringValPair statusDescArray[] = {
        RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_AMPS
    };
    #define NUM_AMPS_ERRORS (sizeof(statusDescArray) / sizeof(RSCMU_tStringValPair))
    #undef AMPS_EXPAND

    #define EXPAND(id, value, text) {id, text},
    RSCMU_tStringValPair baseDescArray[] = {
        RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES
    };
    #define NUM_BASE_ERRORS (sizeof(baseDescArray) / sizeof(RSCMU_tStringValPair))
    #undef EXPAND

    strcpy( message, "No Error" );

    RSCMU_Status = viStatusDesc( instrSession, statusCode, message );
    if( RSCMU_Status == VI_WARN_UNKNOWN_STATUS )
    {
        // Search RSCMU base errors.
        for( i=0; (i < NUM_BASE_ERRORS) && baseDescArray[i].stringName; i++ )
        {
            if( baseDescArray[i].stringVal == statusCode )
            {
                strcpy( message, baseDescArray[i].stringName );
                return( statusCode );
            }
        }

        // Search AMPS specific errors.
        for( i=0; (i < NUM_AMPS_ERRORS) && statusDescArray[i].stringName; i++ )
        {
            if( statusDescArray[i].stringVal == statusCode )
            {
                strcpy( message, statusDescArray[i].stringName );
                return( statusCode );
            }
        }
        sprintf( message, "Unknown Error 0x%08lX", statusCode );
        return( VI_WARN_UNKNOWN_STATUS );
    }
    else if( RSCMU_Status == VI_ERROR_USER_BUF )
    {
      sprintf( message, "The user buffer is not valid for the required size." );
      return( VI_ERROR_USER_BUF );
    }
    
    // Here the call was successful:
    return( statusCode );

} // endof RSCMU_errorMessage()


/**************************************************************************
 *
 * NAME:        RSCMU_SeparateString
 *
 * DESCRIPTION: This function breaks a string into tokens, which are separated
 *              by one specified delimiter character.
 *
 *              The resultant strings are placed in 'Tokens'.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

static ViInt32 RSCMU_SeparateString( ViChar StringToSeparate[]
                                   , ViChar Delimiters[]
                                   , ViChar Tokens[15][30]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViChar   *Token;
   ViInt16   Index = 0;
   ViInt32   cnt   = 0;

   Token = strtok( StringToSeparate, Delimiters );
  
   while( Token )
   {
      strcpy( Tokens[Index++], Token );
      Token = strtok( NULL, Delimiters );
      cnt++;
   }
  
   while( Index < 15 )
   {
      strcpy( Tokens[Index++], "" );
   }
  
   return( cnt );
   
}


/**************************************************************************
 *
 * NAME:        RSCMU_GetMeasurementStatus
 *
 * DESCRIPTION: This function is called to get the measurement status.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

static ViStatus RSCMU_GetMeasurementStatus( ViChar   StringToSeparate[]
                                          , ViChar   Delimiters[]
                                          , ViInt32 *MeasStatus
                                          , ViInt32 *Count
                                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViChar   *Token;

   // Get the measurement status.
   Token = strtok( StringToSeparate, Delimiters ); 
   if( strncmp( "OFF", Token, 3 ) == 0 )  
   {
      *MeasStatus = RSCMU_MEAS_STAT_OFF;
   }
   else if( strncmp( "RUN", Token, 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STAT_RUN;
   }
   else if( strncmp( "STOP", Token, 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STAT_STOP;
   }
   else if( strncmp( "ERR", Token, 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STAT_ERR;
   }
   else if( strncmp( "STEP", Token, 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STAT_STEP;
   }
   else if( strncmp( "RDY", Token, 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STAT_RDY; 
   }
   else
   {
      *MeasStatus = 0xFF;
   }

   // Get the counter for current statistics cycle
   Token = strtok( NULL, Delimiters );
   if( strcmp( Token, "NONE" ) != 0 )
   {
      sscanf( Token, "%d", Count );
   }
   else
   {
      *Count = RSCMU_OFF;
   }

   return( RSCMU_Status );
   
} // endof RSCMU_GetMeasurementStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_ReturnArrayValues
 *
 * DESCRIPTION: This function returns the values from the array string.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

static void RSCMU_ReturnArrayValues( ViChar inBuf[], ViReal64 values[] )
{
   ViChar  *adr;
   ViInt32  i = 0;
   
   adr = strtok( inBuf, "," );
  
   while( adr )
   {
      if( strcmp(adr, "NAN") != 0 )
      {    
         sscanf( adr, "%lf", &values[i] ); 
      }
      else
      
      {
         values[i] = RSCMU_NAN;
      }
      adr = strtok( NULL, "," );
      i++;
   }

} // endof RSCMU_ReturnArrayValues()


/**************************************************************************
 *
 * NAME:        RSCMU_GetMatchingLimit
 *
 * DESCRIPTION: This function is call to get the measure matching.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

static ViStatus  RSCMU_GetMatchingLimit( ViInt32 *Match
                                       , ViChar   tab[15][30]
                                       , ViInt32  NbBox
                                       )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   // For All Measured Values
   if( strncmp( "NMAU", tab[NbBox], 4 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_NMAU;
   }
   else if( strncmp( "NMAL", tab[NbBox], 4 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_NMAL;
   }
   else if( strncmp( "INV", tab[NbBox], 3 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_INV;
   }
   else if( strncmp( "OK", tab[NbBox], 2 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_OK;
   }

   return( RSCMU_Status );
   
} // endof RSCMU_GetMatchingLimit()

/* Ex Functions (No structures) */

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfSubTxafMode_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_AMPS_ConfSubTxafMode_Ex (ViSession instrSession,
                                                 ViInt32 measurement,
                                                 ViInt32 numberofSubranges,
                                                 ViInt32 start[],
                                                 ViInt32 samples[],
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[20];
   ViInt32   i;

   if( numberofSubranges < 1 )
   {
      return RSCMU_errorMessage( instrSession, RSCMU_ERROR_PARAMETER3, errorMessage );
   }
   
   checkRange( TXAF_SUBARR, measurement, numberofSubranges );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_SUBARR].instrCommand
          , Subarray.list[measurement]
          );

   // Handle variable number of subranges, max 32
   for( i = 0; i < numberofSubranges; i++ )
   {
      sprintf( temp
             , ", %d,%d"
             , start[i]
             , samples[i]
             );
      strcat( wrtBuf, temp );
   }
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfSubRxafMode_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_AMPS_ConfSubRxafMode_Ex (ViSession instrSession,
                                                 ViInt32 measurement,
                                                 ViInt32 numberofSubranges,
                                                 ViInt32 start[],
                                                 ViInt32 samples[],
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[20];
   ViInt32   i;

   if( numberofSubranges < 1 )
   {
      return RSCMU_errorMessage( instrSession, RSCMU_ERROR_PARAMETER3, errorMessage );
   }
   
   checkRange( RXAF_SUBARR, measurement, numberofSubranges );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_SUBARR].instrCommand
          , Subarray.list[measurement]
          );

   // Handle variable number of subranges, max 32
   for( i = 0; i < numberofSubranges; i++ )
   {
      sprintf( temp
             , ", %d,%d"
             , start[i]
             , samples[i]
             );
      strcat( wrtBuf, temp );
   }
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafLimitLines_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafLimitLines_Ex (ViSession instrSession,
                                                    ViInt32 area,
                                                    ViReal64 limit[],
                                                    ViInt32 enabled[],
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[40];
   ViInt32   i;

//   checkRange( TXAF_LIMIT_TONE, area );
   checkRange( TXAF_LIMIT_LINES, &area);

   
   for(i=0;i<20;i++) 
    checkRange( TXAF_LIMIT_TONE, &area, &i, &limit[i], &enabled[i] );    

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[TXAF_LIMIT_LINES].instrCommand
          , LimitArea.list[area]
          );
          
   strcat(wrtBuf, "\0");

   // Handle section, max 20 tones
   for( i = 0; i < 20; i++ )
   {
      sprintf( temp
             , (i==0?" %6.2lf,%s\0":",%6.2lf,%s\0")
             , limit[i]
             , enabled[i]
             );
             
      strcat( wrtBuf, temp );
   }
   
   strcat( wrtBuf, "\0");

   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafLimitLines_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafLimitLines_Ex (ViSession instrSession,
                                                    ViInt32 area,
                                                    ViReal64 limit[],
                                                    ViInt32 enabled[],
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[20];
   ViInt32   i;

   checkRange( RXAF_LIMIT_LINES, &area);

   
   for(i=0;i<20;i++) 
    checkRange( RXAF_LIMIT_TONE, &area, &i, &limit[i], &enabled[i] );    
 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[RXAF_LIMIT_LINES].instrCommand
          , LimitArea.list[area]
          );
   
   strcat(wrtBuf, "\0");
   
   // Handle section, max 20 tones
   for( i = 0; i < 20; i++ )
   {
      sprintf( temp
             , (i==0?" %lf,%s\0":", %lf,%s\0")
             , limit[i]
             , enabled[i]
             );
      strcat( wrtBuf, temp );
   }
   
   strcat( wrtBuf, "\0" );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfTxafTestTones_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_AMPS_ConfTxafTestTones_Ex (ViSession instrSession,
                                                   ViInt32 frequency[],
                                                   ViReal64 level[],
                                                   ViInt32 enabled[],
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar   buffout[RD_BUFFER_SIZE_ARRAY]="\0";
   ViChar    temp[20];
   ViInt32   i;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   strcpy( buffout, AMPS[TXAF_TDEF].instrCommand );

   // Handle section, max 20 tones
   for( i = 0; i < 20; i++ )
   {
      if( i == 0 )
      {
         sprintf( temp
               , " %d,%6.4lf,%s"
               , frequency[i]
               , level[i]
               , enable.list[enabled[i]]
               );
      }
      else
      {
         sprintf( temp
               , ", %d,%6.4lf,%s"
               , frequency[i]
               , level[i]
               , enable.list[enabled[i]]
               );
      }
      strcat( buffout, temp );
   }
   
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , buffout
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             

    
   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_ConfRxafTestTones_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_AMPS_ConfRxafTestTones_Ex (ViSession instrSession,
                                                   ViChar errorMessage[],
                                                   ViInt32 frequency[],
                                                   ViInt32 deviation[],
                                                   ViInt32 enabled[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    temp[20];
   ViInt32   i;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   strcpy( wrtBuf, AMPS[RXAF_TDEF].instrCommand );

   // Handle section, max 20 tones
   for( i = 0; i < 20; i++ )
   {
      if( i == 0 )
      {
         sprintf( temp
               , " %d,%d,%s"
               , frequency[i]
               , deviation[i]
               , enable.list[enabled[i]]
               );
      }
      else
      {
         sprintf( temp
               , ", %d,%d,%s"
               , frequency[i]
               , deviation[i]
               , enable.list[enabled[i]]
               );
      }
      strcat( wrtBuf, temp );
   }
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );
    
}

/*===========================================================================*/
/* Function: RSCMU_AMPS_GetResourceName                                      */
/* Purpose:  This function returns resource descriptor for AMPS option.      */
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_AMPS_GetResourceName (ViSession instrSession,
                                              ViSession instrSessionBase,
                                              ViChar _VI_FAR sessionName[])
{
   ViStatus    RSCMU_Status   = VI_SUCCESS;  
   ViInt32     comp;

   struct RSCMU_Base_Globals  *p_globalvarBase;
   struct RSCMU_AMPS_Globals  *p_globalvarAMPS;

    /* Get a copy of the global data for base session. */
   if( (RSCMU_Status = viGetAttribute( instrSessionBase
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarBase
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }
   
   /* Get a copy of the global data for this session. */
   if( (RSCMU_Status = viGetAttribute( instrSession
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarAMPS
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }
   
      // Hardware Connection
      comp = strncmp( "GPIB"
                    , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                    , 4
                    ); 

   if( comp == 0 )
      {
         sprintf( sessionName
                , "%s::%d::%d::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address
                , p_globalvarAMPS->RSCMU_tGlobal.RSCMU_secondary_address
                );
      }
      else
      {
         sprintf( sessionName
                , "%s::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                );
      }

   return RSCMU_Status;
}

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_GPIB_Timeout
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_AMPS_GPIB_Timeout (ViSession instrumentHandle,
                                           ViUInt32 timeout_in_ms,
                                           ViChar errorMessage[])
{
    ViStatus  RSCMU_Status = VI_SUCCESS;  
    

    RSCMU_Status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, timeout_in_ms);

    if (RSCMU_Status != VI_SUCCESS)
        viStatusDesc (instrumentHandle, RSCMU_Status, errorMessage);    
        
    return( RSCMU_Status );     
}


/**************************************************************************
 *
 * NAME:        RSCMU_RSCMU_AMPS_Reset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
                                 
ViStatus _VI_FUNC RSCMU_AMPS_Reset (ViSession instrSession, ViUInt32 MAX_timeout_in_ms, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViUInt32 timeout_in_ms;
   
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   
   RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_TMO_VALUE, &timeout_in_ms);
   RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, MAX_timeout_in_ms);
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[RESET_AMPS].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, timeout_in_ms);
   
   return( RSCMU_Status );
} // end RSCMU_RSCMU_AMPS_Reset
   
/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StatOperSymbEnab
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_AMPS_SetCmuVersion (ViSession   instrumentHandle,
                                            ViChar      firmwareVersion[],
                                            ViChar      errorMessage[])
{
 ViStatus    RSCMU_Status           = VI_SUCCESS;
 ViInt32     CurrentVersion         = 241;
 struct      RSCMU_SESSION_Globals  *p_globalvarBase;    
   
   // Get the global structure
 if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
       return RSCMU_Status;                                        

 strcpy (p_globalvarBase->CmuVersion, firmwareVersion);
 RSCMU_Status = RSCMU_CurrentVersion (instrumentHandle, &CurrentVersion, errorMessage);

 p_globalvarBase->RSCMU_FW_Version = CurrentVersion;

 return( RSCMU_Status );
    
} // end of RSCMU_AMPS_SetCmuVersion

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StatOperSymbEnab
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*$BC*/

ViStatus _VI_FUNC RSCMU_AMPS_StatOperSymbEnab (ViSession instrSession,
                                               ViBoolean CFM, 
                                               ViBoolean RFM,
                                               ViBoolean LORL, 
                                               ViBoolean MREG,
                                               ViBoolean MINV, 
                                               ViBoolean RFNS, 
                                               ViBoolean MDER, 
                                               ViBoolean TCH,
                                               ViBoolean RFIO,
                                               ViBoolean RFIU,
                                               ViBoolean AFIO,
                                               ViBoolean AFIU,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar   temp[80];
   
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   
   
   strcpy(temp, "\0");
   
   if (CFM != 65535)
     strcat(temp, SRS[RSCMU_AMPS_CFM]);

   if (RFM != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_RFM]);
     
   }
   
   if (LORL != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_LORL]);
     
   }   
   
   if (MREG != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_MREG]);
     
   }

   if (MINV != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_MINV]);
     
   }

   if (RFNS != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_RFNS]);
     
   }

   
   if (MDER != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_MDER]);
     
   }
   
   if (TCH != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_TCH]);
     
   }

   if (RFIO != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_RFIO]);
     
   }
   

   if (RFIU != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_RFIU]);
     
   }
   
   if (AFIO != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_AFIO]);
     
   }
   

   if (AFIU != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_AMPS_AFIU]);
     
   }
   
   if (strlen(temp) == 0) 
    sprintf(wrtBuf,AMPS[AMPS_STAT_OPER_SYMB].instrCommand,"NONE");
   else
    sprintf(wrtBuf,AMPS[AMPS_STAT_OPER_SYMB].instrCommand,temp);
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

    
} // end of RSCMU_AMPS_StatOperSymbEnab   

/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_StatOperSymbEvent
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_StatOperSymbEvent (ViSession   instrSession,
                                                ViInt32     *nb,
                                                ViInt32     *statusOperEvent,
                                                ViChar      SstatusOperEvent[],
                                                ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar   Sevent[35][30];
   ViInt32  i = 0; // JMG
   ViInt32  n = 0; // JMG

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)AMPS[AMPS_READ_OPER_SYMB].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
    
       // Separate the CMU response:
       *nb= RSCMU_SeparateString( rdBuf, ",", Sevent );
       
       *statusOperEvent = 0;
       strcpy(SstatusOperEvent, "\0");

       for (i=0;i<*nb;i++)
       {
           
           if (strncmp("NONE", Sevent[i], 4) == 0)
           {
                
                *statusOperEvent =  0;
                strcat(SstatusOperEvent, SRS[16]);
                strcat(SstatusOperEvent, ",\0");    
                
            }
                
           
           if ((strncmp(SRS[RSCMU_AMPS_CFM],Sevent[i],3) == 0)  || (strncmp("E1",Sevent[i],2) == 0))
           {
                *statusOperEvent    =  *statusOperEvent + 1;
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_CFM]);
                strcat(SstatusOperEvent,",\0");
           }
           
           if ((strncmp(SRS[RSCMU_AMPS_RFM],Sevent[i],3) == 0)  || (strncmp("E2", Sevent[i],2) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 2;
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_RFM]);
                strcat(SstatusOperEvent,",\0");
           }
    

           if ((strncmp(SRS[RSCMU_AMPS_LORL],Sevent[i],4) == 0) || (strncmp("E3", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 4;
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_LORL]);
                strcat(SstatusOperEvent,",\0");
           }
                
   
           if ((strncmp(SRS[RSCMU_AMPS_MREG],Sevent[i],4) == 0) || (strncmp("E4", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 8;
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_MREG]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_AMPS_MINV],Sevent[i],4) == 0) || (strncmp("E5", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 16;
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_MINV]);
                strcat(SstatusOperEvent,",\0");
           }
                
            
           if (strncmp("E6", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 32;
                strcat(SstatusOperEvent, SRS[5]);
                strcat(SstatusOperEvent,",\0");
           }
                
            
           if ((strncmp(SRS[RSCMU_AMPS_RFNS],Sevent[i],4) == 0) || (strncmp("E7", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 64;
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_RFNS]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_AMPS_MDER],Sevent[i],4) == 0) || (strncmp("E8", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 128;
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_MDER]);
                strcat(SstatusOperEvent,",\0");
           }
            

           if (strncmp("E9", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 256;
                strcat(SstatusOperEvent, SRS[8]);
                strcat(SstatusOperEvent,",\0");
           }
                
   
           if ((strncmp(SRS[RSCMU_AMPS_TCH],Sevent[i],3) == 0)  || (strncmp("E10", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 512;
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_TCH]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if (strncmp("E11", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 1024;
                strcat(SstatusOperEvent, SRS[10]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_AMPS_RFIO],Sevent[i], 4) == 0) || (strncmp("E12", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 2048;   
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_RFIO]);
                strcat(SstatusOperEvent,",\0");
           }
                
    
           if ((strncmp(SRS[RSCMU_AMPS_RFIU], Sevent[i], 4) == 0) || (strncmp("E13", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 4096;   
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_RFIU]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_AMPS_AFIO], Sevent[i], 4) == 0) || (strncmp("E14", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 8192;   
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_AFIO]);
                strcat(SstatusOperEvent,",\0");
           }
                
    
           if ((strncmp(SRS[RSCMU_AMPS_AFIU], Sevent[i], 4) == 0) || (strncmp("E15", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 16384; 
                strcat(SstatusOperEvent, SRS[RSCMU_AMPS_AFIU]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if (strncmp("E16", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 32768;
                strcat(SstatusOperEvent, SRS[15]);
                strcat(SstatusOperEvent,",\0");
           }
                
        } 
        
        if (*statusOperEvent == 0) *nb = 0;
    }
    
   return( RSCMU_Status );
    
}  // end of RSCMU_AMPS_StatOperSymbEvent  


/**************************************************************************
 *
 * NAME:        RSCMU_AMPS_SetConfProc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_AMPS_SetConfProc (ViSession instrumentHandle,
                                          ViBoolean enabled,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status; 
    
    
   if (p_globalvarBase->RSCMU_FW_Version <= RSCMU200_V3_50)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_50, errorMessage); 
    
   checkRange( SET_CONF_PROC, &enabled );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , AMPS[SET_CONF_PROC].instrCommand
          , enable.list[enabled]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

}  // end of RSCMU_AMPS_SetConfProc


/* End of Ex Functions (No structures) */

/*###########################################################################*/
/*                                                                           */
/*  VXI PLUG & PLAY COMPATIBILITY FUNCTIONS                                  */
/*                                                                           */
/*  These functions provide a VXIplug&play compatibily of this instrument    */
/*  driver with regard to the following documents:                           */
/*                                                                           */
/*  VPP-3.1: Instrument Drivers                                              */
/*      Architecture and Design                                              */
/*      Specification                                                        */
/*      Revision 4.0                                                         */
/*      February 5, 1996                                                     */
/*                                                                           */
/*  VPP-3.2: Instrument Driver                                               */
/*      Functional Body Specification                                        */
/*      Revision 4.0                                                         */
/*      February 2, 1996                                                     */
/*                                                                           */
/* By: Jan Sima                                                             */                                                       
/*                                                        */
/*###########################################################################*/
#ifndef _REMVXIPNP

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrSession)
{
    ViStatus   RSCMU_status = VI_SUCCESS;
    ViString   p2str;
    ViInt32    board = 0,
            primaryAddr = 0,
            secondaryAddr = 0;
    ViChar     errorMessage[WR_BUFFER_SIZE];
    ViSession  rmHandle;
    
    /* --- Set standard "C" locale --- */
    {
        char *locale;

        locale = setlocale(LC_ALL, "C");
    }

    p2str = resourceName;
    
   if (strncmp (p2str, "GPIB", 4) != 0)
      return VI_ERROR_INV_RSRC_NAME;
      
   p2str += 4;

   if (p2str[0] >= '0' && p2str[0] <= '9')
      board = (p2str++)[0] - '0';
      
   if (strncmp (p2str, "::", 2) != 0)
      return VI_ERROR_INV_RSRC_NAME;
      
   if (sscanf (p2str += 2, "%ld", &primaryAddr) != 1)
      return VI_ERROR_INV_RSRC_NAME;

   p2str += (primaryAddr > 9) ? 2 : 1; 
   
   if (strlen (p2str) != 0 && strncmp (p2str, "::", 2) != 0)
      return VI_ERROR_INV_RSRC_NAME;
   
   if (strlen (p2str) != 0) {
      if (sscanf (p2str += 2, "%ld", &secondaryAddr) != 1)
         return VI_ERROR_INV_RSRC_NAME;
      
      p2str += (secondaryAddr > 9) ? 2 : 1;     
      
      if (strlen (p2str) != 0 && strcmp (p2str, "::INSTR") != 0)
         return VI_ERROR_INV_RSRC_NAME;
   }
      
   if (secondaryAddr == 0) {
      if ((RSCMU_status = RSCMU_Init_Base (instrSession, RSCMU_GPIB, board, primaryAddr,
                                  IDQuery, resetDevice, errorMessage)) < 0)
         return RSCMU_status;
   } else {    
      if ((RSCMU_status = viOpenDefaultRM (&rmHandle)) != 0)
         return RSCMU_status;
      
      if ((RSCMU_status = viOpen (rmHandle, resourceName, VI_NULL, VI_NULL, instrSession)) != 0) 
         return RSCMU_status;
   
       if ((RSCMU_status = viGpibControlREN (*instrSession, VI_GPIB_REN_ASSERT)) < 0)
          return RSCMU_status;
    }    
    
    return RSCMU_status;
}

/*===========================================================================*/
/* Function: Init AMPS                                                       */
/* Purpose:  This function initializes the AMPS module's                     */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_initAMPS (ViSession  AMPSSession,
                                 ViSession   BaseSession,
                                 ViInt32  AMPSFunctionGroup)
{
   ViStatus    RSCMU_Status = VI_SUCCESS;
   ViSession   globalSession = 0;
   ViInt32     secondAddr = 0, comp = 1;
   ViChar      FctGrpBuffer[128]= "", resource[25]="";
   ViReal64    Flag = RSCMU_OFF;
   ViChar      errorMessage[WR_BUFFER_SIZE];

   struct RSCMU_Base_Globals  *p_globalvarBase;
   struct RSCMU_AMPS_Globals  *p_globalvarAMPS;

   // Which Function Group does the User want?
   switch( AMPSFunctionGroup )
   {
   case RSCMU_AMPSMS_NSIG:
      // Record "Function Group Name" for the actual Session.
      strcpy( FctGrpBuffer, "\"AMPSMS_NSig\"" );
      break;

   case RSCMU_AMPSMS_SIG:
      // Record "Function Group Name" for the actual Session.
      strcpy( FctGrpBuffer, "\"AMPSMS_Sig\"" );
      break;

   default:
      break;
   }

   // Init the Error Message  
   strcpy (errorMessage, "No Error");

   // Get the current options (= Function Group Names) in the CMU.
   if ((RSCMU_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
     return RSCMU_errorMessage (BaseSession, RSCMU_Status, errorMessage);

   // Find the Secondary address
   while ((comp != 0) && (secondAddr < 30))
   {
     secondAddr++;
     comp = strncmp (p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));  
     if (comp == 0)  Flag = RSCMU_ON;
   }

   if (Flag == RSCMU_OFF)
     return RSCMU_errorMessage (AMPSSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

    // Allocate space for "struct RSCMU_SESSION_Globals" 
    if( (p_globalvarAMPS = (struct RSCMU_AMPS_Globals *) malloc(sizeof(struct RSCMU_AMPS_Globals))) == 0 )
       return RSCMU_initCleanUp( globalSession, AMPSSession, RSCMU_Status);
      
    if( (RSCMU_Status = viSetAttribute( AMPSSession, VI_ATTR_USER_DATA, (ViAttrState)p_globalvarAMPS)) < 0 )
       return RSCMU_initCleanUp( globalSession, AMPSSession, RSCMU_Status);
      
    // Which Function Group does the User want?
    switch( AMPSFunctionGroup )
    {
      case RSCMU_AMPSMS_NSIG:
         // No "HandOverName" for this group
         break;

      case RSCMU_AMPSMS_SIG:
         // Record the "HandOverName" for the actual Session.
         strcpy( p_globalvarAMPS->RSCMU_tHandOver.HandOverSessionName, "\"AMPSMS\"" );
         break;

      default:
         break;
    }
      
   // Set initial values of variables for function Group 'AMPS' .
    strcpy( p_globalvarAMPS->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer );
   strcpy (p_globalvarAMPS->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
    p_globalvarAMPS->RSCMU_tGlobal.RSCMU_primary_address = p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;
    p_globalvarAMPS->RSCMU_tGlobal.RSCMU_secondary_address = secondAddr;
    p_globalvarAMPS->RSCMU_tGlobal.RSCMU_SessionNb = AMPSSession;
    p_globalvarAMPS->RSCMU_tGlobal.RSCMU_TRACE = p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
   
    p_globalvarAMPS->RSCMU_tGlobal.RSCMU_FileHandle = p_globalvarBase->RSCMU_tGlobal.RSCMU_FileHandle;
    p_globalvarAMPS->RSCMU_tGlobal.RSCMU_AddrTargetFile = (ViAddr) p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;
    p_globalvarAMPS->RSCMU_tGlobal.RSCMU_StateTraceFile = p_globalvarBase->RSCMU_tGlobal.RSCMU_StateTraceFile;
    
    // Record the execution of this Init Function.    
    p_globalvarBase->RSCMU_tSecAddr[secondAddr].SessionNb = AMPSSession;  

   // Timeout changed from 10s to 30 seconds 
   if ((RSCMU_Status = viSetAttribute (AMPSSession, VI_ATTR_TMO_VALUE, RSCMU_TMO_VALUE)) < 0)
     return RSCMU_Status;

   return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Get Instrument Handle                                           */
/* Purpose:  This function passes the instrument handle from the first       */
/*           parameter to the second parameter. This function is used in VEE */
/*           where it allows to get the current instrument handle.          */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession instrumentHandle,
                                             ViSession *instrumentHandleOut)
{
   *instrumentHandleOut = instrumentHandle;
    return 0;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.  If the reset function     */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_reset (ViSession instrSession)
{
   return VI_WARN_NSUP_RESET;
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_self_test (ViSession instrSession,
                                    ViPInt16 testResult,
                                    ViChar _VI_FAR testMessage[])
{
    return VI_WARN_NSUP_SELF_TEST;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result.                                        */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[])
{
   return VI_WARN_NSUP_ERROR_QUERY;
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR errMessage[])
{
   return RSCMU_errorMessage (instrSession, statusCode, errMessage);
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_revision_query (ViSession instrSession,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
   strcpy (driverRev, RSCMUK2A_REVISION);
   if (instrRev != 0)
      {
      strcpy (instrRev, "Not defined");
      }
   return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_close (ViSession instrSession)
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar  errorMessage[WR_BUFFER_SIZE];
    ViUInt16 secAddr;
    
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_GPIB_SECONDARY_ADDR, &secAddr)) < 0)
      return RSCMU_Status;

    if (secAddr == 0) {
      if ((RSCMU_Status = RSCMU_Close_Base (instrSession, errorMessage)) < 0)
         return RSCMU_Status;
    } else {
      struct RSCMU_RF_NSig_Globals *p_globalvar;

      if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvar)) < 0)
         return RSCMU_Status;

      // Deallocate all system resources
      if ((RSCMU_Status = viClose (instrSession)) < 0)
         return RSCMU_Status;
    
      // Deallocate the space pointed by p_globalvar
      if (p_globalvar)
         free (p_globalvar);
   }     
    return RSCMU_Status;
}

#endif

